@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,16 +17,19 @@
 
 class CustomFieldsController < ApplicationController
   layout 'admin'
+  self.main_menu = false
 
-  before_filter :require_admin
-  before_filter :build_new_custom_field, :only => [:new, :create]
-  before_filter :find_custom_field, :only => [:edit, :update, :destroy]
+  before_action :require_admin
+  before_action :build_new_custom_field, :only => [:new, :create]
+  before_action :find_custom_field, :only => [:edit, :update, :destroy]
   accept_api_auth :index
 
   def index
     respond_to do |format|
       format.html {
         @custom_fields_by_type = CustomField.all.group_by {|f| f.class.name }
+        @custom_fields_projects_count =
+          IssueCustomField.where(is_for_all: false).joins(:projects).group(:custom_field_id).count
       }
       format.api {
         @custom_fields = CustomField.all
@@ -53,26 +56,29 @@ class CustomFieldsController < ApplicationController
   end
 
   def update
-    if @custom_field.update_attributes(params[:custom_field])
+    @custom_field.safe_attributes = params[:custom_field]
+    if @custom_field.save
       call_hook(:controller_custom_fields_edit_after_save, :params => params, :custom_field => @custom_field)
       respond_to do |format|
         format.html {
           flash[:notice] = l(:notice_successful_update)
           redirect_back_or_default edit_custom_field_path(@custom_field)
         }
-        format.js { render :nothing => true }
+        format.js { head 200 }
       end
     else
       respond_to do |format|
         format.html { render :action => 'edit' }
-        format.js { render :nothing => true, :status => 422 }
+        format.js { head 422 }
       end
     end
   end
 
   def destroy
     begin
-      @custom_field.destroy
+      if @custom_field.destroy
+        flash[:notice] = l(:notice_successful_delete)
+      end
     rescue
       flash[:error] = l(:error_can_not_delete_custom_field)
     end
@@ -82,9 +88,11 @@ class CustomFieldsController < ApplicationController
   private
 
   def build_new_custom_field
-    @custom_field = CustomField.new_subclass_instance(params[:type], params[:custom_field])
+    @custom_field = CustomField.new_subclass_instance(params[:type])
     if @custom_field.nil?
       render :action => 'select_type'
+    else
+      @custom_field.safe_attributes = params[:custom_field]
     end
   end
 
