@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 class GanttsController < ApplicationController
   menu_item :gantt
-  before_filter :find_optional_project
+  before_action :find_optional_project
 
   rescue_from Query::StatementInvalid, :with => :query_statement_invalid
 
@@ -26,8 +26,6 @@ class GanttsController < ApplicationController
   helper :projects
   helper :queries
   include QueriesHelper
-  helper :sort
-  include SortHelper
   include Redmine::Export::PDF
 
   def show
