@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,11 +18,11 @@
 class IssuesController < ApplicationController
   default_search_scope :issues
 
-  before_filter :find_issue, :only => [:show, :edit, :update]
-  before_filter :find_issues, :only => [:bulk_edit, :bulk_update, :destroy]
-  before_filter :authorize, :except => [:index, :new, :create]
-  before_filter :find_optional_project, :only => [:index, :new, :create]
-  before_filter :build_new_issue_from_params, :only => [:new, :create]
+  before_action :find_issue, :only => [:show, :edit, :update]
+  before_action :find_issues, :only => [:bulk_edit, :bulk_update, :destroy]
+  before_action :authorize, :except => [:index, :new, :create]
+  before_action :find_optional_project, :only => [:index, :new, :create]
+  before_action :build_new_issue_from_params, :only => [:new, :create]
   accept_rss_auth :index, :show
   accept_api_auth :index, :show, :create, :update, :destroy
 
@@ -37,54 +37,43 @@ class IssuesController < ApplicationController
   helper :queries
   include QueriesHelper
   helper :repositories
-  helper :sort
-  include SortHelper
   helper :timelog
 
   def index
     retrieve_query
-    sort_init(@query.sort_criteria.empty? ? [['id', 'desc']] : @query.sort_criteria)
-    sort_update(@query.sortable_columns)
-    @query.sort_criteria = sort_criteria.to_a
 
     if @query.valid?
-      case params[:format]
-      when 'csv', 'pdf'
-        @limit = Setting.issues_export_limit.to_i
-        if params[:columns] == 'all'
-          @query.column_names = @query.available_inline_columns.map(&:name)
-        end
-      when 'atom'
-        @limit = Setting.feeds_limit.to_i
-      when 'xml', 'json'
-        @offset, @limit = api_offset_and_limit
-        @query.column_names = %w(author)
-      else
-        @limit = per_page_option
-      end
-
-      @issue_count = @query.issue_count
-      @issue_pages = Paginator.new @issue_count, @limit, params['page']
-      @offset ||= @issue_pages.offset
-      @issues = @query.issues(:include => [:assigned_to, :tracker, :priority, :category, :fixed_version],
-                              :order => sort_clause,
-                              :offset => @offset,
-                              :limit => @limit)
-      @issue_count_by_group = @query.issue_count_by_group
-
       respond_to do |format|
-        format.html { render :template => 'issues/index', :layout => !request.xhr? }
+        format.html {
+          @issue_count = @query.issue_count
+          @issue_pages = Paginator.new @issue_count, per_page_option, params['page']
+          @issues = @query.issues(:offset => @issue_pages.offset, :limit => @issue_pages.per_page)
+          render :layout => !request.xhr?
+        }
         format.api  {
+          @offset, @limit = api_offset_and_limit
+          @query.column_names = %w(author)
+          @issue_count = @query.issue_count
+          @issues = @query.issues(:offset => @offset, :limit => @limit)
           Issue.load_visible_relations(@issues) if include_in_api_response?('relations')
         }
-        format.atom { render_feed(@issues, :title => "#{@project || Setting.app_title}: #{l(:label_issue_plural)}") }
-        format.csv  { send_data(query_to_csv(@issues, @query, params[:csv]), :type => 'text/csv; header=present', :filename => 'issues.csv') }
-        format.pdf  { send_file_headers! :type => 'application/pdf', :filename => 'issues.pdf' }
+        format.atom {
+          @issues = @query.issues(:limit => Setting.feeds_limit.to_i)
+          render_feed(@issues, :title => "#{@project || Setting.app_title}: #{l(:label_issue_plural)}")
+        }
+        format.csv  {
+          @issues = @query.issues(:limit => Setting.issues_export_limit.to_i)
+          send_data(query_to_csv(@issues, @query, params[:csv]), :type => 'text/csv; header=present', :filename => 'issues.csv')
+        }
+        format.pdf  {
+          @issues = @query.issues(:limit => Setting.issues_export_limit.to_i)
+          send_file_headers! :type => 'application/pdf', :filename => 'issues.pdf'
+        }
       end
     else
       respond_to do |format|
-        format.html { render(:template => 'issues/index', :layout => !request.xhr?) }
-        format.any(:atom, :csv, :pdf) { render(:nothing => true) }
+        format.html { render :layout => !request.xhr? }
+        format.any(:atom, :csv, :pdf) { head 422 }
         format.api { render_validation_errors(@query) }
       end
     end
@@ -93,26 +82,26 @@ class IssuesController < ApplicationController
   end
 
   def show
-    @journals = @issue.journals.includes(:user, :details).
-                    references(:user, :details).
-                    reorder(:created_on, :id).to_a
-    @journals.each_with_index {|j,i| j.indice = i+1}
-    @journals.reject!(&:private_notes?) unless User.current.allowed_to?(:view_private_notes, @issue.project)
-    Journal.preload_journals_details_custom_fields(@journals)
-    @journals.select! {|journal| journal.notes? || journal.visible_details.any?}
-    @journals.reverse! if User.current.wants_comments_in_reverse_order?
-
+    @journals = @issue.visible_journals_with_index
     @changesets = @issue.changesets.visible.preload(:repository, :user).to_a
-    @changesets.reverse! if User.current.wants_comments_in_reverse_order?
-
     @relations = @issue.relations.select {|r| r.other_issue(@issue) && r.other_issue(@issue).visible? }
-    @allowed_statuses = @issue.new_statuses_allowed_to(User.current)
-    @priorities = IssuePriority.active
-    @time_entry = TimeEntry.new(:issue => @issue, :project => @issue.project)
-    @relation = IssueRelation.new
+
+    if User.current.wants_comments_in_reverse_order?
+      @journals.reverse!
+      @changesets.reverse!
+    end
+
+    if User.current.allowed_to?(:view_time_entries, @project)
+      Issue.load_visible_spent_hours([@issue])
+      Issue.load_visible_total_spent_hours([@issue])
+    end
 
     respond_to do |format|
       format.html {
+        @allowed_statuses = @issue.new_statuses_allowed_to(User.current)
+        @priorities = IssuePriority.active
+        @time_entry = TimeEntry.new(:issue => @issue, :project => @issue.project)
+        @relation = IssueRelation.new
         retrieve_previous_and_next_issue_ids
         render :template => 'issues/show'
       }
@@ -217,32 +206,69 @@ class IssuesController < ApplicationController
       end
     end
 
+    edited_issues = Issue.where(:id => @issues.map(&:id)).to_a
+
+    @values_by_custom_field = {}
+    edited_issues.each do |issue|
+      issue.custom_field_values.each do |c|
+        if c.value_present?
+          @values_by_custom_field[c.custom_field] ||= []
+          @values_by_custom_field[c.custom_field] << issue.id
+        end
+      end
+    end
+
     @allowed_projects = Issue.allowed_target_projects
     if params[:issue]
       @target_project = @allowed_projects.detect {|p| p.id.to_s == params[:issue][:project_id].to_s}
       if @target_project
         target_projects = [@target_project]
+        edited_issues.each {|issue| issue.project = @target_project}
       end
     end
     target_projects ||= @projects
 
+    @trackers = target_projects.map {|p| Issue.allowed_target_trackers(p) }.reduce(:&)
+    if params[:issue]
+      @target_tracker = @trackers.detect {|t| t.id.to_s == params[:issue][:tracker_id].to_s}
+      if @target_tracker
+        edited_issues.each {|issue| issue.tracker = @target_tracker}
+      end
+    end
+
     if @copy
       # Copied issues will get their default statuses
       @available_statuses = []
     else
-      @available_statuses = @issues.map(&:new_statuses_allowed_to).reduce(:&)
+      @available_statuses = edited_issues.map(&:new_statuses_allowed_to).reduce(:&)
     end
-    @custom_fields = @issues.map{|i|i.editable_custom_fields}.reduce(:&)
+    if params[:issue]
+      @target_status = @available_statuses.detect {|t| t.id.to_s == params[:issue][:status_id].to_s}
+      if @target_status
+        edited_issues.each {|issue| issue.status = @target_status}
+      end
+    end
+
+    edited_issues.each do |issue|
+      issue.custom_field_values.each do |c|
+        if c.value_present? && @values_by_custom_field[c.custom_field]
+          @values_by_custom_field[c.custom_field].delete(issue.id)
+        end
+      end
+    end
+    @values_by_custom_field.delete_if {|k,v| v.blank?}
+
+    @custom_fields = edited_issues.map{|i|i.editable_custom_fields}.reduce(:&).select {|field| field.format.bulk_edit_supported}
     @assignables = target_projects.map(&:assignable_users).reduce(:&)
-    @trackers = target_projects.map {|p| Issue.allowed_target_trackers(p) }.reduce(:&)
     @versions = target_projects.map {|p| p.shared_versions.open}.reduce(:&)
     @categories = target_projects.map {|p| p.issue_categories}.reduce(:&)
     if @copy
       @attachments_present = @issues.detect {|i| i.attachments.any?}.present?
       @subtasks_present = @issues.detect {|i| !i.leaf?}.present?
+      @watchers_present = User.current.allowed_to?(:add_issue_watchers, @projects) && Watcher.where(:watchable_type => 'Issue', :watchable_id => @issues.map(&:id)).exists?
     end
 
-    @safe_attributes = @issues.map(&:safe_attribute_names).reduce(:&)
+    @safe_attributes = edited_issues.map(&:safe_attribute_names).reduce(:&)
 
     @issue_params = params[:issue] || {}
     @issue_params[:custom_field_values] ||= {}
@@ -255,6 +281,7 @@ class IssuesController < ApplicationController
     attributes = parse_params_for_bulk_update(params[:issue])
     copy_subtasks = (params[:copy_subtasks] == '1')
     copy_attachments = (params[:copy_attachments] == '1')
+    copy_watchers = (params[:copy_watchers] == '1')
 
     if @copy
       unless User.current.allowed_to?(:copy_issues, @projects)
@@ -267,6 +294,9 @@ class IssuesController < ApplicationController
       unless User.current.allowed_to?(:add_issues, target_projects)
         raise ::Unauthorized
       end
+      unless User.current.allowed_to?(:add_issue_watchers, @projects)
+        copy_watchers = false
+      end
     else
       unless @issues.all?(&:attributes_editable?)
         raise ::Unauthorized
@@ -288,6 +318,7 @@ class IssuesController < ApplicationController
         issue = orig_issue.copy({},
           :attachments => copy_attachments,
           :subtasks => copy_subtasks,
+          :watchers => copy_watchers,
           :link => link_copy?(params[:link_copy])
         )
       else
@@ -325,21 +356,28 @@ class IssuesController < ApplicationController
 
   def destroy
     raise Unauthorized unless @issues.all?(&:deletable?)
-    @hours = TimeEntry.where(:issue_id => @issues.map(&:id)).sum(:hours).to_f
+
+    # all issues and their descendants are about to be deleted
+    issues_and_descendants_ids = Issue.self_and_descendants(@issues).pluck(:id)
+    time_entries = TimeEntry.where(:issue_id => issues_and_descendants_ids)
+    @hours = time_entries.sum(:hours).to_f
+
     if @hours > 0
       case params[:todo]
       when 'destroy'
         # nothing to do
       when 'nullify'
-        TimeEntry.where(['issue_id IN (?)', @issues]).update_all('issue_id = NULL')
+        time_entries.update_all(:issue_id => nil)
       when 'reassign'
-        reassign_to = @project.issues.find_by_id(params[:reassign_to_id])
+        reassign_to = @project && @project.issues.find_by_id(params[:reassign_to_id])
         if reassign_to.nil?
           flash.now[:error] = l(:error_issue_not_found_in_project)
           return
+        elsif issues_and_descendants_ids.include?(reassign_to.id)
+          flash.now[:error] = l(:error_cannot_reassign_time_entries_to_an_issue_about_to_be_deleted)
+          return
         else
-          TimeEntry.where(['issue_id IN (?)', @issues]).
-            update_all("issue_id = #{reassign_to.id}")
+          time_entries.update_all(:issue_id => reassign_to.id, :project_id => reassign_to.project_id)
         end
       else
         # display the destroy form if it's a user request
@@ -362,7 +400,7 @@ class IssuesController < ApplicationController
   # Overrides Redmine::MenuManager::MenuController::ClassMethods for
   # when the "New issue" tab is enabled
   def current_menu_item
-    if Setting.new_item_menu_tab == '1' && [:new, :create].include?(action_name.to_sym) 
+    if Setting.new_item_menu_tab == '1' && [:new, :create].include?(action_name.to_sym)
       :new_issue
     else
       super
@@ -380,10 +418,9 @@ class IssuesController < ApplicationController
     else
       retrieve_query_from_session
       if @query
-        sort_init(@query.sort_criteria.empty? ? [['id', 'desc']] : @query.sort_criteria)
-        sort_update(@query.sortable_columns, 'issues_index_sort')
+        @per_page = per_page_option
         limit = 500
-        issue_ids = @query.issue_ids(:order => sort_clause, :limit => (limit + 1), :include => [:assigned_to, :tracker, :priority, :category, :fixed_version])
+        issue_ids = @query.issue_ids(:limit => (limit + 1))
         if (idx = issue_ids.index(@issue.id)) && idx < limit
           if issue_ids.size < 500
             @issue_position = idx + 1
@@ -392,6 +429,11 @@ class IssuesController < ApplicationController
           @prev_issue_id = issue_ids[idx - 1] if idx > 0
           @next_issue_id = issue_ids[idx + 1] if idx < (issue_ids.size - 1)
         end
+        query_params = @query.as_params
+        if @issue_position
+          query_params = query_params.merge(:page => (@issue_position / per_page_option) + 1, :per_page => per_page_option)
+        end
+        @query_path = _project_issues_path(@query.project, query_params)
       end
     end
   end
@@ -448,7 +490,8 @@ class IssuesController < ApplicationController
         @link_copy = link_copy?(params[:link_copy]) || request.get?
         @copy_attachments = params[:copy_attachments].present? || request.get?
         @copy_subtasks = params[:copy_subtasks].present? || request.get?
-        @issue.copy_from(@copy_from, :attachments => @copy_attachments, :subtasks => @copy_subtasks, :link => @link_copy)
+        @copy_watchers = User.current.allowed_to?(:add_issue_watchers, @project)
+        @issue.copy_from(@copy_from, :attachments => @copy_attachments, :subtasks => @copy_subtasks, :watchers => @copy_watchers, :link => @link_copy)
         @issue.parent_issue_id = @copy_from.parent_id
       rescue ActiveRecord::RecordNotFound
         render_404
@@ -507,7 +550,7 @@ class IssuesController < ApplicationController
         time_entry.issue = @issue
         time_entry.user = User.current
         time_entry.spent_on = User.current.today
-        time_entry.attributes = params[:time_entry]
+        time_entry.safe_attributes = params[:time_entry]
         @issue.time_entries << time_entry
       end
 
@@ -536,15 +579,18 @@ class IssuesController < ApplicationController
   # Redirects user after a successful issue creation
   def redirect_after_create
     if params[:continue]
-      attrs = {:tracker_id => @issue.tracker, :parent_issue_id => @issue.parent_issue_id}.reject {|k,v| v.nil?}
+      url_params = {}
+      url_params[:issue] = {:tracker_id => @issue.tracker, :parent_issue_id => @issue.parent_issue_id}.reject {|k,v| v.nil?}
+      url_params[:back_url] = params[:back_url].presence
+
       if params[:project_id]
-        redirect_to new_project_issue_path(@issue.project, :issue => attrs)
+        redirect_to new_project_issue_path(@issue.project, url_params)
       else
-        attrs.merge! :project_id => @issue.project_id
-        redirect_to new_issue_path(:issue => attrs)
+        url_params[:issue].merge! :project_id => @issue.project_id
+        redirect_to new_issue_path(url_params)
       end
     else
-      redirect_to issue_path(@issue)
+      redirect_back_or_default issue_path(@issue)
     end
   end
 end
