@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,10 +18,10 @@
 class MessagesController < ApplicationController
   menu_item :boards
   default_search_scope :messages
-  before_filter :find_board, :only => [:new, :preview]
-  before_filter :find_attachments, :only => [:preview]
-  before_filter :find_message, :except => [:new, :preview]
-  before_filter :authorize, :except => [:preview, :edit, :destroy]
+  before_action :find_board, :only => [:new, :preview]
+  before_action :find_attachments, :only => [:preview]
+  before_action :find_message, :except => [:new, :preview]
+  before_action :authorize, :except => [:preview, :edit, :destroy]
 
   helper :boards
   helper :watchers
