@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 class ReportsController < ApplicationController
   menu_item :issues
-  before_filter :find_project, :authorize, :find_issue_statuses
+  before_action :find_project, :authorize, :find_issue_statuses
 
   def issue_report
     @trackers = @project.rolled_up_trackers(false).visible
@@ -76,14 +76,8 @@ class ReportsController < ApplicationController
       @rows = @project.descendants.visible
       @data = Issue.by_subproject(@project) || []
       @report_title = l(:field_subproject)
-    end
-
-    respond_to do |format|
-      if @field
-        format.html {}
-      else
-        format.html { redirect_to :action => 'issue_report', :id => @project }
-      end
+    else
+      render_404
     end
   end
 
