@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -16,22 +16,22 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 class TimelogController < ApplicationController
-  menu_item :issues
+  menu_item :time_entries
 
-  before_filter :find_time_entry, :only => [:show, :edit, :update]
-  before_filter :find_time_entries, :only => [:bulk_edit, :bulk_update, :destroy]
-  before_filter :authorize, :only => [:show, :edit, :update, :bulk_edit, :bulk_update, :destroy]
+  before_action :find_time_entry, :only => [:show, :edit, :update]
+  before_action :check_editability, :only => [:edit, :update]
+  before_action :find_time_entries, :only => [:bulk_edit, :bulk_update, :destroy]
+  before_action :authorize, :only => [:show, :edit, :update, :bulk_edit, :bulk_update, :destroy]
 
-  before_filter :find_optional_project, :only => [:new, :create, :index, :report]
-  before_filter :authorize_global, :only => [:new, :create, :index, :report]
+  before_action :find_optional_issue, :only => [:new, :create]
+  before_action :find_optional_project, :only => [:index, :report]
+  before_action :authorize_global, :only => [:new, :create, :index, :report]
 
   accept_rss_auth :index
   accept_api_auth :index, :show, :create, :update, :destroy
 
   rescue_from Query::StatementInvalid, :with => :query_statement_invalid
 
-  helper :sort
-  include SortHelper
   helper :issues
   include TimelogHelper
   helper :custom_fields
@@ -40,20 +40,16 @@ class TimelogController < ApplicationController
   include QueriesHelper
 
   def index
-    @query = TimeEntryQuery.build_from_params(params, :project => @project, :name => '_')
-
-    sort_init(@query.sort_criteria.empty? ? [['spent_on', 'desc']] : @query.sort_criteria)
-    sort_update(@query.sortable_columns)
-    scope = time_entry_scope(:order => sort_clause).
-      includes(:project, :user, :issue).
-      preload(:issue => [:project, :tracker, :status, :assigned_to, :priority])
+    retrieve_time_entry_query
+    scope = time_entry_scope.
+      preload(:issue => [:project, :tracker, :status, :assigned_to, :priority]).
+      preload(:project, :user)
 
     respond_to do |format|
       format.html {
         @entry_count = scope.count
         @entry_pages = Paginator.new @entry_count, per_page_option, params['page']
         @entries = scope.offset(@entry_pages.offset).limit(@entry_pages.per_page).to_a
-        @total_hours = scope.sum(:hours).to_f
 
         render :layout => !request.xhr?
       }
@@ -75,7 +71,7 @@ class TimelogController < ApplicationController
   end
 
   def report
-    @query = TimeEntryQuery.build_from_params(params, :project => @project, :name => '_')
+    retrieve_time_entry_query
     scope = time_entry_scope
 
     @report = Redmine::Helpers::TimeReport.new(@project, @issue, params[:criteria], params[:columns], scope)
@@ -89,7 +85,7 @@ class TimelogController < ApplicationController
   def show
     respond_to do |format|
       # TODO: Implement html response
-      format.html { render :nothing => true, :status => 406 }
+      format.html { head 406 }
       format.api
     end
   end
@@ -169,26 +165,40 @@ class TimelogController < ApplicationController
   end
 
   def bulk_edit
-    @available_activities = TimeEntryActivity.shared.active
-    @custom_fields = TimeEntry.first.available_custom_fields
+    @available_activities = @projects.map(&:activities).reduce(:&)
+    @custom_fields = TimeEntry.first.available_custom_fields.select {|field| field.format.bulk_edit_supported}
   end
 
   def bulk_update
     attributes = parse_params_for_bulk_update(params[:time_entry])
 
-    unsaved_time_entry_ids = []
+    unsaved_time_entries = []
+    saved_time_entries = []
+
     @time_entries.each do |time_entry|
       time_entry.reload
       time_entry.safe_attributes = attributes
       call_hook(:controller_time_entries_bulk_edit_before_save, { :params => params, :time_entry => time_entry })
-      unless time_entry.save
-        logger.info "time entry could not be updated: #{time_entry.errors.full_messages}" if logger && logger.info?
-        # Keep unsaved time_entry ids to display them in flash error
-        unsaved_time_entry_ids << time_entry.id
+      if time_entry.save
+        saved_time_entries << time_entry
+      else
+        unsaved_time_entries << time_entry
       end
     end
-    set_flash_from_bulk_time_entry_save(@time_entries, unsaved_time_entry_ids)
-    redirect_back_or_default project_time_entries_path(@projects.first)
+
+    if unsaved_time_entries.empty?
+      flash[:notice] = l(:notice_successful_update) unless saved_time_entries.empty?
+      redirect_back_or_default project_time_entries_path(@projects.first)
+    else
+      @saved_time_entries = @time_entries
+      @unsaved_time_entries = unsaved_time_entries
+      @time_entries = TimeEntry.where(:id => unsaved_time_entries.map(&:id)).
+        preload(:project => :time_entry_activities).
+        preload(:user).to_a
+
+      bulk_edit
+      render :action => 'bulk_edit'
+    end
   end
 
   def destroy
@@ -207,7 +217,7 @@ class TimelogController < ApplicationController
         else
           flash[:error] = l(:notice_unable_delete_time_entry)
         end
-        redirect_back_or_default project_time_entries_path(@projects.first)
+        redirect_back_or_default project_time_entries_path(@projects.first), :referer => true
       }
       format.api  {
         if destroyed
@@ -222,17 +232,23 @@ class TimelogController < ApplicationController
 private
   def find_time_entry
     @time_entry = TimeEntry.find(params[:id])
-    unless @time_entry.editable_by?(User.current)
-      render_403
-      return false
-    end
     @project = @time_entry.project
   rescue ActiveRecord::RecordNotFound
     render_404
   end
 
+  def check_editability
+    unless @time_entry.editable_by?(User.current)
+      render_403
+      return false
+    end
+  end
+
   def find_time_entries
-    @time_entries = TimeEntry.where(:id => params[:id] || params[:ids]).to_a
+    @time_entries = TimeEntry.where(:id => params[:id] || params[:ids]).
+      preload(:project => :time_entry_activities).
+      preload(:user).to_a
+
     raise ActiveRecord::RecordNotFound if @time_entries.empty?
     raise Unauthorized unless @time_entries.all? {|t| t.editable_by?(User.current)}
     @projects = @time_entries.collect(&:project).compact.uniq
@@ -241,22 +257,17 @@ private
     render_404
   end
 
-  def set_flash_from_bulk_time_entry_save(time_entries, unsaved_time_entry_ids)
-    if unsaved_time_entry_ids.empty?
-      flash[:notice] = l(:notice_successful_update) unless time_entries.empty?
+  def find_optional_issue
+    if params[:issue_id].present?
+      @issue = Issue.find(params[:issue_id])
+      @project = @issue.project
     else
-      flash[:error] = l(:notice_failed_to_save_time_entries,
-                        :count => unsaved_time_entry_ids.size,
-                        :total => time_entries.size,
-                        :ids => '#' + unsaved_time_entry_ids.join(', #'))
+      find_optional_project
     end
   end
 
   def find_optional_project
-    if params[:issue_id].present?
-      @issue = Issue.find(params[:issue_id])
-      @project = @issue.project
-    elsif params[:project_id].present?
+    if params[:project_id].present?
       @project = Project.find(params[:project_id])
     end
   rescue ActiveRecord::RecordNotFound
@@ -265,10 +276,10 @@ private
 
   # Returns the TimeEntry scope for index and report actions
   def time_entry_scope(options={})
-    scope = @query.results_scope(options)
-    if @issue
-      scope = scope.on_issue(@issue)
-    end
-    scope
+    @query.results_scope(options)
+  end
+
+  def retrieve_time_entry_query
+    retrieve_query(TimeEntryQuery, false)
   end
 end
