@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,9 +17,10 @@
 
 class TrackersController < ApplicationController
   layout 'admin'
+  self.main_menu = false
 
-  before_filter :require_admin, :except => :index
-  before_filter :require_admin_or_api_request, :only => :index
+  before_action :require_admin, :except => :index
+  before_action :require_admin_or_api_request, :only => :index
   accept_api_auth :index
 
   def index
@@ -31,17 +32,19 @@ class TrackersController < ApplicationController
   end
 
   def new
-    @tracker ||= Tracker.new(params[:tracker])
+    @tracker ||= Tracker.new
+    @tracker.safe_attributes = params[:tracker]
     @trackers = Tracker.sorted.to_a
     @projects = Project.all
   end
 
   def create
-    @tracker = Tracker.new(params[:tracker])
+    @tracker = Tracker.new
+    @tracker.safe_attributes = params[:tracker]
     if @tracker.save
       # workflow copy
       if !params[:copy_workflow_from].blank? && (copy_from = Tracker.find_by_id(params[:copy_workflow_from]))
-        @tracker.workflow_rules.copy(copy_from)
+        @tracker.copy_workflow_rules(copy_from)
       end
       flash[:notice] = l(:notice_successful_create)
       redirect_to trackers_path
@@ -58,13 +61,14 @@ class TrackersController < ApplicationController
 
   def update
     @tracker = Tracker.find(params[:id])
-    if @tracker.update_attributes(params[:tracker])
+    @tracker.safe_attributes = params[:tracker]
+    if @tracker.save
       respond_to do |format|
         format.html {
           flash[:notice] = l(:notice_successful_update)
           redirect_to trackers_path(:page => params[:page])
         }
-        format.js { render :nothing => true }
+        format.js { head 200 }
       end
     else
       respond_to do |format|
@@ -72,7 +76,7 @@ class TrackersController < ApplicationController
           edit
           render :action => 'edit'
         }
-        format.js { render :nothing => true, :status => 422 }
+        format.js { head 422 }
       end
     end
   end
