@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 class WikisController < ApplicationController
   menu_item :settings
-  before_filter :find_project, :authorize
+  before_action :find_project, :authorize
 
   # Create or update a project's wiki
   def edit
