@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -34,7 +34,12 @@ module AttachmentsHelper
   def link_to_attachments(container, options = {})
     options.assert_valid_keys(:author, :thumbnails)
 
-    attachments = container.attachments.preload(:author).to_a
+    attachments = if container.attachments.loaded?
+      container.attachments
+    else
+      container.attachments.preload(:author).to_a
+    end
+
     if attachments.any?
       options = {
         :editable => container.attachments_editable?,
@@ -51,19 +56,26 @@ module AttachmentsHelper
     end
   end
 
-  def render_api_attachment(attachment, api)
+  def render_api_attachment(attachment, api, options={})
     api.attachment do
-      api.id attachment.id
-      api.filename attachment.filename
-      api.filesize attachment.filesize
-      api.content_type attachment.content_type
-      api.description attachment.description
-      api.content_url download_named_attachment_url(attachment, attachment.filename)
-      if attachment.thumbnailable?
-        api.thumbnail_url thumbnail_url(attachment)
-      end
-      api.author(:id => attachment.author.id, :name => attachment.author.name) if attachment.author
-      api.created_on attachment.created_on
+      render_api_attachment_attributes(attachment, api)
+      options.each { |key, value| eval("api.#{key} value") }
     end
   end
+
+  def render_api_attachment_attributes(attachment, api)
+    api.id attachment.id
+    api.filename attachment.filename
+    api.filesize attachment.filesize
+    api.content_type attachment.content_type
+    api.description attachment.description
+    api.content_url download_named_attachment_url(attachment, attachment.filename)
+    if attachment.thumbnailable?
+      api.thumbnail_url thumbnail_url(attachment)
+    end
+    if attachment.author
+      api.author(:id => attachment.author.id, :name => attachment.author.name)
+    end
+    api.created_on attachment.created_on
+  end
 end
