@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,9 +27,9 @@ module JournalsHelper
 
   def render_notes(issue, journal, options={})
     content = ''
-    editable = User.current.logged? && (User.current.allowed_to?(:edit_issue_notes, issue.project) || (journal.user == User.current && User.current.allowed_to?(:edit_own_issue_notes, issue.project)))
+    css_classes = "wiki"
     links = []
-    if !journal.notes.blank?
+    if journal.notes.present?
       links << link_to(l(:button_quote),
                        quoted_issue_path(issue, :journal_id => journal),
                        :remote => true,
@@ -37,25 +37,33 @@ module JournalsHelper
                        :title => l(:button_quote),
                        :class => 'icon-only icon-comment'
                       ) if options[:reply_links]
-      links << link_to(l(:button_edit),
-                       edit_journal_path(journal),
-                       :remote => true,
-                       :method => 'get',
-                       :title => l(:button_edit),
-                       :class => 'icon-only icon-edit'
-                      ) if editable
-      links << link_to(l(:button_delete),
-                       journal_path(journal, :notes => ""),
-                       :remote => true,
-                       :method => 'put', :data => {:confirm => l(:text_are_you_sure)}, 
-                       :title => l(:button_delete),
-                       :class => 'icon-only icon-del'
-                      ) if editable
+
+      if journal.editable_by?(User.current)
+        links << link_to(l(:button_edit),
+                         edit_journal_path(journal),
+                         :remote => true,
+                         :method => 'get',
+                         :title => l(:button_edit),
+                         :class => 'icon-only icon-edit'
+                        )
+        links << link_to(l(:button_delete),
+                         journal_path(journal, :journal => {:notes => ""}),
+                         :remote => true,
+                         :method => 'put', :data => {:confirm => l(:text_are_you_sure)}, 
+                         :title => l(:button_delete),
+                         :class => 'icon-only icon-del'
+                        )
+        css_classes << " editable"
+      end
     end
     content << content_tag('div', links.join(' ').html_safe, :class => 'contextual') unless links.empty?
     content << textilizable(journal, :notes)
-    css_classes = "wiki"
-    css_classes << " editable" if editable
     content_tag('div', content.html_safe, :id => "journal-#{journal.id}-notes", :class => css_classes)
   end
+
+  def render_private_notes_indicator(journal)
+    content = journal.private_notes? ? l(:field_is_private) : ''
+    css_classes = journal.private_notes? ? 'private' : ''
+    content_tag('span', content.html_safe, :id => "journal-#{journal.id}-private_notes", :class => css_classes)
+  end
 end
