@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -16,6 +16,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 class CustomField < ActiveRecord::Base
+  include Redmine::SafeAttributes
   include Redmine::SubclassFactory
 
   has_many :enumerations,
@@ -31,6 +32,7 @@ class CustomField < ActiveRecord::Base
   validates_presence_of :name, :field_format
   validates_uniqueness_of :name, :scope => :type
   validates_length_of :name, :maximum => 30
+  validates_length_of :regexp, maximum: 255
   validates_inclusion_of :field_format, :in => Proc.new { Redmine::FieldFormat.available_formats }
   validate :validate_custom_field
   attr_protected :id
@@ -61,11 +63,35 @@ class CustomField < ActiveRecord::Base
       where(:visible => true)
     end
   }
-
   def visible_by?(project, user=User.current)
     visible? || user.admin?
   end
 
+  safe_attributes 'name',
+    'field_format',
+    'possible_values',
+    'regexp',
+    'min_length',
+    'max_length',
+    'is_required',
+    'is_for_all',
+    'is_filter',
+    'position',
+    'searchable',
+    'default_value',
+    'editable',
+    'visible',
+    'multiple',
+    'description',
+    'role_ids',
+    'url_pattern',
+    'text_formatting',
+    'edit_tag_style',
+    'user_role',
+    'version_status',
+    'extensions_allowed',
+    'full_width_layout'
+
   def format
     @format ||= Redmine::FieldFormat.find(field_format)
   end
@@ -140,6 +166,10 @@ class CustomField < ActiveRecord::Base
     end
   end
 
+  def set_custom_field_value(custom_field_value, value)
+    format.set_custom_field_value(self, custom_field_value, value)
+  end
+
   def cast_value(value)
     format.cast_value(self, value)
   end
@@ -157,6 +187,10 @@ class CustomField < ActiveRecord::Base
     format.totalable_supported
   end
 
+  def full_width_layout?
+    full_width_layout == '1'
+  end
+
   # Returns a ORDER BY clause that can used to sort customized
   # objects by their value of the custom field.
   # Returns nil if the custom field can not be used for sorting.
@@ -220,7 +254,7 @@ class CustomField < ActiveRecord::Base
 
   # to move in project_custom_field
   def self.for_all
-    where(:is_for_all => true).order('position').to_a
+    where(:is_for_all => true).order(:position).to_a
   end
 
   def type_name
@@ -231,20 +265,23 @@ class CustomField < ActiveRecord::Base
   # or an empty array if value is a valid value for the custom field
   def validate_custom_value(custom_value)
     value = custom_value.value
-    errs = []
-    if value.is_a?(Array)
-      if !multiple?
-        errs << ::I18n.t('activerecord.errors.messages.invalid')
-      end
-      if is_required? && value.detect(&:present?).nil?
-        errs << ::I18n.t('activerecord.errors.messages.blank')
-      end
-    else
-      if is_required? && value.blank?
-        errs << ::I18n.t('activerecord.errors.messages.blank')
+    errs = format.validate_custom_value(custom_value)
+
+    unless errs.any?
+      if value.is_a?(Array)
+        if !multiple?
+          errs << ::I18n.t('activerecord.errors.messages.invalid')
+        end
+        if is_required? && value.detect(&:present?).nil?
+          errs << ::I18n.t('activerecord.errors.messages.blank')
+        end
+      else
+        if is_required? && value.blank?
+          errs << ::I18n.t('activerecord.errors.messages.blank')
+        end
       end
     end
-    errs += format.validate_custom_value(custom_value)
+
     errs
   end
 
@@ -258,6 +295,10 @@ class CustomField < ActiveRecord::Base
     validate_field_value(value).empty?
   end
 
+  def after_save_custom_value(custom_value)
+    format.after_save_custom_value(self, custom_value)
+  end
+
   def format_in?(*args)
     args.include?(field_format)
   end
