@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -16,6 +16,8 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 class EmailAddress < ActiveRecord::Base
+  include Redmine::SafeAttributes
+
   belongs_to :user
   attr_protected :id
 
@@ -29,6 +31,8 @@ class EmailAddress < ActiveRecord::Base
   validates_uniqueness_of :address, :case_sensitive => false,
     :if => Proc.new {|email| email.address_changed? && email.address.present?}
 
+  safe_attributes 'address'
+
   def address=(arg)
     write_attribute(:address, arg.to_s.strip)
   end
