@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -37,12 +37,12 @@ class GroupBuiltin < Group
   class << self
     def load_instance
       return nil if self == GroupBuiltin
-      instance = order('id').first || create_instance
+      instance = unscoped.order('id').first || create_instance
     end
 
     def create_instance
       raise 'The builtin group already exists.' if exists?
-      instance = new
+      instance = unscoped.new
       instance.lastname = name
       instance.save :validate => false
       raise 'Unable to create builtin group.' if instance.new_record?
