@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,6 +20,9 @@ class IssueCustomField < CustomField
   has_and_belongs_to_many :trackers, :join_table => "#{table_name_prefix}custom_fields_trackers#{table_name_suffix}", :foreign_key => "custom_field_id"
   has_many :issues, :through => :issue_custom_values
 
+  safe_attributes 'project_ids',
+    'tracker_ids'
+
   def type_name
     :label_issue_plural
   end
