@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -72,9 +72,6 @@ class MemberRole < ActiveRecord::Base
   end
 
   def remove_inherited_roles
-    MemberRole.where(:inherited_from => id).group_by(&:member).
-        each do |member, member_roles|
-      member_roles.each(&:destroy)
-    end
+    MemberRole.where(:inherited_from => id).destroy_all
   end
 end
