@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -37,21 +37,22 @@ class Project < ActiveRecord::Base
   has_and_belongs_to_many :trackers, lambda {order(:position)}
   has_many :issues, :dependent => :destroy
   has_many :issue_changes, :through => :issues, :source => :journals
-  has_many :versions, lambda {order("#{Version.table_name}.effective_date DESC, #{Version.table_name}.name DESC")}, :dependent => :destroy
+  has_many :versions, :dependent => :destroy
   belongs_to :default_version, :class_name => 'Version'
+  belongs_to :default_assigned_to, :class_name => 'Principal'
   has_many :time_entries, :dependent => :destroy
-  has_many :queries, :class_name => 'IssueQuery', :dependent => :delete_all
+  has_many :queries, :dependent => :delete_all
   has_many :documents, :dependent => :destroy
   has_many :news, lambda {includes(:author)}, :dependent => :destroy
-  has_many :issue_categories, lambda {order("#{IssueCategory.table_name}.name")}, :dependent => :delete_all
-  has_many :boards, lambda {order("position ASC")}, :dependent => :destroy
-  has_one :repository, lambda {where(["is_default = ?", true])}
+  has_many :issue_categories, lambda {order(:name)}, :dependent => :delete_all
+  has_many :boards, lambda {order(:position)}, :inverse_of => :project, :dependent => :destroy
+  has_one :repository, lambda {where(:is_default => true)}
   has_many :repositories, :dependent => :destroy
   has_many :changesets, :through => :repository
   has_one :wiki, :dependent => :destroy
   # Custom field for the project issues
   has_and_belongs_to_many :issue_custom_fields,
-                          lambda {order("#{CustomField.table_name}.position")},
+                          lambda {order(:position)},
                           :class_name => 'IssueCustomField',
                           :join_table => "#{table_name_prefix}custom_fields_projects#{table_name_suffix}",
                           :association_foreign_key => 'custom_field_id'
@@ -72,7 +73,7 @@ class Project < ActiveRecord::Base
   validates_uniqueness_of :identifier, :if => Proc.new {|p| p.identifier_changed?}
   validates_length_of :name, :maximum => 255
   validates_length_of :homepage, :maximum => 255
-  validates_length_of :identifier, :in => 1..IDENTIFIER_MAX_LENGTH
+  validates_length_of :identifier, :maximum => IDENTIFIER_MAX_LENGTH
   # downcase letters, digits, dashes but not digits only
   validates_format_of :identifier, :with => /\A(?!\d+$)[a-z0-9\-_]*\z/, :if => Proc.new { |p| p.identifier_changed? }
   # reserved words
@@ -103,11 +104,9 @@ class Project < ActiveRecord::Base
     where(Project.allowed_to_condition(user, permission, *args))
   }
   scope :like, lambda {|arg|
-    if arg.blank?
-      where(nil)
-    else
-      pattern = "%#{arg.to_s.strip.downcase}%"
-      where("LOWER(identifier) LIKE :p OR LOWER(name) LIKE :p", :p => pattern)
+    if arg.present?
+      pattern = "%#{arg.to_s.strip}%"
+      where("LOWER(identifier) LIKE LOWER(:p) OR LOWER(name) LIKE LOWER(:p)", :p => pattern)
     end
   }
   scope :sorted, lambda {order(:lft)}
@@ -173,15 +172,16 @@ class Project < ActiveRecord::Base
   # Returns a SQL conditions string used to find all projects for which +user+ has the given +permission+
   #
   # Valid options:
-  # * :project => limit the condition to project
-  # * :with_subprojects => limit the condition to project and its subprojects
-  # * :member => limit the condition to the user projects
+  # * :skip_pre_condition => true       don't check that the module is enabled (eg. when the condition is already set elsewhere in the query)
+  # * :project => project               limit the condition to project
+  # * :with_subprojects => true         limit the condition to project and its subprojects
+  # * :member => true                   limit the condition to the user projects
   def self.allowed_to_condition(user, permission, options={})
     perm = Redmine::AccessControl.permission(permission)
     base_statement = (perm && perm.read? ? "#{Project.table_name}.status <> #{Project::STATUS_ARCHIVED}" : "#{Project.table_name}.status = #{Project::STATUS_ACTIVE}")
-    if perm && perm.project_module
+    if !options[:skip_pre_condition] && perm && perm.project_module
       # If the permission belongs to a project module, make sure the module is enabled
-      base_statement << " AND #{Project.table_name}.id IN (SELECT em.project_id FROM #{EnabledModule.table_name} em WHERE em.name='#{perm.project_module}')"
+      base_statement << " AND EXISTS (SELECT 1 AS one FROM #{EnabledModule.table_name} em WHERE em.project_id = #{Project.table_name}.id AND em.name='#{perm.project_module}')"
     end
     if project = options[:project]
       project_statement = project.project_condition(options[:with_subprojects])
@@ -204,9 +204,9 @@ class Project < ActiveRecord::Base
           statement_by_role[role] = s
         end
       end
-      user.projects_by_role.each do |role, projects|
-        if role.allowed_to?(permission) && projects.any?
-          statement_by_role[role] = "#{Project.table_name}.id IN (#{projects.collect(&:id).join(',')})"
+      user.project_ids_by_role.each do |role, project_ids|
+        if role.allowed_to?(permission) && project_ids.any?
+          statement_by_role[role] = "#{Project.table_name}.id IN (#{project_ids.join(',')})"
         end
       end
       if statement_by_role.empty?
@@ -235,11 +235,11 @@ class Project < ActiveRecord::Base
   end
 
   def principals
-    @principals ||= Principal.active.joins(:members).where("#{Member.table_name}.project_id = ?", id).uniq
+    @principals ||= Principal.active.joins(:members).where("#{Member.table_name}.project_id = ?", id).distinct
   end
 
   def users
-    @users ||= User.active.joins(:members).where("#{Member.table_name}.project_id = ?", id).uniq
+    @users ||= User.active.joins(:members).where("#{Member.table_name}.project_id = ?", id).distinct
   end
 
   # Returns the Systemwide and project specific activities
@@ -324,6 +324,8 @@ class Project < ActiveRecord::Base
     @shared_versions = nil
     @rolled_up_versions = nil
     @rolled_up_trackers = nil
+    @rolled_up_statuses = nil
+    @rolled_up_custom_fields = nil
     @all_issue_custom_fields = nil
     @all_time_entry_custom_fields = nil
     @to_param = nil
@@ -350,6 +352,10 @@ class Project < ActiveRecord::Base
     self.status == STATUS_ACTIVE
   end
 
+  def closed?
+    self.status == STATUS_CLOSED
+  end
+
   def archived?
     self.status == STATUS_ARCHIVED
   end
@@ -362,7 +368,7 @@ class Project < ActiveRecord::Base
 
     if version_ids.any? &&
       Issue.
-        includes(:project).
+        joins(:project).
         where("#{Project.table_name}.lft < ? OR #{Project.table_name}.rgt > ?", lft, rgt).
         where(:fixed_version_id => version_ids).
         exists?
@@ -377,8 +383,12 @@ class Project < ActiveRecord::Base
   # Unarchives the project
   # All its ancestors must be active
   def unarchive
-    return false if ancestors.detect {|a| !a.active?}
-    update_attribute :status, STATUS_ACTIVE
+    return false if ancestors.detect {|a| a.archived?}
+    new_status = STATUS_ACTIVE
+    if parent
+      new_status = parent.status
+    end
+    update_attribute :status, new_status
   end
 
   def close
@@ -439,10 +449,21 @@ class Project < ActiveRecord::Base
       joins(projects: :enabled_modules).
       where("#{Project.table_name}.status <> ?", STATUS_ARCHIVED).
       where(:enabled_modules => {:name => 'issue_tracking'}).
-      uniq.
+      distinct.
       sorted
   end
 
+  def rolled_up_statuses
+    issue_status_ids = WorkflowTransition.
+      where(:tracker_id => rolled_up_trackers.map(&:id)).
+      distinct.
+      pluck(:old_status_id, :new_status_id).
+      flatten.
+      uniq
+
+    IssueStatus.where(:id => issue_status_ids).sorted
+  end
+
   # Closes open and locked project versions that are completed
   def close_completed_versions
     Version.transaction do
@@ -500,17 +521,23 @@ class Project < ActiveRecord::Base
   # Adds user as a project member with the default role
   # Used for when a non-admin user creates a project
   def add_default_member(user)
-    role = Role.givable.find_by_id(Setting.new_project_user_role_id.to_i) || Role.givable.first
+    role = self.class.default_member_role
     member = Member.new(:project => self, :principal => user, :roles => [role])
     self.members << member
     member
   end
 
+	# Default role that is given to non-admin users that
+	# create a project
+  def self.default_member_role
+    Role.givable.find_by_id(Setting.new_project_user_role_id.to_i) || Role.givable.first
+  end
+
   # Deletes all project's members
   def delete_all_members
     me, mr = Member.table_name, MemberRole.table_name
     self.class.connection.delete("DELETE FROM #{mr} WHERE #{mr}.member_id IN (SELECT #{me}.id FROM #{me} WHERE #{me}.project_id = #{id})")
-    Member.delete_all(['project_id = ?', id])
+    Member.where(:project_id => id).delete_all
   end
 
   # Return a Principal scope of users/groups issues can be assigned to
@@ -524,7 +551,7 @@ class Project < ActiveRecord::Base
       active.
       joins(:members => :roles).
       where(:type => types, :members => {:project_id => id}, :roles => {:assignable => true}).
-      uniq.
+      distinct.
       sorted
 
     if tracker
@@ -564,6 +591,22 @@ class Project < ActiveRecord::Base
     end
   end
 
+  # Returns a scope of all custom fields enabled for issues of the project
+  # and its subprojects
+  def rolled_up_custom_fields
+    if leaf?
+      all_issue_custom_fields
+    else
+      @rolled_up_custom_fields ||= IssueCustomField.
+        sorted.
+        where("is_for_all = ? OR EXISTS (SELECT 1" +
+          " FROM #{table_name_prefix}custom_fields_projects#{table_name_suffix} cfp" +
+          " JOIN #{Project.table_name} p ON p.id = cfp.project_id" +
+          " WHERE cfp.custom_field_id = #{CustomField.table_name}.id" +
+          " AND p.lft >= ? AND p.rgt <= ?)", true, lft, rgt)
+    end
+  end
+
   def project
     self
   end
@@ -713,10 +756,21 @@ class Project < ActiveRecord::Base
     'tracker_ids',
     'issue_custom_field_ids',
     'parent_id',
-    'default_version_id'
+    'default_version_id',
+    'default_assigned_to_id'
 
   safe_attributes 'enabled_module_names',
-    :if => lambda {|project, user| project.new_record? || user.allowed_to?(:select_project_modules, project) }
+    :if => lambda {|project, user|
+        if project.new_record?
+          if user.admin?
+            true
+          else
+            default_member_role.has_permission?(:select_project_modules)
+          end
+        else
+          user.allowed_to?(:select_project_modules, project)
+        end
+      }
 
   safe_attributes 'inherit_members',
     :if => lambda {|project, user| project.parent.nil? || project.parent.visible?(user)}
@@ -764,7 +818,7 @@ class Project < ActiveRecord::Base
   def copy(project, options={})
     project = project.is_a?(Project) ? project : Project.find(project)
 
-    to_be_copied = %w(wiki versions issue_categories issues members queries boards)
+    to_be_copied = %w(members wiki versions issue_categories issues queries boards)
     to_be_copied = to_be_copied & Array.wrap(options[:only]) unless options[:only].nil?
 
     Project.transaction do
@@ -800,8 +854,11 @@ class Project < ActiveRecord::Base
   end
 
   # Yields the given block for each project with its level in the tree
-  def self.project_tree(projects, &block)
+  def self.project_tree(projects, options={}, &block)
     ancestors = []
+    if options[:init_level] && projects.first
+      ancestors = projects.first.ancestors.to_a
+    end
     projects.sort_by(&:lft).each do |project|
       while (ancestors.any? && !project.is_descendant_of?(ancestors.last))
         ancestors.pop
@@ -825,7 +882,7 @@ class Project < ActiveRecord::Base
   end
 
   def remove_inherited_member_roles
-    member_roles = memberships.map(&:member_roles).flatten
+    member_roles = MemberRole.where(:member_id => membership_ids).to_a
     member_role_ids = member_roles.map(&:id)
     member_roles.each do |member_role|
       if member_role.inherited_from && !member_role_ids.include?(member_role.inherited_from)
@@ -924,7 +981,7 @@ class Project < ActiveRecord::Base
     # get copied before their children
     project.issues.reorder('root_id, lft').each do |issue|
       new_issue = Issue.new
-      new_issue.copy_from(issue, :subtasks => false, :link => false)
+      new_issue.copy_from(issue, :subtasks => false, :link => false, :keep_status => true)
       new_issue.project = self
       # Changing project resets the custom field values
       # TODO: handle this in Issue#project=
@@ -1027,12 +1084,12 @@ class Project < ActiveRecord::Base
   # Copies queries from +project+
   def copy_queries(project)
     project.queries.each do |query|
-      new_query = IssueQuery.new
+      new_query = query.class.new
       new_query.attributes = query.attributes.dup.except("id", "project_id", "sort_criteria", "user_id", "type")
       new_query.sort_criteria = query.sort_criteria if query.sort_criteria
       new_query.project = self
       new_query.user_id = query.user_id
-      new_query.role_ids = query.role_ids if query.visibility == IssueQuery::VISIBILITY_ROLES
+      new_query.role_ids = query.role_ids if query.visibility == ::Query::VISIBILITY_ROLES
       self.queries << new_query
     end
   end
