@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 # Copyright (C) 2007  Patrick Aljord patcito@ŋmail.com
 #
 # This program is free software; you can redistribute it and/or
@@ -22,6 +22,8 @@ class Repository::Git < Repository
   attr_protected :root_url
   validates_presence_of :url
 
+  safe_attributes 'report_last_commit'
+
   def self.human_attribute_name(attribute_key_name, *args)
     attr_name = attribute_key_name.to_s
     if attr_name == "url"
@@ -39,15 +41,15 @@ class Repository::Git < Repository
   end
 
   def report_last_commit
-    extra_report_last_commit
-  end
-
-  def extra_report_last_commit
     return false if extra_info.nil?
     v = extra_info["extra_report_last_commit"]
     return false if v.nil?
     v.to_s != '0'
   end
+ 
+  def report_last_commit=(arg)
+    merge_extra_info "extra_report_last_commit" => arg
+  end
 
   def supports_directory_revisions?
     true
@@ -94,7 +96,7 @@ class Repository::Git < Repository
   end
 
   def scm_entries(path=nil, identifier=nil)
-    scm.entries(path, identifier, :report_last_commit => extra_report_last_commit)
+    scm.entries(path, identifier, :report_last_commit => report_last_commit)
   end
   protected :scm_entries
 
@@ -141,7 +143,7 @@ class Repository::Git < Repository
     return if prev_db_heads.sort == repo_heads.sort
 
     h["db_consistent"]  ||= {}
-    if changesets.count == 0
+    if ! changesets.exists?
       h["db_consistent"]["ordering"] = 1
       merge_extra_info(h)
       self.save
