@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -74,12 +74,12 @@ Rails.application.routes.draw do
   match 'my/account', :controller => 'my', :action => 'account', :via => [:get, :post]
   match 'my/account/destroy', :controller => 'my', :action => 'destroy', :via => [:get, :post]
   match 'my/page', :controller => 'my', :action => 'page', :via => :get
+  post 'my/page', :to => 'my#update_page'
   match 'my', :controller => 'my', :action => 'index', :via => :get # Redirects to my/page
   get 'my/api_key', :to => 'my#show_api_key', :as => 'my_api_key'
   post 'my/api_key', :to => 'my#reset_api_key'
   post 'my/rss_key', :to => 'my#reset_rss_key', :as => 'my_rss_key'
   match 'my/password', :controller => 'my', :action => 'password', :via => [:get, :post]
-  match 'my/page_layout', :controller => 'my', :action => 'page_layout', :via => :get
   match 'my/add_block', :controller => 'my', :action => 'add_block', :via => :post
   match 'my/remove_block', :controller => 'my', :action => 'remove_block', :via => :post
   match 'my/order_blocks', :controller => 'my', :action => 'order_blocks', :via => :post
@@ -101,6 +101,10 @@ Rails.application.routes.draw do
   delete 'issues/:object_id/watchers/:user_id' => 'watchers#destroy', :object_type => 'issue'
 
   resources :projects do
+    collection do
+      get 'autocomplete'
+    end
+
     member do
       get 'settings(/:tab)', :action => 'settings', :as => 'settings'
       post 'modules'
@@ -112,7 +116,7 @@ Rails.application.routes.draw do
     end
 
     shallow do
-      resources :memberships, :controller => 'members', :only => [:index, :show, :new, :create, :update, :destroy] do
+      resources :memberships, :controller => 'members' do
         collection do
           get 'autocomplete'
         end
@@ -188,11 +192,7 @@ Rails.application.routes.draw do
       match 'bulk_edit', :via => [:get, :post]
       post 'bulk_update'
     end
-    resources :time_entries, :controller => 'timelog', :except => [:show, :edit, :update, :destroy] do
-      collection do
-        get 'report'
-      end
-    end
+    resources :time_entries, :controller => 'timelog', :only => [:new, :create]
     shallow do
       resources :relations, :controller => 'issue_relations', :only => [:index, :show, :create, :destroy]
     end
@@ -202,6 +202,7 @@ Rails.application.routes.draw do
   match '/issues', :controller => 'issues', :action => 'destroy', :via => :delete
 
   resources :queries, :except => [:show]
+  get '/queries/filter', :to => 'queries#filter', :as => 'queries_filter'
 
   resources :news, :only => [:index, :show, :edit, :update, :destroy]
   match '/news/:id/comments', :to => 'comments#create', :via => :post
@@ -218,6 +219,10 @@ Rails.application.routes.draw do
   match '/time_entries/context_menu', :to => 'context_menus#time_entries', :as => :time_entries_context_menu, :via => [:get, :post]
 
   resources :time_entries, :controller => 'timelog', :except => :destroy do
+    member do
+      # Used when updating the edit form of an existing time entry
+      patch 'edit', :to => 'timelog#edit'
+    end
     collection do
       get 'report'
       get 'bulk_edit'
@@ -246,13 +251,13 @@ Rails.application.routes.draw do
   post   'projects/:id/repository/:repository_id/revisions/:rev/issues', :to => 'repositories#add_related_issue'
   delete 'projects/:id/repository/:repository_id/revisions/:rev/issues/:issue_id', :to => 'repositories#remove_related_issue'
   get 'projects/:id/repository/:repository_id/revisions', :to => 'repositories#revisions'
-  get 'projects/:id/repository/:repository_id/revisions/:rev/:action(/*path)',
-      :controller => 'repositories',
-      :format => false,
-      :constraints => {
-            :action => /(browse|show|entry|raw|annotate|diff)/,
-            :rev    => /[a-z0-9\.\-_]+/
-          }
+  %w(browse show entry raw annotate diff).each do |action|
+    get "projects/:id/repository/:repository_id/revisions/:rev/#{action}(/*path)",
+        :controller => 'repositories',
+        :action => action,
+        :format => false,
+        :constraints => {:rev => /[a-z0-9\.\-_]+/}
+  end
 
   get 'projects/:id/repository/statistics', :to => 'repositories#stats'
   get 'projects/:id/repository/graph', :to => 'repositories#graph'
@@ -266,21 +271,28 @@ Rails.application.routes.draw do
   get 'projects/:id/repository/revision', :to => 'repositories#revision'
   post   'projects/:id/repository/revisions/:rev/issues', :to => 'repositories#add_related_issue'
   delete 'projects/:id/repository/revisions/:rev/issues/:issue_id', :to => 'repositories#remove_related_issue'
-  get 'projects/:id/repository/revisions/:rev/:action(/*path)',
-      :controller => 'repositories',
-      :format => false,
-      :constraints => {
-            :action => /(browse|show|entry|raw|annotate|diff)/,
-            :rev    => /[a-z0-9\.\-_]+/
-          }
-  get 'projects/:id/repository/:repository_id/:action(/*path)',
-      :controller => 'repositories',
-      :action => /(browse|show|entry|raw|changes|annotate|diff)/,
-      :format => false
-  get 'projects/:id/repository/:action(/*path)',
-      :controller => 'repositories',
-      :action => /(browse|show|entry|raw|changes|annotate|diff)/,
-      :format => false
+  %w(browse show entry raw annotate diff).each do |action|
+    get "projects/:id/repository/revisions/:rev/#{action}(/*path)",
+        :controller => 'repositories',
+        :action => action,
+        :format => false,
+        :constraints => {:rev => /[a-z0-9\.\-_]+/}
+  end
+  %w(browse entry raw changes annotate diff).each do |action|
+    get "projects/:id/repository/:repository_id/#{action}(/*path)",
+        :controller => 'repositories',
+        :action => action,
+        :format => false
+  end
+  %w(browse entry raw changes annotate diff).each do |action|
+    get "projects/:id/repository/#{action}(/*path)",
+        :controller => 'repositories',
+        :action => action,
+        :format => false
+  end
+
+  get 'projects/:id/repository/:repository_id/show/*path', :to => 'repositories#show', :format => false
+  get 'projects/:id/repository/show/*path', :to => 'repositories#show', :format => false
 
   get 'projects/:id/repository/:repository_id', :to => 'repositories#show', :path => nil
   get 'projects/:id/repository', :to => 'repositories#show', :path => nil
@@ -290,9 +302,9 @@ Rails.application.routes.draw do
   get 'attachments/download/:id/:filename', :to => 'attachments#download', :id => /\d+/, :filename => /.*/, :as => 'download_named_attachment'
   get 'attachments/download/:id', :to => 'attachments#download', :id => /\d+/
   get 'attachments/thumbnail/:id(/:size)', :to => 'attachments#thumbnail', :id => /\d+/, :size => /\d+/, :as => 'thumbnail'
-  resources :attachments, :only => [:show, :destroy]
-  get 'attachments/:object_type/:object_id/edit', :to => 'attachments#edit', :as => :object_attachments_edit
-  patch 'attachments/:object_type/:object_id', :to => 'attachments#update', :as => :object_attachments
+  resources :attachments, :only => [:show, :update, :destroy]
+  get 'attachments/:object_type/:object_id/edit', :to => 'attachments#edit_all', :as => :object_attachments_edit
+  patch 'attachments/:object_type/:object_id', :to => 'attachments#update_all', :as => :object_attachments
 
   resources :groups do
     resources :memberships, :controller => 'principal_memberships'
@@ -366,7 +378,7 @@ Rails.application.routes.draw do
 
   get 'robots.txt', :to => 'welcome#robots'
 
-  Dir.glob File.expand_path("plugins/*", Rails.root) do |plugin_dir|
+  Dir.glob File.expand_path("#{Redmine::Plugin.directory}/*") do |plugin_dir|
     file = File.join(plugin_dir, "config/routes.rb")
     if File.exists?(file)
       begin
