@@ -288,14 +288,17 @@ class Setup < ActiveRecord::Migration
     Permission.create :controller => "versions", :action => "destroy_file", :description => "button_delete", :sort => 1322
 
     # create default administrator account
-    user = User.create :login => "admin",
-                       :hashed_password => "d033e22ae348aeb5660fc2140aec35850c4da997",
-                       :admin => true,
-                       :firstname => "Redmine",
-                       :lastname => "Admin",
-                       :mail => "admin@example.net",
-                       :mail_notification => true,
-                       :status => 1
+    user = User.new :firstname => "Redmine",
+                    :lastname => "Admin",
+                    :mail => "admin@example.net",
+                    :mail_notification => true,
+                    :status => 1
+    user.login = 'admin'
+    user.hashed_password = "d033e22ae348aeb5660fc2140aec35850c4da997"
+    user.admin = true
+    user.save
+
+
   end
 
   def self.down
