@@ -1,7 +1,7 @@
 class AddRolePosition < ActiveRecord::Migration
   def self.up
     add_column :roles, :position, :integer, :default => 1
-    Role.find(:all).each_with_index {|role, i| role.update_attribute(:position, i+1)}
+    Role.all.each_with_index {|role, i| role.update_attribute(:position, i+1)}
   end
 
   def self.down
