@@ -2,7 +2,7 @@ class AddSettingsUpdatedOn < ActiveRecord::Migration
   def self.up
     add_column :settings, :updated_on, :timestamp
     # set updated_on
-    Setting.find(:all).each(&:save)
+    Setting.all.each(&:save)
   end
 
   def self.down
