@@ -3,7 +3,8 @@ class CopyRepositoriesLogEncoding < ActiveRecord::Migration
     encoding = Setting.commit_logs_encoding.to_s.strip
     encoding = encoding.blank? ? 'UTF-8' : encoding
     # encoding is NULL by default
-    Repository.update_all(["log_encoding = ?", encoding], "type IN ('Bazaar', 'Cvs', 'Darcs')")
+    Repository.where("type IN ('Bazaar', 'Cvs', 'Darcs')").
+                 update_all(["log_encoding = ?", encoding])
   end
 
   def self.down
