@@ -6,7 +6,7 @@ class RemoveIssueStatusesIsDefault < ActiveRecord::Migration
   def down
     add_column :issue_statuses, :is_default, :boolean, :null => false, :default => false
     # Restores the first status as default
-    default_status_id = IssueStatus.order("position").pluck(:id).first
+    default_status_id = IssueStatus.order(:position).pluck(:id).first
     IssueStatus.where(:id => default_status_id).update_all(:is_default => true)
   end
 end
