@@ -3,7 +3,7 @@ class ExampleController < ApplicationController
   unloadable
 
   layout 'base'
-  before_filter :find_project, :authorize
+  before_action :find_project, :authorize
   menu_item :sample_plugin
 
   def say_hello
