@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@ module Redmine
           self.customizable_options = options
           has_many :custom_values, lambda {includes(:custom_field).order("#{CustomField.table_name}.position")},
                                    :as => :customized,
+                                   :inverse_of => :customized,
                                    :dependent => :delete_all,
                                    :validate => false
 
@@ -41,7 +42,6 @@ module Redmine
       module InstanceMethods
         def self.included(base)
           base.extend ClassMethods
-          base.send :alias_method_chain, :reload, :custom_fields
         end
 
         def available_custom_fields
@@ -69,16 +69,7 @@ module Redmine
           custom_field_values.each do |custom_field_value|
             key = custom_field_value.custom_field_id.to_s
             if values.has_key?(key)
-              value = values[key]
-              if value.is_a?(Array)
-                value = value.reject(&:blank?).map(&:to_s).uniq
-                if value.empty?
-                  value << ''
-                end
-              else
-                value = value.to_s
-              end
-              custom_field_value.value = value
+              custom_field_value.value = values[key]
             end
           end
           @custom_field_values_changed = true
@@ -94,11 +85,11 @@ module Redmine
               if values.empty?
                 values << custom_values.build(:customized => self, :custom_field => field)
               end
-              x.value = values.map(&:value)
+              x.instance_variable_set("@value", values.map(&:value))
             else
               cv = custom_values.detect { |v| v.custom_field == field }
               cv ||= custom_values.build(:customized => self, :custom_field => field)
-              x.value = cv.value
+              x.instance_variable_set("@value", cv.value)
             end
             x.value_was = x.value.dup if x.value
             x
@@ -164,10 +155,10 @@ module Redmine
           @custom_field_values_changed = true
         end
 
-        def reload_with_custom_fields(*args)
+        def reload(*args)
           @custom_field_values = nil
           @custom_field_values_changed = false
-          reload_without_custom_fields(*args)
+          super
         end
 
         module ClassMethods
