@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -45,11 +45,11 @@ module Redmine
 
     def l_hours(hours)
       hours = hours.to_f
-      l((hours < 2.0 ? :label_f_hour : :label_f_hour_plural), :value => ("%.2f" % hours.to_f))
+      l((hours < 2.0 ? :label_f_hour : :label_f_hour_plural), :value => format_hours(hours))
     end
 
     def l_hours_short(hours)
-      l(:label_f_hour_short, :value => ("%.2f" % hours.to_f))
+      l(:label_f_hour_short, :value => format_hours(hours.to_f))
     end
 
     def ll(lang, str, arg=nil)
@@ -82,6 +82,18 @@ module Redmine
       (include_date ? "#{format_date(local)} " : "") + ::I18n.l(local, options)
     end
 
+    def format_hours(hours)
+      return "" if hours.blank?
+
+      if Setting.timespan_format == 'minutes'
+        h = hours.floor
+        m = ((hours - h) * 60).round
+        "%d:%02d" % [ h, m ]
+      else
+        "%.2f" % hours.to_f
+      end
+    end
+
     def day_name(day)
       ::I18n.t('date.day_names')[day % 7]
     end
@@ -118,7 +130,7 @@ module Redmine
     end
 
     def find_language(lang)
-      @@languages_lookup = valid_languages.inject({}) {|k, v| k[v.to_s.downcase] = v; k }
+      @@languages_lookup ||= valid_languages.inject({}) {|k, v| k[v.to_s.downcase] = v; k }
       @@languages_lookup[lang.to_s.downcase]
     end
 
