@@ -2,8 +2,8 @@ module Redmine
   module Info
     class << self
       def app_name; 'Redmine' end
-      def url; 'http://www.redmine.org/' end
-      def help_url; 'http://www.redmine.org/guide' end
+      def url; 'https://www.redmine.org/' end
+      def help_url; 'https://www.redmine.org/guide' end
       def versioned_name; "#{app_name} #{Redmine::VERSION}" end
 
       def environment
