@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -53,6 +53,11 @@ module Redmine
       map
     end
 
+    # returns all full mime types for a given (top level) type
+    def self.by_type(type)
+      MIME_TYPES.keys.select{|m| m.start_with? "#{type}/"}
+    end
+
     # returns mime type for name or nil if unknown
     def self.of(name)
       return nil unless name.present?
