@@ -1,14 +1,13 @@
 /* Redmine - project management software
-   Copyright (C) 2006-2016  Jean-Philippe Lang */
+   Copyright (C) 2006-2017  Jean-Philippe Lang */
 
 var contextMenuObserving;
-var contextMenuUrl;
 
 function contextMenuRightClick(event) {
   var target = $(event.target);
   if (target.is('a')) {return;}
-  var tr = target.parents('tr').first();
-  if (!tr.hasClass('hascontextmenu')) {return;}
+  var tr = target.closest('.hascontextmenu').first();
+  if (tr.length < 1) {return;}
   event.preventDefault();
   if (!contextMenuIsSelected(tr)) {
     contextMenuUnselectAll();
@@ -29,8 +28,8 @@ function contextMenuClick(event) {
   contextMenuHide();
   if (target.is('a') || target.is('img')) { return; }
   if (event.which == 1 || (navigator.appVersion.match(/\bMSIE\b/))) {
-    var tr = target.parents('tr').first();
-    if (tr.length && tr.hasClass('hascontextmenu')) {
+    var tr = target.closest('.hascontextmenu').first();
+    if (tr.length > 0) {
       // a row was clicked, check if the click was on checkbox
       if (target.is('input')) {
         // a checkbox may be clicked
@@ -98,13 +97,17 @@ function contextMenuShow(event) {
   var window_height;
   var max_width;
   var max_height;
+  var url;
 
   $('#context-menu').css('left', (render_x + 'px'));
   $('#context-menu').css('top', (render_y + 'px'));
   $('#context-menu').html('');
 
+  url = $(event.target).parents('form').first().data('cm-url');
+  if (url == null) {alert('no url'); return;}
+
   $.ajax({
-    url: contextMenuUrl,
+    url: url,
     data: $(event.target).parents('form').first().serialize(),
     success: function(data, textStatus, jqXHR) {
       $('#context-menu').html(data);
@@ -208,8 +211,7 @@ function contextMenuClearDocumentSelection() {
   }
 }
 
-function contextMenuInit(url) {
-  contextMenuUrl = url;
+function contextMenuInit() {
   contextMenuCreate();
   contextMenuUnselectAll();
   
@@ -223,7 +225,7 @@ function contextMenuInit(url) {
 function toggleIssuesSelection(el) {
   var checked = $(this).prop('checked');
   var boxes = $(this).parents('table').find('input[name=ids\\[\\]]');
-  boxes.prop('checked', checked).parents('tr').toggleClass('context-menu-selection', checked);
+  boxes.prop('checked', checked).parents('.hascontextmenu').toggleClass('context-menu-selection', checked);
 }
 
 function window_size() {
@@ -243,5 +245,6 @@ function window_size() {
 }
 
 $(document).ready(function(){
+  contextMenuInit();
   $('input[type=checkbox].toggle-selection').on('change', toggleIssuesSelection);
 });
