@@ -10,8 +10,8 @@ jsToolBar.strings['Heading 3'] = 'Titre niveau 3';
 jsToolBar.strings['Highlighted code'] = 'Code colorisé';
 jsToolBar.strings['Unordered list'] = 'Liste à puces';
 jsToolBar.strings['Ordered list'] = 'Liste numérotée';
-jsToolBar.strings['Quote'] = 'Citer';
-jsToolBar.strings['Unquote'] = 'Supprimer citation';
+jsToolBar.strings['Quote'] = 'Indenté';
+jsToolBar.strings['Unquote'] = 'Supprimer indentation';
 jsToolBar.strings['Preformatted text'] = 'Texte préformaté';
 jsToolBar.strings['Wiki link'] = 'Lien vers une page Wiki';
 jsToolBar.strings['Image'] = 'Image';
