@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class AutoCompletesControllerTest < ActionController::TestCase
+class AutoCompletesControllerTest < Redmine::ControllerTest
   fixtures :projects, :issues, :issue_statuses,
            :enumerations, :users, :issue_categories,
            :trackers,
@@ -29,55 +29,73 @@ class AutoCompletesControllerTest < ActionController::TestCase
            :journals, :journal_details
 
   def test_issues_should_not_be_case_sensitive
-    get :issues, :project_id => 'ecookbook', :q => 'ReCiPe'
+    get :issues, :params => {
+        :project_id => 'ecookbook',
+        :q => 'ReCiPe'
+      }
     assert_response :success
-    assert_not_nil assigns(:issues)
-    assert assigns(:issues).detect {|issue| issue.subject.match /recipe/}
+    assert_include "recipe", response.body
   end
 
   def test_issues_should_accept_term_param
-    get :issues, :project_id => 'ecookbook', :term => 'ReCiPe'
+    get :issues, :params => {
+        :project_id => 'ecookbook',
+        :term => 'ReCiPe'
+      }
     assert_response :success
-    assert_not_nil assigns(:issues)
-    assert assigns(:issues).detect {|issue| issue.subject.match /recipe/}
+    assert_include "recipe", response.body
   end
 
   def test_issues_should_return_issue_with_given_id
-    get :issues, :project_id => 'subproject1', :q => '13'
+    get :issues, :params => {
+        :project_id => 'subproject1',
+        :q => '13'
+      }
     assert_response :success
-    assert_not_nil assigns(:issues)
-    assert assigns(:issues).include?(Issue.find(13))
+    assert_include "Bug #13", response.body
   end
 
   def test_issues_should_return_issue_with_given_id_preceded_with_hash
-    get :issues, :project_id => 'subproject1', :q => '#13'
+    get :issues, :params => {
+        :project_id => 'subproject1',
+        :q => '#13'
+      }
     assert_response :success
-    assert_not_nil assigns(:issues)
-    assert assigns(:issues).include?(Issue.find(13))
+    assert_include "Bug #13", response.body
   end
 
   def test_auto_complete_with_scope_all_should_search_other_projects
-    get :issues, :project_id => 'ecookbook', :q => '13', :scope => 'all'
+    get :issues, :params => {
+        :project_id => 'ecookbook',
+        :q => '13',
+        :scope => 'all'
+      }
     assert_response :success
-    assert_not_nil assigns(:issues)
-    assert assigns(:issues).include?(Issue.find(13))
+    assert_include "Bug #13", response.body
   end
 
   def test_auto_complete_without_project_should_search_all_projects
-    get :issues, :q => '13'
+    get :issues, :params => {
+        :q => '13'
+      }
     assert_response :success
-    assert_not_nil assigns(:issues)
-    assert assigns(:issues).include?(Issue.find(13))
+    assert_include "Bug #13", response.body
   end
 
   def test_auto_complete_without_scope_all_should_not_search_other_projects
-    get :issues, :project_id => 'ecookbook', :q => '13'
+    get :issues, :params => {
+        :project_id => 'ecookbook',
+        :q => '13'
+      }
     assert_response :success
-    assert_equal [], assigns(:issues)
+    assert_not_include "Bug #13", response.body
   end
 
   def test_issues_should_return_json
-    get :issues, :project_id => 'subproject1', :q => '13'
+    get :issues, :params => {
+        :project_id => 'subproject1',
+        :q => '13'
+      }
     assert_response :success
     json = ActiveSupport::JSON.decode(response.body)
     assert_kind_of Array, json
@@ -87,4 +105,37 @@ class AutoCompletesControllerTest < ActionController::TestCase
     assert_equal 13, issue['value']
     assert_equal 'Bug #13: Subproject issue two', issue['label']
   end
+
+  def test_auto_complete_with_status_o_should_return_open_issues_only
+    get :issues, :params => {
+        :project_id => 'ecookbook',
+        :q => 'issue',
+        :status => 'o'
+      }
+    assert_response :success
+    assert_include "Issue due today", response.body
+    assert_not_include "closed", response.body
+  end
+
+  def test_auto_complete_with_status_c_should_return_closed_issues_only
+    get :issues, :params => {
+        :project_id => 'ecookbook',
+        :q => 'issue',
+        :status => 'c'
+      }
+    assert_response :success
+    assert_include "closed", response.body
+    assert_not_include "Issue due today", response.body
+  end
+
+  def test_auto_complete_with_issue_id_should_not_return_that_issue
+    get :issues, :params => {
+        :project_id => 'ecookbook',
+        :q => 'issue',
+        :issue_id => '12'
+      }
+    assert_response :success
+    assert_include "issue", response.body
+    assert_not_include "Bug #12: Closed issue on a locked version", response.body
+  end
 end
