@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class ContextMenusControllerTest < ActionController::TestCase
+class ContextMenusControllerTest < Redmine::ControllerTest
   fixtures :projects,
            :trackers,
            :projects_trackers,
@@ -35,9 +35,10 @@ class ContextMenusControllerTest < ActionController::TestCase
 
   def test_context_menu_one_issue
     @request.session[:user_id] = 2
-    get :issues, :ids => [1]
+    get :issues, :params => {
+        :ids => [1]
+      }
     assert_response :success
-    assert_template 'context_menus/issues'
 
     assert_select 'a.icon-edit[href=?]', '/issues/1/edit', :text => 'Edit'
     assert_select 'a.icon-copy[href=?]', '/projects/ecookbook/issues/1/copy', :text => 'Copy'
@@ -57,22 +58,23 @@ class ContextMenusControllerTest < ActionController::TestCase
 
   def test_context_menu_one_issue_by_anonymous
     with_settings :default_language => 'en' do
-      get :issues, :ids => [1]
+      get :issues, :params => {
+          :ids => [1]
+        }
       assert_response :success
-      assert_template 'context_menus/issues'
+
       assert_select 'a.icon-del.disabled[href="#"]', :text => 'Delete'
     end
   end
 
   def test_context_menu_multiple_issues_of_same_project
     @request.session[:user_id] = 2
-    get :issues, :ids => [1, 2]
+    get :issues, :params => {
+        :ids => [1, 2]
+      }
     assert_response :success
-    assert_template 'context_menus/issues'
-    assert_not_nil assigns(:issues)
-    assert_equal [1, 2], assigns(:issues).map(&:id).sort
 
-    ids = assigns(:issues).map(&:id).sort.map {|i| "ids%5B%5D=#{i}"}.join('&')
+    ids = [1, 2].map {|i| "ids%5B%5D=#{i}"}.join('&')
 
     assert_select 'a.icon-edit[href=?]', "/issues/bulk_edit?#{ids}", :text => 'Edit'
     assert_select 'a.icon-copy[href=?]', "/issues/bulk_edit?copy=1&#{ids}", :text => 'Copy'
@@ -85,13 +87,12 @@ class ContextMenusControllerTest < ActionController::TestCase
 
   def test_context_menu_multiple_issues_of_different_projects
     @request.session[:user_id] = 2
-    get :issues, :ids => [1, 2, 6]
+    get :issues, :params => {
+        :ids => [1, 2, 6]
+      }
     assert_response :success
-    assert_template 'context_menus/issues'
-    assert_not_nil assigns(:issues)
-    assert_equal [1, 2, 6], assigns(:issues).map(&:id).sort
 
-    ids = assigns(:issues).map(&:id).sort.map {|i| "ids%5B%5D=#{i}"}.join('&')
+    ids = [1, 2, 6].map {|i| "ids%5B%5D=#{i}"}.join('&')
 
     assert_select 'a.icon-edit[href=?]', "/issues/bulk_edit?#{ids}", :text => 'Edit'
     assert_select 'a.icon-del[href=?]', "/issues?#{ids}", :text => 'Delete'
@@ -105,7 +106,9 @@ class ContextMenusControllerTest < ActionController::TestCase
     field = IssueCustomField.create!(:name => 'List', :field_format => 'list',
       :possible_values => ['Foo', 'Bar'], :is_for_all => true, :tracker_ids => [1, 2, 3])
     @request.session[:user_id] = 2
-    get :issues, :ids => [1]
+    get :issues, :params => {
+        :ids => [1]
+      }
 
     assert_select "li.cf_#{field.id}" do
       assert_select 'a[href="#"]', :text => 'List'
@@ -121,7 +124,9 @@ class ContextMenusControllerTest < ActionController::TestCase
     field = IssueCustomField.create!(:name => 'List', :is_required => true, :field_format => 'list',
       :possible_values => ['Foo', 'Bar'], :is_for_all => true, :tracker_ids => [1, 2, 3])
     @request.session[:user_id] = 2
-    get :issues, :ids => [1, 2]
+    get :issues, :params => {
+        :ids => [1, 2]
+      }
 
     assert_select "li.cf_#{field.id}" do
       assert_select 'a[href="#"]', :text => 'List'
@@ -139,7 +144,9 @@ class ContextMenusControllerTest < ActionController::TestCase
     issue.custom_field_values = {field.id => 'Bar'}
     issue.save!
     @request.session[:user_id] = 2
-    get :issues, :ids => [1]
+    get :issues, :params => {
+        :ids => [1]
+      }
 
     assert_select "li.cf_#{field.id}" do
       assert_select 'a[href="#"]', :text => 'List'
@@ -154,7 +161,9 @@ class ContextMenusControllerTest < ActionController::TestCase
     field = IssueCustomField.create!(:name => 'Bool', :field_format => 'bool',
       :is_for_all => true, :tracker_ids => [1, 2, 3])
     @request.session[:user_id] = 2
-    get :issues, :ids => [1]
+    get :issues, :params => {
+        :ids => [1]
+      }
 
     assert_select "li.cf_#{field.id}" do
       assert_select 'a[href="#"]', :text => 'Bool'
@@ -171,7 +180,9 @@ class ContextMenusControllerTest < ActionController::TestCase
     field = IssueCustomField.create!(:name => 'User', :field_format => 'user',
       :is_for_all => true, :tracker_ids => [1, 2, 3])
     @request.session[:user_id] = 2
-    get :issues, :ids => [1]
+    get :issues, :params => {
+        :ids => [1]
+      }
 
     assert_select "li.cf_#{field.id}" do
       assert_select 'a[href="#"]', :text => 'User'
@@ -186,7 +197,9 @@ class ContextMenusControllerTest < ActionController::TestCase
   def test_context_menu_should_include_version_custom_fields
     field = IssueCustomField.create!(:name => 'Version', :field_format => 'version', :is_for_all => true, :tracker_ids => [1, 2, 3])
     @request.session[:user_id] = 2
-    get :issues, :ids => [1]
+    get :issues, :params => {
+        :ids => [1]
+      }
 
     assert_select "li.cf_#{field.id}" do
       assert_select 'a[href="#"]', :text => 'Version'
@@ -204,7 +217,9 @@ class ContextMenusControllerTest < ActionController::TestCase
     issue = Issue.generate!(:project_id => 1, :tracker_id => 1)
 
     @request.session[:user_id] = 2
-    get :issues, :ids => [issue.id]
+    get :issues, :params => {
+        :ids => [issue.id]
+      }
 
     assert_select "li.cf_#{enabled_cf.id}"
     assert_select "li.cf_#{disabled_cf.id}", 0
@@ -212,9 +227,10 @@ class ContextMenusControllerTest < ActionController::TestCase
 
   def test_context_menu_by_assignable_user_should_include_assigned_to_me_link
     @request.session[:user_id] = 2
-    get :issues, :ids => [1]
+    get :issues, :params => {
+        :ids => [1]
+      }
     assert_response :success
-    assert_template 'context_menus/issues'
 
     assert_select 'a[href=?]', '/issues/bulk_update?ids%5B%5D=1&issue%5Bassigned_to_id%5D=2', :text => / me /
   end
@@ -223,16 +239,18 @@ class ContextMenusControllerTest < ActionController::TestCase
     @request.session[:user_id] = 2
     version = Version.create!(:name => 'Shared', :sharing => 'system', :project_id => 1)
 
-    get :issues, :ids => [1, 4]
+    get :issues, :params => {
+        :ids => [1, 4]
+      }
     assert_response :success
-    assert_template 'context_menus/issues'
 
-    assert_include version, assigns(:versions)
     assert_select 'a', :text => 'eCookbook - Shared'
   end
 
   def test_context_menu_with_issue_that_is_not_visible_should_fail
-    get :issues, :ids => [1, 4] # issue 4 is not visible
+    get :issues, :params => {
+        :ids => [1, 4] # issue 4 is not visible
+      }
     assert_response 302
   end
 
@@ -243,18 +261,20 @@ class ContextMenusControllerTest < ActionController::TestCase
 
   def test_time_entries_context_menu
     @request.session[:user_id] = 2
-    get :time_entries, :ids => [1, 2]
+    get :time_entries, :params => {
+        :ids => [1, 2]
+      }
     assert_response :success
-    assert_template 'context_menus/time_entries'
 
     assert_select 'a:not(.disabled)', :text => 'Edit'
   end
 
   def test_context_menu_for_one_time_entry
     @request.session[:user_id] = 2
-    get :time_entries, :ids => [1]
+    get :time_entries, :params => {
+        :ids => [1]
+      }
     assert_response :success
-    assert_template 'context_menus/time_entries'
 
     assert_select 'a:not(.disabled)', :text => 'Edit'
   end
@@ -263,8 +283,11 @@ class ContextMenusControllerTest < ActionController::TestCase
     field = TimeEntryCustomField.generate!(:name => "Field", :field_format => "list", :possible_values => ["foo", "bar"])
 
     @request.session[:user_id] = 2
-    get :time_entries, :ids => [1, 2]
+    get :time_entries, :params => {
+        :ids => [1, 2]
+      }
     assert_response :success
+
     assert_select "li.cf_#{field.id}" do
       assert_select 'a[href="#"]', :text => "Field"
       assert_select 'ul' do
@@ -282,9 +305,11 @@ class ContextMenusControllerTest < ActionController::TestCase
     Role.find_by_name('Manager').add_permission! :edit_own_time_entries
     ids = (0..1).map {TimeEntry.generate!(:user => User.find(2)).id}
 
-    get :time_entries, :ids => ids
+    get :time_entries, :params => {
+        :ids => ids
+      }
     assert_response :success
-    assert_template 'context_menus/time_entries'
+
     assert_select 'a:not(.disabled)', :text => 'Edit'
   end
 
@@ -292,9 +317,11 @@ class ContextMenusControllerTest < ActionController::TestCase
     @request.session[:user_id] = 2
     Role.find_by_name('Manager').remove_permission! :edit_time_entries
     
-    get :time_entries, :ids => [1, 2]
+    get :time_entries, :params => {
+        :ids => [1, 2]
+      }
     assert_response :success
-    assert_template 'context_menus/time_entries'
+
     assert_select 'a.disabled', :text => 'Edit'
   end
 end
