@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class GanttsControllerTest < ActionController::TestCase
+class GanttsControllerTest < Redmine::ControllerTest
   fixtures :projects, :trackers, :issue_statuses, :issues,
            :enumerations, :users, :issue_categories,
            :projects_trackers,
@@ -30,10 +30,11 @@ class GanttsControllerTest < ActionController::TestCase
   def test_gantt_should_work
     i2 = Issue.find(2)
     i2.update_attribute(:due_date, 1.month.from_now)
-    get :show, :project_id => 1
+    get :show, :params => {
+        :project_id => 1
+      }
     assert_response :success
-    assert_template 'gantts/show'
-    assert_not_nil assigns(:gantt)
+
     # Issue with start and due dates
     i = Issue.find(1)
     assert_not_nil i.due_date
@@ -44,47 +45,49 @@ class GanttsControllerTest < ActionController::TestCase
   end
 
   def test_gantt_at_minimal_zoom
-    get :show, :project_id => 1, :zoom => 1
+    get :show, :params => {
+        :project_id => 1,
+        :zoom => 1
+      }
     assert_response :success
-    assert_equal 1, assigns(:gantt).zoom
+    assert_select 'input[type=hidden][name=zoom][value=?]', '1'
   end
 
   def test_gantt_at_maximal_zoom
-    get :show, :project_id => 1, :zoom => 4
+    get :show, :params => {
+        :project_id => 1,
+        :zoom => 4
+      }
     assert_response :success
-    assert_equal 4, assigns(:gantt).zoom
+    assert_select 'input[type=hidden][name=zoom][value=?]', '4'
   end
 
   def test_gantt_should_work_without_issue_due_dates
     Issue.update_all("due_date = NULL")
-    get :show, :project_id => 1
+    get :show, :params => {
+        :project_id => 1
+      }
     assert_response :success
-    assert_template 'gantts/show'
-    assert_not_nil assigns(:gantt)
   end
 
   def test_gantt_should_work_without_issue_and_version_due_dates
     Issue.update_all("due_date = NULL")
     Version.update_all("effective_date = NULL")
-    get :show, :project_id => 1
+    get :show, :params => {
+        :project_id => 1
+      }
     assert_response :success
-    assert_template 'gantts/show'
-    assert_not_nil assigns(:gantt)
   end
 
   def test_gantt_should_work_cross_project
     get :show
     assert_response :success
-    assert_template 'gantts/show'
-    assert_not_nil assigns(:gantt)
-    assert_not_nil assigns(:gantt).query
-    assert_nil assigns(:gantt).project
   end
 
   def test_gantt_should_not_disclose_private_projects
     get :show
     assert_response :success
-    assert_template 'gantts/show'
+
     assert_select 'a', :text => /eCookbook/
     # Root private project
     assert_select 'a', :text => /OnlineStore/, :count => 0
@@ -101,32 +104,35 @@ class GanttsControllerTest < ActionController::TestCase
     get :show
     assert_response :success
 
-    relations = assigns(:gantt).relations
-    assert_kind_of Hash, relations
-    assert relations.present?
     assert_select 'div.task_todo[id=?][data-rels*=?]', "task-todo-issue-#{issue1.id}", issue2.id.to_s
     assert_select 'div.task_todo[id=?]:not([data-rels])', "task-todo-issue-#{issue2.id}"
   end
 
   def test_gantt_should_export_to_pdf
-    get :show, :project_id => 1, :format => 'pdf'
+    get :show, :params => {
+        :project_id => 1,
+        :format => 'pdf'
+      }
     assert_response :success
     assert_equal 'application/pdf', @response.content_type
     assert @response.body.starts_with?('%PDF')
-    assert_not_nil assigns(:gantt)
   end
 
   def test_gantt_should_export_to_pdf_cross_project
-    get :show, :format => 'pdf'
+    get :show, :params => {
+        :format => 'pdf'
+      }
     assert_response :success
     assert_equal 'application/pdf', @response.content_type
     assert @response.body.starts_with?('%PDF')
-    assert_not_nil assigns(:gantt)
   end
 
   if Object.const_defined?(:Magick)
     def test_gantt_should_export_to_png
-      get :show, :project_id => 1, :format => 'png'
+      get :show, :params => {
+          :project_id => 1,
+          :format => 'png'
+        }
       assert_response :success
       assert_equal 'image/png', @response.content_type
     end
