@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class GroupsControllerTest < ActionController::TestCase
+class GroupsControllerTest < Redmine::ControllerTest
   fixtures :projects, :users, :members, :member_roles, :roles, :groups_users
 
   def setup
@@ -27,7 +27,7 @@ class GroupsControllerTest < ActionController::TestCase
   def test_index
     get :index
     assert_response :success
-    assert_template 'index'
+    assert_select 'table.groups'
   end
 
   def test_index_should_show_user_count
@@ -36,27 +36,44 @@ class GroupsControllerTest < ActionController::TestCase
     assert_select 'tr#group-11 td.user_count', :text => '1'
   end
 
+  def test_index_with_name_filter
+    Group.generate!(:name => "Clients")
+
+    get :index, :params => {
+        :name => "cli"
+      }
+    assert_response :success
+    assert_select 'table.groups tbody tr', 1
+    assert_select 'table.groups tbody td.name', :text => 'Clients'
+  end
+
   def test_show
-    get :show, :id => 10
+    get :show, :params => {
+        :id => 10
+      }
     assert_response :success
-    assert_template 'show'
   end
 
   def test_show_invalid_should_return_404
-    get :show, :id => 99
+    get :show, :params => {
+        :id => 99
+      }
     assert_response 404
   end
 
   def test_new
     get :new
     assert_response :success
-    assert_template 'new'
     assert_select 'input[name=?]', 'group[name]'
   end
 
   def test_create
     assert_difference 'Group.count' do
-      post :create, :group => {:name => 'New group'}
+      post :create, :params => {
+          :group => {
+            :name => 'New group'
+          }
+        }
     end
     assert_redirected_to '/groups'
     group = Group.order('id DESC').first
@@ -66,7 +83,12 @@ class GroupsControllerTest < ActionController::TestCase
 
   def test_create_and_continue
     assert_difference 'Group.count' do
-      post :create, :group => {:name => 'New group'}, :continue => 'Create and continue'
+      post :create, :params => {
+          :group => {
+            :name => 'New group'
+          },  
+          :continue => 'Create and continue'
+        }
     end
     assert_redirected_to '/groups/new'
     group = Group.order('id DESC').first
@@ -75,16 +97,21 @@ class GroupsControllerTest < ActionController::TestCase
 
   def test_create_with_failure
     assert_no_difference 'Group.count' do
-      post :create, :group => {:name => ''}
+      post :create, :params => {
+          :group => {
+            :name => ''
+          }
+        }
     end
     assert_response :success
-    assert_template 'new'
+    assert_select_error /Name cannot be blank/i
   end
 
   def test_edit
-    get :edit, :id => 10
+    get :edit, :params => {
+        :id => 10
+      }
     assert_response :success
-    assert_template 'edit'
 
     assert_select 'div#tab-content-users'
     assert_select 'div#tab-content-memberships' do
@@ -94,48 +121,71 @@ class GroupsControllerTest < ActionController::TestCase
 
   def test_update
     new_name = 'New name'
-    put :update, :id => 10, :group => {:name => new_name}
+    put :update, :params => {
+        :id => 10,
+        :group => {
+          :name => new_name
+        }
+      }
     assert_redirected_to '/groups'
     group = Group.find(10)
     assert_equal new_name, group.name
   end
 
   def test_update_with_failure
-    put :update, :id => 10, :group => {:name => ''}
+    put :update, :params => {
+        :id => 10,
+        :group => {
+          :name => ''
+        }
+      }
     assert_response :success
-    assert_template 'edit'
+    assert_select_error /Name cannot be blank/i
   end
 
   def test_destroy
     assert_difference 'Group.count', -1 do
-      post :destroy, :id => 10
+      post :destroy, :params => {
+          :id => 10
+        }
     end
     assert_redirected_to '/groups'
   end
 
   def test_new_users
-    get :new_users, :id => 10
+    get :new_users, :params => {
+        :id => 10
+      }
     assert_response :success
-    assert_template 'new_users'
+    assert_select 'input[name=?]', 'user_search'
   end
 
   def test_xhr_new_users
-    xhr :get, :new_users, :id => 10
+    get :new_users, :params => {
+        :id => 10
+      },
+      :xhr => true
     assert_response :success
     assert_equal 'text/javascript', response.content_type
   end
 
   def test_add_users
     assert_difference 'Group.find(10).users.count', 2 do
-      post :add_users, :id => 10, :user_ids => ['2', '3']
+      post :add_users, :params => {
+          :id => 10,
+          :user_ids => ['2', '3']
+        }
     end
   end
 
   def test_xhr_add_users
     assert_difference 'Group.find(10).users.count', 2 do
-      xhr :post, :add_users, :id => 10, :user_ids => ['2', '3']
+      post :add_users, :params => {
+          :id => 10,
+          :user_ids => ['2', '3']
+        },
+        :xhr => true
       assert_response :success
-      assert_template 'add_users'
       assert_equal 'text/javascript', response.content_type
     end
     assert_match /John Smith/, response.body
@@ -143,21 +193,32 @@ class GroupsControllerTest < ActionController::TestCase
 
   def test_remove_user
     assert_difference 'Group.find(10).users.count', -1 do
-      delete :remove_user, :id => 10, :user_id => '8'
+      delete :remove_user, :params => {
+          :id => 10,
+          :user_id => '8'
+        }
     end
   end
 
   def test_xhr_remove_user
     assert_difference 'Group.find(10).users.count', -1 do
-      xhr :delete, :remove_user, :id => 10, :user_id => '8'
+      delete :remove_user, :params => {
+          :id => 10,
+          :user_id => '8'
+        },
+        :xhr => true
       assert_response :success
-      assert_template 'remove_user'
       assert_equal 'text/javascript', response.content_type
     end
   end
 
   def test_autocomplete_for_user
-    xhr :get, :autocomplete_for_user, :id => 10, :q => 'smi', :format => 'js'
+    get :autocomplete_for_user, :params => {
+        :id => 10,
+        :q => 'smi',
+        :format => 'js'
+      },
+      :xhr => true
     assert_response :success
     assert_include 'John Smith', response.body
   end
