@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class IssueCategoriesControllerTest < ActionController::TestCase
+class IssueCategoriesControllerTest < Redmine::ControllerTest
   fixtures :projects, :users, :members, :member_roles, :roles, :enabled_modules, :issue_categories,
            :issues
 
@@ -28,25 +28,33 @@ class IssueCategoriesControllerTest < ActionController::TestCase
 
   def test_new
     @request.session[:user_id] = 2 # manager
-    get :new, :project_id => '1'
+    get :new, :params => {
+        :project_id => '1'
+      }
     assert_response :success
-    assert_template 'new'
     assert_select 'input[name=?]', 'issue_category[name]'
   end
 
   def test_new_from_issue_form
     @request.session[:user_id] = 2 # manager
-    xhr :get, :new, :project_id => '1'
+    get :new, :params => {
+        :project_id => '1'
+      },
+      :xhr => true
 
     assert_response :success
-    assert_template 'new'
     assert_equal 'text/javascript', response.content_type
   end
 
   def test_create
     @request.session[:user_id] = 2 # manager
     assert_difference 'IssueCategory.count' do
-      post :create, :project_id => '1', :issue_category => {:name => 'New category'}
+      post :create, :params => {
+          :project_id => '1',
+          :issue_category => {
+            :name => 'New category'
+          }
+        }
     end
     assert_redirected_to '/projects/ecookbook/settings/categories'
     category = IssueCategory.find_by_name('New category')
@@ -56,78 +64,118 @@ class IssueCategoriesControllerTest < ActionController::TestCase
 
   def test_create_failure
     @request.session[:user_id] = 2
-    post :create, :project_id => '1', :issue_category => {:name => ''}
+    post :create, :params => {
+        :project_id => '1',
+        :issue_category => {
+          :name => ''
+        }
+      }
     assert_response :success
-    assert_template 'new'
+    assert_select_error /Name cannot be blank/i
   end
 
   def test_create_from_issue_form
     @request.session[:user_id] = 2 # manager
     assert_difference 'IssueCategory.count' do
-      xhr :post, :create, :project_id => '1', :issue_category => {:name => 'New category'}
+      post :create, :params => {
+          :project_id => '1',
+          :issue_category => {
+            :name => 'New category'
+          }
+        },
+        :xhr => true
     end
     category = IssueCategory.order('id DESC').first
     assert_equal 'New category', category.name
 
     assert_response :success
-    assert_template 'create'
     assert_equal 'text/javascript', response.content_type
   end
 
   def test_create_from_issue_form_with_failure
     @request.session[:user_id] = 2 # manager
     assert_no_difference 'IssueCategory.count' do
-      xhr :post, :create, :project_id => '1', :issue_category => {:name => ''}
+      post :create, :params => {
+          :project_id => '1',
+          :issue_category => {
+            :name => ''
+          }
+        },
+        :xhr => true
     end
 
     assert_response :success
-    assert_template 'new'
     assert_equal 'text/javascript', response.content_type
+    assert_include 'Name cannot be blank', response.body
   end
 
   def test_edit
     @request.session[:user_id] = 2
-    get :edit, :id => 2
+    get :edit, :params => {
+        :id => 2
+      }
     assert_response :success
-    assert_template 'edit'
     assert_select 'input[name=?][value=?]', 'issue_category[name]', 'Recipes'
   end
 
   def test_update
     assert_no_difference 'IssueCategory.count' do
-      put :update, :id => 2, :issue_category => { :name => 'Testing' }
+      put :update, :params => {
+          :id => 2,
+          :issue_category => {
+            :name => 'Testing' 
+          }
+        }
     end
     assert_redirected_to '/projects/ecookbook/settings/categories'
     assert_equal 'Testing', IssueCategory.find(2).name
   end
 
   def test_update_failure
-    put :update, :id => 2, :issue_category => { :name => '' }
+    put :update, :params => {
+        :id => 2,
+        :issue_category => {
+          :name => '' 
+        }
+      }
     assert_response :success
-    assert_template 'edit'
+    assert_select_error /Name cannot be blank/i
   end
 
   def test_update_not_found
-    put :update, :id => 97, :issue_category => { :name => 'Testing' }
+    put :update, :params => {
+        :id => 97,
+        :issue_category => {
+          :name => 'Testing' 
+        }
+      }
     assert_response 404
   end
 
   def test_destroy_category_not_in_use
-    delete :destroy, :id => 2
+    delete :destroy, :params => {
+        :id => 2
+      }
     assert_redirected_to '/projects/ecookbook/settings/categories'
     assert_nil IssueCategory.find_by_id(2)
   end
 
   def test_destroy_category_in_use
-    delete :destroy, :id => 1
+    delete :destroy, :params => {
+        :id => 1
+      }
     assert_response :success
-    assert_template 'destroy'
     assert_not_nil IssueCategory.find_by_id(1)
+    assert_select 'select[name=?]', 'reassign_to_id'
   end
 
   def test_destroy_category_in_use_with_reassignment
     issue = Issue.where(:category_id => 1).first
-    delete :destroy, :id => 1, :todo => 'reassign', :reassign_to_id => 2
+    delete :destroy, :params => {
+        :id => 1,
+        :todo => 'reassign',
+        :reassign_to_id => 2
+      }
     assert_redirected_to '/projects/ecookbook/settings/categories'
     assert_nil IssueCategory.find_by_id(1)
     # check that the issue was reassign
@@ -136,7 +184,10 @@ class IssueCategoriesControllerTest < ActionController::TestCase
 
   def test_destroy_category_in_use_without_reassignment
     issue = Issue.where(:category_id => 1).first
-    delete :destroy, :id => 1, :todo => 'nullify'
+    delete :destroy, :params => {
+        :id => 1,
+        :todo => 'nullify'
+      }
     assert_redirected_to '/projects/ecookbook/settings/categories'
     assert_nil IssueCategory.find_by_id(1)
     # check that the issue category was nullified
