@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
 require File.expand_path('../../test_helper', __FILE__)
 require 'issues_controller'
 
-class IssuesControllerTransactionTest < ActionController::TestCase
+class IssuesControllerTransactionTest < Redmine::ControllerTest
   tests IssuesController
   fixtures :projects,
            :users,
@@ -56,19 +56,24 @@ class IssuesControllerTransactionTest < ActionController::TestCase
 
     assert_no_difference 'Journal.count' do
       assert_no_difference 'TimeEntry.count' do
-        put :update,
-              :id => issue.id,
-              :issue => {
-                :fixed_version_id => 4,
-                :notes => 'My notes',
-                :lock_version => (issue.lock_version - 1)
-              },
-              :time_entry => { :hours => '2.5', :comments => '', :activity_id => TimeEntryActivity.first.id }
+        put :update, :params => {
+            :id => issue.id,
+            :issue => {
+              :fixed_version_id => 4,
+              :notes => 'My notes',
+              :lock_version => (issue.lock_version - 1)
+              
+            },  
+            :time_entry => {
+              :hours => '2.5',
+              :comments => '',
+              :activity_id => TimeEntryActivity.first.id 
+            }
+          }
       end
     end
 
     assert_response :success
-    assert_template 'edit'
 
     assert_select 'div.conflict'
     assert_select 'input[name=?][value=?]', 'conflict_resolution', 'overwrite'
@@ -87,21 +92,30 @@ class IssuesControllerTransactionTest < ActionController::TestCase
     assert_no_difference 'Journal.count' do
       assert_no_difference 'TimeEntry.count' do
         assert_difference 'Attachment.count' do
-          put :update,
-                :id => issue.id,
-                :issue => {
-                  :fixed_version_id => 4,
-                  :notes => 'My notes',
-                  :lock_version => (issue.lock_version - 1)
-                },
-                :attachments => {'1' => {'file' => uploaded_test_file('testfile.txt', 'text/plain')}},
-                :time_entry => { :hours => '2.5', :comments => '', :activity_id => TimeEntryActivity.first.id }
+          put :update, :params => {
+              :id => issue.id,
+              :issue => {
+                :fixed_version_id => 4,
+                :notes => 'My notes',
+                :lock_version => (issue.lock_version - 1)
+                
+              },  
+              :attachments => {
+                '1' => {
+                'file' => uploaded_test_file('testfile.txt', 'text/plain')}    
+              },  
+              :time_entry => {
+                :hours => '2.5',
+                :comments => '',
+                :activity_id => TimeEntryActivity.first.id 
+              }
+            }
         end
       end
     end
 
     assert_response :success
-    assert_template 'edit'
+
     attachment = Attachment.order('id DESC').first
     assert_select 'input[name=?][value=?]', 'attachments[p0][token]', attachment.token
     assert_select 'input[name=?][value=?]', 'attachments[p0][filename]', 'testfile.txt'
@@ -111,12 +125,16 @@ class IssuesControllerTransactionTest < ActionController::TestCase
     issue = Issue.find(2)
     @request.session[:user_id] = 2
 
-    put :update, :id => issue.id,
-          :issue => {
-            :fixed_version_id => 4,
-            :notes => '',
-            :lock_version => (issue.lock_version - 1)
-          }
+    put :update, :params => {
+        :id => issue.id,
+        :issue => {
+          :fixed_version_id => 4,
+          :notes => '',
+          :lock_version => (issue.lock_version - 1)
+          
+        }
+      }
+    assert_response :success
 
     assert_select 'div.conflict'
     assert_select 'input[name=conflict_resolution][value=overwrite]'
@@ -127,34 +145,38 @@ class IssuesControllerTransactionTest < ActionController::TestCase
   def test_update_stale_issue_should_show_conflicting_journals
     @request.session[:user_id] = 2
 
-    put :update, :id => 1,
-          :issue => {
-            :fixed_version_id => 4,
-            :notes => '',
-            :lock_version => 2
-          },
-          :last_journal_id => 1
-
-    assert_not_nil assigns(:conflict_journals)
-    assert_equal 1, assigns(:conflict_journals).size
-    assert_equal 2, assigns(:conflict_journals).first.id
+    put :update, :params => {
+        :id => 1,
+        :issue => {
+          :fixed_version_id => 4,
+          :notes => '',
+          :lock_version => 2
+          
+        },  
+        :last_journal_id => 1
+      }
+    assert_response :success
 
+    assert_select '.conflict-journal', 1
     assert_select 'div.conflict', :text => /Some notes with Redmine links/
   end
 
   def test_update_stale_issue_without_previous_journal_should_show_all_journals
     @request.session[:user_id] = 2
 
-    put :update, :id => 1,
-          :issue => {
-            :fixed_version_id => 4,
-            :notes => '',
-            :lock_version => 2
-          },
-          :last_journal_id => ''
+    put :update, :params => {
+        :id => 1,
+        :issue => {
+          :fixed_version_id => 4,
+          :notes => '',
+          :lock_version => 2
+          
+        },  
+        :last_journal_id => ''
+      }
+    assert_response :success
 
-    assert_not_nil assigns(:conflict_journals)
-    assert_equal 2, assigns(:conflict_journals).size
+    assert_select '.conflict-journal', 2
     assert_select 'div.conflict', :text => /Some notes with Redmine links/
     assert_select 'div.conflict', :text => /Journal notes/
   end
@@ -163,25 +185,44 @@ class IssuesControllerTransactionTest < ActionController::TestCase
     journal = Journal.create!(:journalized => Issue.find(1), :notes => 'Privates notes', :private_notes => true, :user_id => 1)
 
     @request.session[:user_id] = 2
-    put :update, :id => 1, :issue => {:fixed_version_id => 4, :lock_version => 2}, :last_journal_id => ''
-    assert_include journal, assigns(:conflict_journals)
+    put :update, :params => {
+        :id => 1,
+        :issue => {
+          :fixed_version_id => 4,
+          :lock_version => 2
+        },  
+        :last_journal_id => ''
+      }
+    assert_response :success
+    assert_select '.conflict-journal', :text => /Privates notes/
 
     Role.find(1).remove_permission! :view_private_notes
-    put :update, :id => 1, :issue => {:fixed_version_id => 4, :lock_version => 2}, :last_journal_id => ''
-    assert_not_include journal, assigns(:conflict_journals)
+    put :update, :params => {
+        :id => 1,
+        :issue => {
+          :fixed_version_id => 4,
+          :lock_version => 2
+        },  
+        :last_journal_id => ''
+      }
+    assert_response :success
+    assert_select '.conflict-journal', :text => /Privates notes/, :count => 0
   end
 
   def test_update_stale_issue_with_overwrite_conflict_resolution_should_update
     @request.session[:user_id] = 2
 
     assert_difference 'Journal.count' do
-      put :update, :id => 1,
-            :issue => {
-              :fixed_version_id => 4,
-              :notes => 'overwrite_conflict_resolution',
-              :lock_version => 2
-            },
-            :conflict_resolution => 'overwrite'
+      put :update, :params => {
+          :id => 1,
+          :issue => {
+            :fixed_version_id => 4,
+            :notes => 'overwrite_conflict_resolution',
+            :lock_version => 2
+            
+          },  
+          :conflict_resolution => 'overwrite'
+        }
     end
 
     assert_response 302
@@ -196,13 +237,16 @@ class IssuesControllerTransactionTest < ActionController::TestCase
     @request.session[:user_id] = 2
 
     assert_difference 'Journal.count' do
-      put :update, :id => 1,
-            :issue => {
-              :fixed_version_id => 4,
-              :notes => 'add_notes_conflict_resolution',
-              :lock_version => 2
-            },
-            :conflict_resolution => 'add_notes'
+      put :update, :params => {
+          :id => 1,
+          :issue => {
+            :fixed_version_id => 4,
+            :notes => 'add_notes_conflict_resolution',
+            :lock_version => 2
+            
+          },  
+          :conflict_resolution => 'add_notes'
+        }
     end
 
     assert_response 302
@@ -218,14 +262,17 @@ class IssuesControllerTransactionTest < ActionController::TestCase
     @request.session[:user_id] = 2
 
     journal = new_record(Journal) do
-      put :update, :id => 1,
-            :issue => {
-              :fixed_version_id => 4,
-              :notes => 'add_privates_notes_conflict_resolution',
-              :private_notes => '1',
-              :lock_version => 2
-            },
-            :conflict_resolution => 'add_notes'
+      put :update, :params => {
+          :id => 1,
+          :issue => {
+            :fixed_version_id => 4,
+            :notes => 'add_privates_notes_conflict_resolution',
+            :private_notes => '1',
+            :lock_version => 2
+            
+          },  
+          :conflict_resolution => 'add_notes'
+        }
     end
 
     assert_response 302
@@ -238,13 +285,16 @@ class IssuesControllerTransactionTest < ActionController::TestCase
     @request.session[:user_id] = 2
 
     assert_no_difference 'Journal.count' do
-      put :update, :id => 1,
-            :issue => {
-              :fixed_version_id => 4,
-              :notes => 'add_notes_conflict_resolution',
-              :lock_version => 2
-            },
-            :conflict_resolution => 'cancel'
+      put :update, :params => {
+          :id => 1,
+          :issue => {
+            :fixed_version_id => 4,
+            :notes => 'add_notes_conflict_resolution',
+            :lock_version => 2
+            
+          },  
+          :conflict_resolution => 'cancel'
+        }
     end
 
     assert_redirected_to '/issues/1'
@@ -256,14 +306,21 @@ class IssuesControllerTransactionTest < ActionController::TestCase
     @request.session[:user_id] = 2
 
     assert_no_difference('TimeEntry.count') do
-      put :update,
-           :id => 1,
-           :issue => { :subject => '' },
-           :time_entry => { :hours => '2.5', :comments => 'should not be added', :activity_id => TimeEntryActivity.first.id }
+      put :update, :params => {
+          :id => 1,
+          :issue => {
+            :subject => '' 
+          },  
+          :time_entry => {
+            :hours => '2.5',
+            :comments => 'should not be added',
+            :activity_id => TimeEntryActivity.first.id 
+          }
+        }
       assert_response :success
     end
 
-    assert_select 'input[name=?][value=?]', 'time_entry[hours]', '2.5'
+    assert_select 'input[name=?][value=?]', 'time_entry[hours]', '2.50'
     assert_select 'input[name=?][value=?]', 'time_entry[comments]', 'should not be added'
     assert_select 'select[name=?]', 'time_entry[activity_id]' do
       assert_select 'option[value=?][selected=selected]', TimeEntryActivity.first.id.to_s
