@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class JournalsControllerTest < ActionController::TestCase
+class JournalsControllerTest < Redmine::ControllerTest
   fixtures :projects, :users, :members, :member_roles, :roles, :issues, :journals, :journal_details, :enabled_modules,
     :trackers, :issue_statuses, :enumerations, :custom_fields, :custom_values, :custom_fields_projects, :projects_trackers
 
@@ -26,14 +26,18 @@ class JournalsControllerTest < ActionController::TestCase
   end
 
   def test_index
-    get :index, :project_id => 1
+    get :index, :params => {
+        :project_id => 1
+      }
     assert_response :success
-    assert_not_nil assigns(:journals)
     assert_equal 'application/atom+xml', @response.content_type
   end
 
   def test_index_with_invalid_query_id
-    get :index, :project_id => 1, :query_id => 999
+    get :index, :params => {
+        :project_id => 1,
+        :query_id => 999
+      }
     assert_response 404
   end
 
@@ -41,18 +45,23 @@ class JournalsControllerTest < ActionController::TestCase
     journal = Journal.create!(:journalized => Issue.find(2), :notes => 'Privates notes', :private_notes => true, :user_id => 1)
     @request.session[:user_id] = 2
 
-    get :index, :project_id => 1
+    get :index, :params => {
+        :project_id => 1
+      }
     assert_response :success
-    assert_include journal, assigns(:journals)
+    assert_select 'entry>id', :text => "http://test.host/issues/2?journal_id=#{journal.id}"
 
     Role.find(1).remove_permission! :view_private_notes
-    get :index, :project_id => 1
+    get :index, :params => {
+        :project_id => 1
+      }
     assert_response :success
-    assert_not_include journal, assigns(:journals)
+    assert_select 'entry>id', :text => "http://test.host/issues/2?journal_id=#{journal.id}", :count => 0
   end
 
   def test_index_should_show_visible_custom_fields_only
     Issue.destroy_all
+    Journal.delete_all
     field_attributes = {:field_format => 'string', :is_for_all => true, :is_filter => true, :trackers => Tracker.all}
     @fields = []
     @fields << (@field1 = IssueCustomField.create!(field_attributes.merge(:name => 'Field 1', :visible => true)))
@@ -65,8 +74,8 @@ class JournalsControllerTest < ActionController::TestCase
       :custom_field_values => {@field1.id => 'Value0', @field2.id => 'Value1', @field3.id => 'Value2'}
     )
     @issue.init_journal(User.find(1))
-    @issue.update_attribute :custom_field_values, {@field1.id => 'NewValue0', @field2.id => 'NewValue1', @field3.id => 'NewValue2'}
-
+    @issue.custom_field_values = {@field1.id => 'NewValue0', @field2.id => 'NewValue1', @field3.id => 'NewValue2'}
+    @issue.save!
 
     user_with_role_on_other_project = User.generate!
     User.add_to_project(user_with_role_on_other_project, Project.find(2), Role.find(3))
@@ -79,7 +88,10 @@ class JournalsControllerTest < ActionController::TestCase
     }
 
     users_to_test.each do |user, visible_fields|
-      get :index, :format => 'atom', :key => user.rss_key
+      get :index, :params => {
+          :format => 'atom',
+          :key => user.rss_key
+        }
       @fields.each_with_index do |field, i|
         if visible_fields.include?(field)
           assert_select "content[type=html]", { :text => /NewValue#{i}/, :count => 1 }, "User #{user.id} was not able to view #{field.name} in API"
@@ -92,9 +104,11 @@ class JournalsControllerTest < ActionController::TestCase
   end
 
   def test_diff_for_description_change
-    get :diff, :id => 3, :detail_id => 4
+    get :diff, :params => {
+        :id => 3,
+        :detail_id => 4
+      }
     assert_response :success
-    assert_template 'diff'
 
     assert_select 'span.diff_out', :text => /removed/
     assert_select 'span.diff_in', :text => /added/
@@ -106,9 +120,11 @@ class JournalsControllerTest < ActionController::TestCase
     detail = JournalDetail.create!(:journal => journal, :property => 'cf', :prop_key => field.id,
       :old_value => 'Foo', :value => 'Bar')
 
-    get :diff, :id => journal.id, :detail_id => detail.id
+    get :diff, :params => {
+        :id => journal.id,
+        :detail_id => detail.id
+      }
     assert_response :success
-    assert_template 'diff'
 
     assert_select 'span.diff_out', :text => /Foo/
     assert_select 'span.diff_in', :text => /Bar/
@@ -120,14 +136,18 @@ class JournalsControllerTest < ActionController::TestCase
     detail = JournalDetail.create!(:journal => journal, :property => 'cf', :prop_key => field.id,
       :old_value => 'Foo', :value => 'Bar')
 
-    get :diff, :id => journal.id, :detail_id => detail.id
+    get :diff, :params => {
+        :id => journal.id,
+        :detail_id => detail.id
+      }
     assert_response 302
   end
 
   def test_diff_should_default_to_description_diff
-    get :diff, :id => 3
+    get :diff, :params => {
+        :id => 3
+      }
     assert_response :success
-    assert_template 'diff'
 
     assert_select 'span.diff_out', :text => /removed/
     assert_select 'span.diff_in', :text => /added/
@@ -135,24 +155,33 @@ class JournalsControllerTest < ActionController::TestCase
 
   def test_reply_to_issue
     @request.session[:user_id] = 2
-    xhr :get, :new, :id => 6
+    get :new, :params => {
+        :id => 6
+      },
+      :xhr => true
     assert_response :success
-    assert_template 'new'
+
     assert_equal 'text/javascript', response.content_type
     assert_include '> This is an issue', response.body
   end
 
   def test_reply_to_issue_without_permission
     @request.session[:user_id] = 7
-    xhr :get, :new, :id => 6
+    get :new, :params => {
+        :id => 6
+      },
+      :xhr => true
     assert_response 403
   end
 
   def test_reply_to_note
     @request.session[:user_id] = 2
-    xhr :get, :new, :id => 6, :journal_id => 4
+    get :new, :params => {
+        :id => 6,
+        :journal_id => 4
+      },
+      :xhr => true
     assert_response :success
-    assert_template 'new'
     assert_equal 'text/javascript', response.content_type
     assert_include '> A comment with a private version', response.body
   end
@@ -161,22 +190,31 @@ class JournalsControllerTest < ActionController::TestCase
     journal = Journal.create!(:journalized => Issue.find(2), :notes => 'Privates notes', :private_notes => true)
     @request.session[:user_id] = 2
 
-    xhr :get, :new, :id => 2, :journal_id => journal.id
+    get :new, :params => {
+        :id => 2,
+        :journal_id => journal.id
+      },
+      :xhr => true
     assert_response :success
-    assert_template 'new'
     assert_equal 'text/javascript', response.content_type
     assert_include '> Privates notes', response.body
 
     Role.find(1).remove_permission! :view_private_notes
-    xhr :get, :new, :id => 2, :journal_id => journal.id
+    get :new, :params => {
+        :id => 2,
+        :journal_id => journal.id
+      },
+      :xhr => true
     assert_response 404
   end
 
   def test_edit_xhr
     @request.session[:user_id] = 1
-    xhr :get, :edit, :id => 2
+    get :edit, :params => {
+        :id => 2
+      },
+      :xhr => true
     assert_response :success
-    assert_template 'edit'
     assert_equal 'text/javascript', response.content_type
     assert_include 'textarea', response.body
   end
@@ -186,33 +224,98 @@ class JournalsControllerTest < ActionController::TestCase
     @request.session[:user_id] = 2
     Role.find(1).add_permission! :edit_issue_notes
 
-    xhr :get, :edit, :id => journal.id
+    get :edit, :params => {
+        :id => journal.id
+      },
+      :xhr => true
     assert_response :success
-    assert_template 'edit'
     assert_equal 'text/javascript', response.content_type
     assert_include 'textarea', response.body
 
     Role.find(1).remove_permission! :view_private_notes
-    xhr :get, :edit, :id => journal.id
+    get :edit, :params => {
+        :id => journal.id
+      },
+      :xhr => true
     assert_response 404
   end
 
   def test_update_xhr
     @request.session[:user_id] = 1
-    xhr :post, :update, :id => 2, :notes => 'Updated notes'
+    post :update, :params => {
+        :id => 2,
+        :journal => {
+          :notes => 'Updated notes'
+        }
+      },
+      :xhr => true
     assert_response :success
-    assert_template 'update'
     assert_equal 'text/javascript', response.content_type
     assert_equal 'Updated notes', Journal.find(2).notes
     assert_include 'journal-2-notes', response.body
   end
 
+  def test_update_xhr_with_private_notes_checked
+    @request.session[:user_id] = 1
+    post :update, :params => {
+        :id => 2,
+        :journal => {
+          :private_notes => '1'
+        }
+      },
+      :xhr => true
+    assert_response :success
+    assert_equal 'text/javascript', response.content_type
+    assert_equal true, Journal.find(2).private_notes
+    assert_include 'change-2', response.body
+    assert_include 'journal-2-private_notes', response.body
+  end
+
+  def test_update_xhr_with_private_notes_unchecked
+    Journal.find(2).update_attributes(:private_notes => true)
+    @request.session[:user_id] = 1
+    post :update, :params => {
+        :id => 2,
+        :journal => {
+          :private_notes => '0'
+        }
+      },
+      :xhr => true
+    assert_response :success
+    assert_equal 'text/javascript', response.content_type
+    assert_equal false, Journal.find(2).private_notes
+    assert_include 'change-2', response.body
+    assert_include 'journal-2-private_notes', response.body
+  end
+
+  def test_update_xhr_without_set_private_notes_permission_should_ignore_private_notes
+    @request.session[:user_id] = 2
+    Role.find(1).add_permission! :edit_issue_notes
+    Role.find(1).add_permission! :view_private_notes
+    Role.find(1).remove_permission! :set_notes_private
+
+    post :update, :params => {
+        :id => 2,
+        :journal => {
+          :private_notes => '1'
+        }
+      },
+      :xhr => true
+    assert_response :success
+    assert_equal false, Journal.find(2).private_notes
+  end
+
   def test_update_xhr_with_empty_notes_should_delete_the_journal
     @request.session[:user_id] = 1
     assert_difference 'Journal.count', -1 do
-      xhr :post, :update, :id => 2, :notes => ''
+      post :update, :params => {
+          :id => 2,
+          :journal => {
+            :notes => ''
+          }
+        },
+        :xhr => true
       assert_response :success
-      assert_template 'update'
       assert_equal 'text/javascript', response.content_type
     end
     assert_nil Journal.find_by_id(2)
