@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class MailHandlerControllerTest < ActionController::TestCase
+class MailHandlerControllerTest < Redmine::ControllerTest
   fixtures :users, :email_addresses, :projects, :enabled_modules, :roles, :members, :member_roles, :issues, :issue_statuses,
            :trackers, :projects_trackers, :enumerations
 
@@ -33,7 +33,10 @@ class MailHandlerControllerTest < ActionController::TestCase
     Setting.mail_handler_api_key = 'secret'
 
     assert_difference 'Issue.count' do
-      post :index, :key => 'secret', :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+      post :index, :params => {
+          :key => 'secret',
+          :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+        }
     end
     assert_response 201
   end
@@ -44,9 +47,13 @@ class MailHandlerControllerTest < ActionController::TestCase
     Setting.mail_handler_api_key = 'secret'
 
     assert_difference 'Issue.count' do
-      post :index, :key => 'secret',
-        :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml')),
-        :issue => {:is_private => '1'}
+      post :index, :params => {
+          :key => 'secret',
+          :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml')),
+          :issue => {
+            :is_private => '1'
+          }
+        }
     end
     assert_response 201
     issue = Issue.order(:id => :desc).first
@@ -60,7 +67,10 @@ class MailHandlerControllerTest < ActionController::TestCase
     Setting.mail_handler_api_key = 'secret'
 
     assert_no_difference 'Issue.count' do
-      post :index, :key => 'secret', :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+      post :index, :params => {
+          :key => 'secret',
+          :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+        }
     end
     assert_response 422
   end
@@ -71,9 +81,13 @@ class MailHandlerControllerTest < ActionController::TestCase
     Setting.mail_handler_api_key = 'secret'
 
     assert_no_difference 'Issue.count' do
-      post :index, :key => 'secret', :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+      post :index, :params => {
+          :key => 'secret',
+          :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+        }
     end
     assert_response 403
+    assert_include 'Access denied', response.body
   end
 
   def test_should_not_allow_with_wrong_key
@@ -81,16 +95,22 @@ class MailHandlerControllerTest < ActionController::TestCase
     Setting.mail_handler_api_key = 'secret'
 
     assert_no_difference 'Issue.count' do
-      post :index, :key => 'wrong', :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+      post :index, :params => {
+          :key => 'wrong',
+          :email => IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+        }
     end
     assert_response 403
+    assert_include 'Access denied', response.body
   end
 
   def test_new
     Setting.mail_handler_api_enabled = 1
     Setting.mail_handler_api_key = 'secret'
 
-    get :new, :key => 'secret'
+    get :new, :params => {
+        :key => 'secret'
+      }
     assert_response :success
   end
 end
