@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class PreviewsControllerTest < ActionController::TestCase
+class PreviewsControllerTest < Redmine::ControllerTest
   fixtures :projects, :trackers, :issue_statuses, :issues,
            :enumerations, :users, :issue_categories,
            :projects_trackers,
@@ -30,66 +30,115 @@ class PreviewsControllerTest < ActionController::TestCase
 
   def test_preview_new_issue
     @request.session[:user_id] = 2
-    post :issue, :project_id => '1', :issue => {:description => 'Foo'}
+    post :issue, :params => {
+        :project_id => '1',
+        :issue => {
+          :description => 'Foo'
+        }
+      }
     assert_response :success
-    assert_template 'previews/issue'
-    assert_not_nil assigns(:description)
+    assert_select 'fieldset' do
+      assert_select 'legend', :text => 'Description'
+      assert_select 'p', :text => 'Foo'
+    end
   end
 
-  def test_preview_issue_notes
+  def test_preview_issue_notes_with_no_change_to_description
     @request.session[:user_id] = 2
-    post :issue, :project_id => '1', :id => 1,
-         :issue => {:description => Issue.find(1).description, :notes => 'Foo'}
+    post :issue, :params => {
+        :project_id => '1',
+        :id => 1,
+        :issue => {
+          :description => Issue.find(1).description,
+          :notes => 'Foo'
+        }
+      }
     assert_response :success
-    assert_template 'previews/issue'
-    assert_not_nil assigns(:notes)
+    assert_select 'legend', :text => 'Description', :count => 0
+    assert_select 'legend', :text => 'Notes'
+  end
+
+  def test_preview_issue_notes_with_change_to_description
+    @request.session[:user_id] = 2
+    post :issue, :params => {
+        :project_id => '1',
+        :id => 1,
+        :issue => {
+          :description => 'Changed description',
+          :notes => 'Foo'
+        }
+      }
+    assert_response :success
+    assert_select 'legend', :text => 'Description'
+    assert_select 'legend', :text => 'Notes'
   end
 
   def test_preview_journal_notes_for_update
     @request.session[:user_id] = 2
-    post :issue, :project_id => '1', :id => 1, :notes => 'Foo'
+    post :issue, :params => {
+        :project_id => '1',
+        :id => 1,
+        :journal => {
+          :notes => 'Foo'
+        }
+      }
     assert_response :success
-    assert_template 'previews/issue'
-    assert_not_nil assigns(:notes)
+    assert_select 'legend', :text => 'Notes'
     assert_select 'p', :text => 'Foo'
   end
 
   def test_preview_issue_notes_should_support_links_to_existing_attachments
     Attachment.generate!(:container => Issue.find(1), :filename => 'foo.bar')
     @request.session[:user_id] = 2
-    post :issue, :project_id => '1', :id => 1, :notes => 'attachment:foo.bar'
+    post :issue, :params => {
+        :project_id => '1',
+        :id => 1,
+        :issue => {
+          :notes => 'attachment:foo.bar'
+        }
+      }
     assert_response :success
     assert_select 'a.attachment', :text => 'foo.bar'
   end
 
   def test_preview_issue_with_project_changed
     @request.session[:user_id] = 2
-    post :issue, :project_id => '1', :id => 1, :issue => {:notes => 'notes', :project_id => 2}
+    post :issue, :params => {
+        :project_id => '1',
+        :id => 1,
+        :issue => {
+          :notes => 'notes',
+          :project_id => 2
+        }
+      }
     assert_response :success
-    assert_not_nil assigns(:issue)
-    assert_not_nil assigns(:notes)
+    assert_select 'legend', :text => 'Notes'
   end
 
   def test_preview_new_news
-    get :news, :project_id => 1,
-                  :news => {:title => '',
-                            :description => 'News description',
-                            :summary => ''}
+    get :news, :params => {
+        :project_id => 1,
+        :news => {
+          :title => '',
+          :description => 'News description',
+          :summary => ''
+        }
+      }
     assert_response :success
-    assert_template 'common/_preview'
     assert_select 'fieldset.preview', :text => /News description/
   end
 
-  def test_existing_new_news
-    get :news, :project_id => 1, :id => 2,
-                  :news => {:title => '',
-                            :description => 'News description',
-                            :summary => ''}
+  def test_preview_existing_news
+    get :news, :params => {
+        :project_id => 1,
+        :id => 2,
+        :news => {
+          :title => '',
+          :description => 'News description',
+          :summary => ''
+        }
+      }
     assert_response :success
-    assert_template 'common/_preview'
-    assert_equal News.find(2), assigns(:previewed)
-    assert_not_nil assigns(:attachments)
-
     assert_select 'fieldset.preview', :text => /News description/
   end
 end
