@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class ProjectEnumerationsControllerTest < ActionController::TestCase
+class ProjectEnumerationsControllerTest < Redmine::ControllerTest
   fixtures :projects, :trackers, :issue_statuses, :issues,
            :enumerations, :users, :issue_categories,
            :projects_trackers,
@@ -40,12 +40,15 @@ class ProjectEnumerationsControllerTest < ActionController::TestCase
     @request.session[:user_id] = 2 # manager
     billable_field = TimeEntryActivityCustomField.find_by_name("Billable")
 
-    put :update, :project_id => 1, :enumerations => {
-      "9"=> {"parent_id"=>"9", "custom_field_values"=>{"7" => "1"}, "active"=>"0"}, # Design, De-activate
-      "10"=> {"parent_id"=>"10", "custom_field_values"=>{"7"=>"0"}, "active"=>"1"}, # Development, Change custom value
-      "14"=>{"parent_id"=>"14", "custom_field_values"=>{"7"=>"1"}, "active"=>"1"}, # Inactive Activity, Activate with custom value
-      "11"=>{"parent_id"=>"11", "custom_field_values"=>{"7"=>"1"}, "active"=>"1"} # QA, no changes
-    }
+    put :update, :params => {
+        :project_id => 1,
+        :enumerations => {
+          "9"=> {"parent_id"=>"9", "custom_field_values"=> {"7" => "1"}, "active"=>"0"}, # Design, De-activate
+          "10"=> {"parent_id"=>"10", "custom_field_values"=>{"7"=>"0"}, "active"=>"1"}, # Development, Change custom value
+          "14"=>{"parent_id"=>"14", "custom_field_values"=>{"7"=>"1"}, "active"=>"1"}, # Inactive Activity, Activate with custom value
+          "11"=>{"parent_id"=>"11", "custom_field_values"=>{"7"=>"1"}, "active"=>"1"} # QA, no changes
+        }
+      }
 
     assert_response :redirect
     assert_redirected_to '/projects/ecookbook/settings/activities'
@@ -105,10 +108,13 @@ class ProjectEnumerationsControllerTest < ActionController::TestCase
     assert project_activity_two.save
 
 
-    put :update, :project_id => 1, :enumerations => {
-      project_activity.id => {"custom_field_values"=>{"7" => "1"}, "active"=>"0"}, # De-activate
-      project_activity_two.id => {"custom_field_values"=>{"7" => "1"}, "active"=>"0"} # De-activate
-    }
+    put :update, :params => {
+        :project_id => 1,
+        :enumerations => {
+          project_activity.id => {"custom_field_values"=> {"7" => "1"}, "active"=>"0"}, # De-activate
+          project_activity_two.id => {"custom_field_values"=>{"7" => "1"}, "active"=>"0"} # De-activate
+        }
+      }
 
     assert_response :redirect
     assert_redirected_to '/projects/ecookbook/settings/activities'
@@ -132,9 +138,15 @@ class ProjectEnumerationsControllerTest < ActionController::TestCase
     assert_equal 3, TimeEntry.where(:activity_id => 9, :project_id => 1).count
 
     @request.session[:user_id] = 2 # manager
-    put :update, :project_id => 1, :enumerations => {
-      "9"=> {"parent_id"=>"9", "custom_field_values"=>{"7" => "1"}, "active"=>"0"} # Design, De-activate
-    }
+    put :update, :params => {
+        :project_id => 1,
+        :enumerations => {
+          "9"=> {
+            "parent_id"=>"9", "custom_field_values"=> {
+            "7" => "1"}, "active"=>"0"} # Design, De-activate      
+            
+          }
+      }
     assert_response :redirect
 
     # No more TimeEntries using the system activity
@@ -160,12 +172,15 @@ class ProjectEnumerationsControllerTest < ActionController::TestCase
     assert_equal 1, TimeEntry.where(:activity_id => 10, :project_id => 1).count
 
     @request.session[:user_id] = 2 # manager
-    put :update, :project_id => 1, :enumerations => {
-      # Design
-      "9"=> {"parent_id"=>"9", "custom_field_values"=>{"7" => "1"}, "active"=>"0"},
-      # Development, Change custom value
-      "10"=> {"parent_id"=>"10", "custom_field_values"=>{"7"=>"0"}, "active"=>"1"}
-    }
+    put :update, :params => {
+        :project_id => 1,
+        :enumerations => {
+          # Design
+          "9"=> {"parent_id"=>"9", "custom_field_values"=>{"7" => "1"}, "active"=>"0"},
+          # Development, Change custom value
+          "10"=> {"parent_id"=>"10", "custom_field_values"=>{"7"=>"0"}, "active"=>"1"}
+        }
+      }
     assert_response :redirect
 
     # TimeEntries shouldn't have been reassigned on the failed record
@@ -195,7 +210,9 @@ class ProjectEnumerationsControllerTest < ActionController::TestCase
                                                  })
     assert project_activity_two.save
 
-    delete :destroy, :project_id => 1
+    delete :destroy, :params => {
+        :project_id => 1
+      }
     assert_response :redirect
     assert_redirected_to '/projects/ecookbook/settings/activities'
 
@@ -216,7 +233,9 @@ class ProjectEnumerationsControllerTest < ActionController::TestCase
              update_all("activity_id = '#{project_activity.id}'")
     assert_equal 3, TimeEntry.where(:activity_id => project_activity.id,
                                     :project_id => 1).count
-    delete :destroy, :project_id => 1
+    delete :destroy, :params => {
+        :project_id => 1
+      }
     assert_response :redirect
     assert_redirected_to '/projects/ecookbook/settings/activities'
 
