@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class ReportsControllerTest < ActionController::TestCase
+class ReportsControllerTest < Redmine::ControllerTest
   fixtures :projects, :trackers, :issue_statuses, :issues,
            :enumerations, :users, :issue_categories,
            :projects_trackers,
@@ -28,29 +28,19 @@ class ReportsControllerTest < ActionController::TestCase
            :versions
 
   def test_get_issue_report
-    get :issue_report, :id => 1
-
+    get :issue_report, :params => {
+        :id => 1
+      }
     assert_response :success
-    assert_template 'issue_report'
-
-    [:issues_by_tracker, :issues_by_version, :issues_by_category, :issues_by_assigned_to,
-     :issues_by_author, :issues_by_subproject, :issues_by_priority].each do |ivar|
-      assert_not_nil assigns(ivar)
-    end
-
-    assert_equal IssuePriority.all.reverse, assigns(:priorities)
   end
 
   def test_get_issue_report_details
     %w(tracker version priority category assigned_to author subproject).each do |detail|
-      get :issue_report_details, :id => 1, :detail => detail
-
+      get :issue_report_details, :params => {
+          :id => 1,
+          :detail => detail
+        }
       assert_response :success
-      assert_template 'issue_report_details'
-      assert_not_nil assigns(:field)
-      assert_not_nil assigns(:rows)
-      assert_not_nil assigns(:data)
-      assert_not_nil assigns(:report_title)
     end
   end
 
@@ -61,7 +51,10 @@ class ReportsControllerTest < ActionController::TestCase
     Issue.generate!(:tracker_id => 1, :status_id => 5)
     Issue.generate!(:tracker_id => 2)
 
-    get :issue_report_details, :id => 1, :detail => 'tracker'
+    get :issue_report_details, :params => {
+        :id => 1,
+        :detail => 'tracker'
+      }
     assert_select 'table.list tbody :nth-child(1)' do
       assert_select 'td', :text => 'Bug'
       assert_select ':nth-child(2)', :text => '2' # status:1
@@ -72,14 +65,11 @@ class ReportsControllerTest < ActionController::TestCase
     end
   end
 
-  def test_get_issue_report_details_by_priority
-    get :issue_report_details, :id => 1, :detail => 'priority'
-    assert_equal IssuePriority.all.reverse, assigns(:rows)
-  end
-
   def test_get_issue_report_details_with_an_invalid_detail
-    get :issue_report_details, :id => 1, :detail => 'invalid'
-
-    assert_redirected_to '/projects/ecookbook/issues/report'
+    get :issue_report_details, :params => {
+        :id => 1,
+        :detail => 'invalid'
+      }
+    assert_response 404
   end
 end
