@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class RepositoriesGitControllerTest < ActionController::TestCase
+class RepositoriesGitControllerTest < Redmine::ControllerTest
   tests RepositoriesController
 
   fixtures :projects, :users, :email_addresses, :roles, :members, :member_roles,
@@ -54,28 +54,34 @@ class RepositoriesGitControllerTest < ActionController::TestCase
   def test_create_and_update
     @request.session[:user_id] = 1
     assert_difference 'Repository.count' do
-      post :create, :project_id => 'subproject1',
-                    :repository_scm => 'Git',
-                    :repository => {
-                       :url => '/test',
-                       :is_default => '0',
-                       :identifier => 'test-create',
-                       :extra_report_last_commit => '1',
-                     }
+      post :create, :params => {
+          :project_id => 'subproject1',
+          :repository_scm => 'Git',
+          :repository => {
+            :url => '/test',
+            :is_default => '0',
+            :identifier => 'test-create',
+            :report_last_commit => '1',
+                                 
+          }
+        }
     end
     assert_response 302
     repository = Repository.order('id DESC').first
     assert_kind_of Repository::Git, repository
     assert_equal '/test', repository.url
-    assert_equal true, repository.extra_report_last_commit
+    assert_equal true, repository.report_last_commit
 
-    put :update, :id => repository.id,
-                 :repository => {
-                     :extra_report_last_commit => '0'
-                 }
+    put :update, :params => {
+        :id => repository.id,
+        :repository => {
+          :report_last_commit => '0'
+          
+        }
+      }
     assert_response 302
     repo2 = Repository.find(repository.id)
-    assert_equal false, repo2.extra_report_last_commit
+    assert_equal false, repo2.report_last_commit
   end
 
   if File.directory?(REPOSITORY_PATH)
@@ -92,11 +98,14 @@ class RepositoriesGitControllerTest < ActionController::TestCase
     def test_get_new
       @request.session[:user_id] = 1
       @project.repository.destroy
-      get :new, :project_id => 'subproject1', :repository_scm => 'Git'
+      get :new, :params => {
+          :project_id => 'subproject1',
+          :repository_scm => 'Git'
+        }
       assert_response :success
-      assert_template 'new'
-      assert_kind_of Repository::Git, assigns(:repository)
-      assert assigns(:repository).new_record?
+      assert_select 'select[name=?]', 'repository_scm' do
+        assert_select 'option[value=?][selected=selected]', 'Git'
+      end
     end
 
     def test_browse_root
@@ -105,22 +114,27 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
 
-      get :show, :id => PRJ_ID
+      get :show, :params => {
+          :id => PRJ_ID
+        }
       assert_response :success
-      assert_template 'show'
-      assert_not_nil assigns(:entries)
-      assert_equal 9, assigns(:entries).size
-      assert assigns(:entries).detect {|e| e.name == 'images' && e.kind == 'dir'}
-      assert assigns(:entries).detect {|e| e.name == 'this_is_a_really_long_and_verbose_directory_name' && e.kind == 'dir'}
-      assert assigns(:entries).detect {|e| e.name == 'sources' && e.kind == 'dir'}
-      assert assigns(:entries).detect {|e| e.name == 'README' && e.kind == 'file'}
-      assert assigns(:entries).detect {|e| e.name == 'copied_README' && e.kind == 'file'}
-      assert assigns(:entries).detect {|e| e.name == 'new_file.txt' && e.kind == 'file'}
-      assert assigns(:entries).detect {|e| e.name == 'renamed_test.txt' && e.kind == 'file'}
-      assert assigns(:entries).detect {|e| e.name == 'filemane with spaces.txt' && e.kind == 'file'}
-      assert assigns(:entries).detect {|e| e.name == ' filename with a leading space.txt ' && e.kind == 'file'}
-      assert_not_nil assigns(:changesets)
-      assert assigns(:changesets).size > 0
+
+      assert_select 'table.entries tbody' do
+        assert_select 'tr', 9
+        assert_select 'tr.dir td.filename_no_report a', :text => 'images'
+        assert_select 'tr.dir td.filename_no_report a', :text => 'this_is_a_really_long_and_verbose_directory_name'
+        assert_select 'tr.dir td.filename_no_report a', :text => 'sources'
+        assert_select 'tr.file td.filename_no_report a', :text => 'README'
+        assert_select 'tr.file td.filename_no_report a', :text => 'copied_README'
+        assert_select 'tr.file td.filename_no_report a', :text => 'new_file.txt'
+        assert_select 'tr.file td.filename_no_report a', :text => 'renamed_test.txt'
+        assert_select 'tr.file td.filename_no_report a', :text => 'filemane with spaces.txt'
+        assert_select 'tr.file td.filename_no_report a', :text => 'filename with a leading space.txt'
+      end
+
+      assert_select 'table.changesets tbody' do
+        assert_select 'tr'
+      end
     end
 
     def test_browse_branch
@@ -128,17 +142,23 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @repository.fetch_changesets
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
-      get :show, :id => PRJ_ID, :rev => 'test_branch'
+      get :show, :params => {
+          :id => PRJ_ID,
+          :rev => 'test_branch'
+        }
       assert_response :success
-      assert_template 'show'
-      assert_not_nil assigns(:entries)
-      assert_equal 4, assigns(:entries).size
-      assert assigns(:entries).detect {|e| e.name == 'images' && e.kind == 'dir'}
-      assert assigns(:entries).detect {|e| e.name == 'sources' && e.kind == 'dir'}
-      assert assigns(:entries).detect {|e| e.name == 'README' && e.kind == 'file'}
-      assert assigns(:entries).detect {|e| e.name == 'test.txt' && e.kind == 'file'}
-      assert_not_nil assigns(:changesets)
-      assert assigns(:changesets).size > 0
+
+      assert_select 'table.entries tbody' do
+        assert_select 'tr', 4
+        assert_select 'tr.dir td.filename_no_report a', :text => 'images'
+        assert_select 'tr.dir td.filename_no_report a', :text => 'sources'
+        assert_select 'tr.file td.filename_no_report a', :text => 'README'
+        assert_select 'tr.file td.filename_no_report a', :text => 'test.txt'
+      end
+
+      assert_select 'table.changesets tbody' do
+        assert_select 'tr'
+      end
     end
 
     def test_browse_tag
@@ -150,13 +170,14 @@ class RepositoriesGitControllerTest < ActionController::TestCase
         "tag00.lightweight",
         "tag01.annotated",
        ].each do |t1|
-        get :show, :id => PRJ_ID, :rev => t1
+        get :show, :params => {
+            :id => PRJ_ID,
+            :rev => t1
+          }
         assert_response :success
-        assert_template 'show'
-        assert_not_nil assigns(:entries)
-        assert assigns(:entries).size > 0
-        assert_not_nil assigns(:changesets)
-        assert assigns(:changesets).size > 0
+
+        assert_select 'table.entries tbody tr'
+        assert_select 'table.changesets tbody tr'
       end
     end
 
@@ -165,17 +186,17 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @repository.fetch_changesets
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
-      get :show, :id => PRJ_ID, :path => repository_path_hash(['images'])[:param]
+      get :show, :params => {
+          :id => PRJ_ID,
+          :path => repository_path_hash(['images'])[:param]
+        }
       assert_response :success
-      assert_template 'show'
-      assert_not_nil assigns(:entries)
-      assert_equal ['edit.png'], assigns(:entries).collect(&:name)
-      entry = assigns(:entries).detect {|e| e.name == 'edit.png'}
-      assert_not_nil entry
-      assert_equal 'file', entry.kind
-      assert_equal 'images/edit.png', entry.path
-      assert_not_nil assigns(:changesets)
-      assert assigns(:changesets).size > 0
+
+      assert_select 'table.entries tbody' do
+        assert_select 'tr', 1
+        assert_select 'tr.file td.filename_no_report a', :text => 'edit.png'
+      end
+      assert_select 'table.changesets tbody tr'
     end
 
     def test_browse_at_given_revision
@@ -183,29 +204,34 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @repository.fetch_changesets
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
-      get :show, :id => PRJ_ID, :path => repository_path_hash(['images'])[:param],
+      get :show, :params => {
+          :id => PRJ_ID,
+          :path => repository_path_hash(['images'])[:param],
           :rev => '7234cb2750b63f47bff735edc50a1c0a433c2518'
+        }
       assert_response :success
-      assert_template 'show'
-      assert_not_nil assigns(:entries)
-      assert_equal ['delete.png'], assigns(:entries).collect(&:name)
-      assert_not_nil assigns(:changesets)
-      assert assigns(:changesets).size > 0
+
+      assert_select 'table.entries tbody' do
+        assert_select 'tr', 1
+        assert_select 'tr.file td.filename_no_report a', :text => 'delete.png'
+      end
     end
 
     def test_changes
-      get :changes, :id => PRJ_ID,
+      get :changes, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['images', 'edit.png'])[:param]
+        }
       assert_response :success
-      assert_template 'changes'
       assert_select 'h2', :text => /edit.png/
     end
 
     def test_entry_show
-      get :entry, :id => PRJ_ID,
+      get :entry, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param]
+        }
       assert_response :success
-      assert_template 'entry'
       # Line 11
       assert_select 'tr#L11 td.line-code', :text => /WITHOUT ANY WARRANTY/
     end
@@ -220,11 +246,12 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       else
         with_settings :repositories_encodings => 'UTF-8,ISO-8859-1' do
           ['57ca437c', '57ca437c0acbbcb749821fdf3726a1367056d364'].each do |r1|
-            get :entry, :id => PRJ_ID,
-                :path => repository_path_hash(['latin-1-dir', "test-#{CHAR_1_HEX}.txt"])[:param],
-                :rev => r1
+            get :entry, :params => {
+                :id => PRJ_ID,
+              :path => repository_path_hash(['latin-1-dir', "test-#{CHAR_1_HEX}.txt"])[:param],
+              :rev => r1
+              }
             assert_response :success
-            assert_template 'entry'
             assert_select 'tr#L1 td.line-code', :text => /test-#{CHAR_1_HEX}.txt/
           end
         end
@@ -232,21 +259,26 @@ class RepositoriesGitControllerTest < ActionController::TestCase
     end
 
     def test_entry_download
-      get :entry, :id => PRJ_ID,
+      get :entry, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param],
           :format => 'raw'
+        }
       assert_response :success
       # File content
       assert @response.body.include?('WITHOUT ANY WARRANTY')
     end
 
     def test_directory_entry
-      get :entry, :id => PRJ_ID,
+      get :entry, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources'])[:param]
+        }
       assert_response :success
-      assert_template 'show'
-      assert_not_nil assigns(:entry)
-      assert_equal 'sources', assigns(:entry).name
+      assert_select 'h2 a', :text => 'sources'
+      assert_select 'table.entries tbody'
+      assert_select 'div.contextual > a.icon-download', false
+
     end
 
     def test_diff
@@ -258,12 +290,12 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       assert_equal NUM_REV, @repository.changesets.count
       # Full diff of changeset 2f9c0091
       ['inline', 'sbs'].each do |dt|
-        get :diff,
+        get :diff, :params => {
             :id   => PRJ_ID,
             :rev  => '2f9c0091c754a91af7a9c478e36556b4bde8dcf7',
             :type => dt
+          }
         assert_response :success
-        assert_template 'diff'
         # Line 22 removed
         assert_select 'th.line-num:contains(22) ~ td.diff_out', :text => /def remove/
         assert_select 'h2', :text => /2f9c0091/
@@ -278,13 +310,13 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       with_settings :diff_max_lines_displayed => 1000 do
         # Full diff of changeset 2f9c0091
         ['inline', 'sbs'].each do |dt|
-          get :diff,
+          get :diff, :params => {
               :id   => PRJ_ID,
               :rev  => '2f9c0091c754a91af7a9c478e36556b4bde8dcf7',
               :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param],
               :type => dt
+            }
           assert_response :success
-          assert_template 'diff'
           # Line 22 removed
           assert_select 'th.line-num:contains(22) ~ td.diff_out', :text => /def remove/
           assert_select 'h2', :text => /2f9c0091/
@@ -302,14 +334,20 @@ class RepositoriesGitControllerTest < ActionController::TestCase
         # Truncated diff of changeset 2f9c0091
         with_cache do
           with_settings :default_language => 'en' do
-            get :diff, :id   => PRJ_ID, :type => 'inline',
+            get :diff, :params => {
+                :id   => PRJ_ID,
+                :type => 'inline',
                 :rev  => '2f9c0091c754a91af7a9c478e36556b4bde8dcf7'
+              }
             assert_response :success
             assert @response.body.include?("... This diff was truncated")
           end
           with_settings :default_language => 'fr' do
-            get :diff, :id   => PRJ_ID, :type => 'inline',
+            get :diff, :params => {
+                :id   => PRJ_ID,
+                :type => 'inline',
                 :rev  => '2f9c0091c754a91af7a9c478e36556b4bde8dcf7'
+              }
             assert_response :success
             assert ! @response.body.include?("... This diff was truncated")
             assert @response.body.include?("... Ce diff")
@@ -324,15 +362,13 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
       ['inline', 'sbs'].each do |dt|
-        get :diff,
+        get :diff, :params => {
             :id     => PRJ_ID,
             :rev    => '61b685fbe55ab05b5ac68402d5720c1a6ac973d1',
             :rev_to => '2f9c0091c754a91af7a9c478e36556b4bde8dcf7',
             :type   => dt
+          }
         assert_response :success
-        assert_template 'diff'
-        diff = assigns(:diff)
-        assert_not_nil diff
         assert_select 'h2', :text => /2f9c0091:61b685fb/
         assert_select 'form[action=?]', '/projects/subproject1/repository/revisions/61b685fbe55ab05b5ac68402d5720c1a6ac973d1/diff'
         assert_select 'input#rev_to[type=hidden][name=rev_to][value=?]', '2f9c0091c754a91af7a9c478e36556b4bde8dcf7'
@@ -349,16 +385,14 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       assert repo
       assert_equal false, repo.is_default
       assert_equal 'test-diff-path', repo.identifier
-      get :diff,
+      get :diff, :params => {
           :id     => PRJ_ID,
           :repository_id => 'test-diff-path',
           :rev    => '61b685fbe55ab05b',
           :rev_to => '2f9c0091c754a91a',
           :type   => 'inline'
+        }
       assert_response :success
-      assert_template 'diff'
-      diff = assigns(:diff)
-      assert_not_nil diff
       assert_select 'form[action=?]', '/projects/subproject1/repository/test-diff-path/revisions/61b685fbe55ab05b/diff'
       assert_select 'input#rev_to[type=hidden][name=rev_to][value=?]', '2f9c0091c754a91a'
     end
@@ -370,9 +404,12 @@ class RepositoriesGitControllerTest < ActionController::TestCase
         with_settings :repositories_encodings => 'UTF-8,ISO-8859-1' do
           ['57ca437c', '57ca437c0acbbcb749821fdf3726a1367056d364'].each do |r1|
             ['inline', 'sbs'].each do |dt|
-              get :diff, :id => PRJ_ID, :rev => r1, :type => dt
+              get :diff, :params => {
+                  :id => PRJ_ID,
+                  :rev => r1,
+                  :type => dt
+                }
               assert_response :success
-              assert_template 'diff'
               assert_select 'table' do
                 assert_select 'thead th.filename', :text => /latin-1-dir\/test-#{CHAR_1_HEX}.txt/
                 assert_select 'tbody td.diff_in', :text => /test-#{CHAR_1_HEX}.txt/
@@ -384,9 +421,12 @@ class RepositoriesGitControllerTest < ActionController::TestCase
     end
 
     def test_diff_should_show_filenames
-      get :diff, :id => PRJ_ID, :rev => 'deff712f05a90d96edbd70facc47d944be5897e3', :type => 'inline'
+      get :diff, :params => {
+          :id => PRJ_ID,
+          :rev => 'deff712f05a90d96edbd70facc47d944be5897e3',
+          :type => 'inline'
+        }
       assert_response :success
-      assert_template 'diff'
       # modified file
       assert_select 'th.filename', :text => 'sources/watchers_controller.rb'
       # deleted file
@@ -401,28 +441,29 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       assert_nil user.pref[:diff_type]
 
       @request.session[:user_id] = 1 # admin
-      get :diff,
+      get :diff, :params => {
           :id   => PRJ_ID,
           :rev  => '2f9c0091c754a91af7a9c478e36556b4bde8dcf7'
+        }
       assert_response :success
-      assert_template 'diff'
       user.reload
       assert_equal "inline", user.pref[:diff_type]
-      get :diff,
+      get :diff, :params => {
           :id   => PRJ_ID,
           :rev  => '2f9c0091c754a91af7a9c478e36556b4bde8dcf7',
           :type => 'sbs'
+        }
       assert_response :success
-      assert_template 'diff'
       user.reload
       assert_equal "sbs", user.pref[:diff_type]
     end
 
     def test_annotate
-      get :annotate, :id => PRJ_ID,
+      get :annotate, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param]
+        }
       assert_response :success
-      assert_template 'annotate'
 
       # Line 23, changeset 2f9c0091
       assert_select 'tr' do
@@ -438,35 +479,42 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @repository.fetch_changesets
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
-      get :annotate, :id => PRJ_ID, :rev => 'deff7',
+      get :annotate, :params => {
+          :id => PRJ_ID,
+          :rev => 'deff7',
           :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param]
+        }
       assert_response :success
-      assert_template 'annotate'
       assert_select 'h2', :text => /@ deff712f/
     end
 
     def test_annotate_binary_file
       with_settings :default_language => 'en' do
-        get :annotate, :id => PRJ_ID,
+        get :annotate, :params => {
+            :id => PRJ_ID,
             :path => repository_path_hash(['images', 'edit.png'])[:param]
-        assert_response 500
+          }
+        assert_response :success
         assert_select 'p#errorExplanation', :text => /cannot be annotated/
       end
     end
 
     def test_annotate_error_when_too_big
       with_settings :file_max_size_displayed => 1 do
-        get :annotate, :id => PRJ_ID,
+        get :annotate, :params => {
+            :id => PRJ_ID,
             :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param],
             :rev => 'deff712f'
-        assert_response 500
+          }
+        assert_response :success
         assert_select 'p#errorExplanation', :text => /exceeds the maximum text file size/
 
-        get :annotate, :id => PRJ_ID,
+        get :annotate, :params => {
+            :id => PRJ_ID,
             :path => repository_path_hash(['README'])[:param],
             :rev => '7234cb2'
+          }
         assert_response :success
-        assert_template 'annotate'
       end
     end
 
@@ -480,9 +528,11 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       else
         with_settings :repositories_encodings => 'UTF-8,ISO-8859-1' do
           ['57ca437c', '57ca437c0acbbcb749821fdf3726a1367056d364'].each do |r1|
-            get :annotate, :id => PRJ_ID,
-                :path => repository_path_hash(['latin-1-dir', "test-#{CHAR_1_HEX}.txt"])[:param],
-                :rev => r1
+            get :annotate, :params => {
+                :id => PRJ_ID,
+              :path => repository_path_hash(['latin-1-dir', "test-#{CHAR_1_HEX}.txt"])[:param],
+              :rev => r1
+              }
             assert_select "th.line-num", :text => '1' do
               assert_select "+ td.revision" do
                 assert_select "a", :text => '57ca437c'
@@ -499,9 +549,11 @@ class RepositoriesGitControllerTest < ActionController::TestCase
 
     def test_annotate_latin_1_author
       ['83ca5fd546063a3c7dc2e568ba3355661a9e2b2c', '83ca5fd546063a'].each do |r1|
-        get :annotate, :id => PRJ_ID,
+        get :annotate, :params => {
+            :id => PRJ_ID,
             :path => repository_path_hash([" filename with a leading space.txt "])[:param],
             :rev => r1
+          }
         assert_select "th.line-num", :text => '1' do
           assert_select "+ td.revision" do
             assert_select "a", :text => '83ca5fd5'
@@ -519,9 +571,9 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @repository.fetch_changesets
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
-      get :revisions, :id => PRJ_ID
-      assert_response :success
-      assert_template 'revisions'
+      get :revisions, :params => {
+          :id => PRJ_ID
+        }
       assert_select 'form[method=get][action=?]', '/projects/subproject1/repository/revision'
     end
 
@@ -531,9 +583,11 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
       ['61b685fbe55ab05b5ac68402d5720c1a6ac973d1', '61b685f'].each do |r|
-        get :revision, :id => PRJ_ID, :rev => r
+        get :revision, :params => {
+            :id => PRJ_ID,
+            :rev => r
+          }
         assert_response :success
-        assert_template 'revision'
       end
     end
 
@@ -543,7 +597,10 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
       ['', ' ', nil].each do |r|
-        get :revision, :id => PRJ_ID, :rev => r
+        get :revision, :params => {
+            :id => PRJ_ID,
+            :rev => r
+          }
         assert_response 404
         assert_select_error /was not found/
       end
@@ -557,7 +614,9 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       assert_equal NUM_REV, @repository.changesets.count
 
       assert_difference 'Repository.count', -1 do
-        delete :destroy, :id => @repository.id
+        delete :destroy, :params => {
+            :id => @repository.id
+          }
       end
       assert_response 302
       @project.reload
@@ -577,7 +636,9 @@ class RepositoriesGitControllerTest < ActionController::TestCase
       assert_equal 0, @repository.changesets.count
 
       assert_difference 'Repository.count', -1 do
-        delete :destroy, :id => @repository.id
+        delete :destroy, :params => {
+            :id => @repository.id
+          }
       end
       assert_response 302
       @project.reload
