@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class RepositoriesMercurialControllerTest < ActionController::TestCase
+class RepositoriesMercurialControllerTest < Redmine::ControllerTest
   tests RepositoriesController
 
   fixtures :projects, :users, :email_addresses, :roles, :members, :member_roles,
@@ -56,11 +56,14 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
     def test_get_new
       @request.session[:user_id] = 1
       @project.repository.destroy
-      get :new, :project_id => 'subproject1', :repository_scm => 'Mercurial'
+      get :new, :params => {
+          :project_id => 'subproject1',
+          :repository_scm => 'Mercurial'
+        }
       assert_response :success
-      assert_template 'new'
-      assert_kind_of Repository::Mercurial, assigns(:repository)
-      assert assigns(:repository).new_record?
+      assert_select 'select[name=?]', 'repository_scm' do
+        assert_select 'option[value=?][selected=selected]', 'Mercurial'
+      end
     end
 
     def test_show_root
@@ -68,16 +71,22 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       @repository.fetch_changesets
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
-      get :show, :id => PRJ_ID
+      get :show, :params => {
+          :id => PRJ_ID
+        }
       assert_response :success
-      assert_template 'show'
-      assert_not_nil assigns(:entries)
-      assert_equal 4, assigns(:entries).size
-      assert assigns(:entries).detect {|e| e.name == 'images'  && e.kind == 'dir'}
-      assert assigns(:entries).detect {|e| e.name == 'sources' && e.kind == 'dir'}
-      assert assigns(:entries).detect {|e| e.name == 'README'  && e.kind == 'file'}
-      assert_not_nil assigns(:changesets)
-      assert assigns(:changesets).size > 0
+
+      assert_select 'table.entries tbody' do
+        assert_select 'tr', 4
+        assert_select 'tr.dir td.filename a', :text => 'images'
+        assert_select 'tr.dir td.filename a', :text => 'sources'
+        assert_select 'tr.file td.filename a', :text => '.hgtags'
+        assert_select 'tr.file td.filename a', :text => 'README'
+      end
+
+      assert_select 'table.changesets tbody' do
+        assert_select 'tr'
+      end
     end
 
     def test_show_directory
@@ -85,17 +94,21 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       @repository.fetch_changesets
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
-      get :show, :id => PRJ_ID, :path => repository_path_hash(['images'])[:param]
+      get :show, :params => {
+          :id => PRJ_ID,
+          :path => repository_path_hash(['images'])[:param]
+        }
       assert_response :success
-      assert_template 'show'
-      assert_not_nil assigns(:entries)
-      assert_equal ['delete.png', 'edit.png'], assigns(:entries).collect(&:name)
-      entry = assigns(:entries).detect {|e| e.name == 'edit.png'}
-      assert_not_nil entry
-      assert_equal 'file', entry.kind
-      assert_equal 'images/edit.png', entry.path
-      assert_not_nil assigns(:changesets)
-      assert assigns(:changesets).size > 0
+
+      assert_select 'table.entries tbody' do
+        assert_select 'tr', 2
+        assert_select 'tr.file td.filename a', :text => 'delete.png'
+        assert_select 'tr.file td.filename a', :text => 'edit.png'
+      end
+
+      assert_select 'table.changesets tbody' do
+        assert_select 'tr'
+      end
     end
 
     def test_show_at_given_revision
@@ -104,14 +117,21 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
       [0, '0', '0885933ad4f6'].each do |r1|
-        get :show, :id => PRJ_ID, :path => repository_path_hash(['images'])[:param],
+        get :show, :params => {
+            :id => PRJ_ID,
+            :path => repository_path_hash(['images'])[:param],
             :rev => r1
+          }
         assert_response :success
-        assert_template 'show'
-        assert_not_nil assigns(:entries)
-        assert_equal ['delete.png'], assigns(:entries).collect(&:name)
-        assert_not_nil assigns(:changesets)
-        assert assigns(:changesets).size > 0
+
+        assert_select 'table.entries tbody' do
+          assert_select 'tr', 1
+          assert_select 'tr.file td.filename a', :text => 'delete.png'
+        end
+  
+        assert_select 'table.changesets tbody' do
+          assert_select 'tr'
+        end
       end
     end
 
@@ -121,19 +141,25 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
       [13, '13', '3a330eb32958'].each do |r1|
-        get :show, :id => PRJ_ID,
+        get :show, :params => {
+            :id => PRJ_ID,
             :path => repository_path_hash(['sql_escape', 'percent%dir'])[:param],
             :rev => r1
+          }
         assert_response :success
-        assert_template 'show'
 
-        assert_not_nil assigns(:entries)
-        assert_equal ['percent%file1.txt', 'percentfile1.txt'],
-                     assigns(:entries).collect(&:name)
-        changesets = assigns(:changesets)
-        assert_not_nil changesets
-        assert assigns(:changesets).size > 0
-        assert_equal %w(13 11 10 9), changesets.collect(&:revision)
+        assert_select 'table.entries tbody' do
+          assert_select 'tr', 2
+          assert_select 'tr.file td.filename a', :text => 'percent%file1.txt'
+          assert_select 'tr.file td.filename a', :text => 'percentfile1.txt'
+        end
+  
+        assert_select 'table.changesets tbody' do
+          assert_select 'tr td.id a', :text => /^13:/
+          assert_select 'tr td.id a', :text => /^11:/
+          assert_select 'tr td.id a', :text => /^10:/
+          assert_select 'tr td.id a', :text => /^9:/
+        end
       end
     end
 
@@ -143,27 +169,37 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
       [21, '21', 'adf805632193'].each do |r1|
-        get :show, :id => PRJ_ID,
+        get :show, :params => {
+            :id => PRJ_ID,
             :path => repository_path_hash(['latin-1-dir'])[:param],
             :rev => r1
+          }
         assert_response :success
-        assert_template 'show'
 
-        assert_not_nil assigns(:entries)
-        assert_equal ["make-latin-1-file.rb",
-                      "test-#{@char_1}-1.txt",
-                      "test-#{@char_1}-2.txt",
-                      "test-#{@char_1}.txt"], assigns(:entries).collect(&:name)
-        changesets = assigns(:changesets)
-        assert_not_nil changesets
-        assert_equal %w(21 20 19 18 17), changesets.collect(&:revision)
+        assert_select 'table.entries tbody' do
+          assert_select 'tr', 4
+          assert_select 'tr.file td.filename a', :text => "make-latin-1-file.rb"
+          assert_select 'tr.file td.filename a', :text => "test-#{@char_1}-1.txt"
+          assert_select 'tr.file td.filename a', :text => "test-#{@char_1}-2.txt"
+          assert_select 'tr.file td.filename a', :text => "test-#{@char_1}.txt"
+        end
+  
+        assert_select 'table.changesets tbody' do
+          assert_select 'tr td.id a', :text => /^21:/
+          assert_select 'tr td.id a', :text => /^20:/
+          assert_select 'tr td.id a', :text => /^19:/
+          assert_select 'tr td.id a', :text => /^18:/
+          assert_select 'tr td.id a', :text => /^17:/
+        end
       end
     end
 
     def show_should_show_branch_selection_form
       @repository.fetch_changesets
       @project.reload
-      get :show, :id => PRJ_ID
+      get :show, :params => {
+          :id => PRJ_ID
+        }
       assert_select 'form#revision_selector[action=?]', '/projects/subproject1/repository/show' do
         assert_select 'select[name=branch]' do
           assert_select 'option[value=?]', 'test-branch-01'
@@ -184,13 +220,14 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
           'test_branch.latin-1',
           'test-branch-00',
       ].each do |bra|
-        get :show, :id => PRJ_ID, :rev => bra
+        get :show, :params => {
+            :id => PRJ_ID,
+            :rev => bra
+          }
         assert_response :success
-        assert_template 'show'
-        assert_not_nil assigns(:entries)
-        assert assigns(:entries).size > 0
-        assert_not_nil assigns(:changesets)
-        assert assigns(:changesets).size > 0
+
+        assert_select 'table.entries tbody tr'
+        assert_select 'table.changesets tbody tr'
       end
     end
 
@@ -204,40 +241,44 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
         'tag_test.00',
         'tag-init-revision'
       ].each do |tag|
-        get :show, :id => PRJ_ID, :rev => tag
+        get :show, :params => {
+            :id => PRJ_ID,
+            :rev => tag
+          }
         assert_response :success
-        assert_template 'show'
-        assert_not_nil assigns(:entries)
-        assert assigns(:entries).size > 0
-        assert_not_nil assigns(:changesets)
-        assert assigns(:changesets).size > 0
+
+        assert_select 'table.entries tbody tr'
+        assert_select 'table.changesets tbody tr'
       end
     end
 
     def test_changes
-      get :changes, :id => PRJ_ID,
+      get :changes, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['images', 'edit.png'])[:param]
+        }
       assert_response :success
-      assert_template 'changes'
       assert_select 'h2', :text => /edit.png/
     end
 
     def test_entry_show
-      get :entry, :id => PRJ_ID,
+      get :entry, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param]
+        }
       assert_response :success
-      assert_template 'entry'
       # Line 10
       assert_select 'tr#L10 td.line-code', :text => /WITHOUT ANY WARRANTY/
     end
 
     def test_entry_show_latin_1_path
       [21, '21', 'adf805632193'].each do |r1|
-        get :entry, :id => PRJ_ID,
-            :path => repository_path_hash(['latin-1-dir', "test-#{@char_1}-2.txt"])[:param],
-            :rev => r1
+        get :entry, :params => {
+            :id => PRJ_ID,
+          :path => repository_path_hash(['latin-1-dir', "test-#{@char_1}-2.txt"])[:param],
+          :rev => r1
+          }
         assert_response :success
-        assert_template 'entry'
         assert_select 'tr#L1 td.line-code', :text => /Mercurial is a distributed version control system/
       end
     end
@@ -245,20 +286,23 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
     def test_entry_show_latin_1_contents
       with_settings :repositories_encodings => 'UTF-8,ISO-8859-1' do
         [27, '27', '7bbf4c738e71'].each do |r1|
-          get :entry, :id => PRJ_ID,
-              :path => repository_path_hash(['latin-1-dir', "test-#{@char_1}.txt"])[:param],
-              :rev => r1
+          get :entry, :params => {
+              :id => PRJ_ID,
+            :path => repository_path_hash(['latin-1-dir', "test-#{@char_1}.txt"])[:param],
+            :rev => r1
+            }
           assert_response :success
-          assert_template 'entry'
           assert_select 'tr#L1 td.line-code', :text => /test-#{@char_1}.txt/
         end
       end
     end
 
     def test_entry_download
-      get :entry, :id => PRJ_ID,
+      get :entry, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param],
           :format => 'raw'
+        }
       assert_response :success
       # File content
       assert @response.body.include?('WITHOUT ANY WARRANTY')
@@ -269,12 +313,13 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
     end
 
     def test_directory_entry
-      get :entry, :id => PRJ_ID,
+      get :entry, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources'])[:param]
+        }
       assert_response :success
-      assert_template 'show'
-      assert_not_nil assigns(:entry)
-      assert_equal 'sources', assigns(:entry).name
+      assert_select 'h2 a', :text => 'sources'
+      assert_select 'table.entries tbody'
     end
 
     def test_diff
@@ -285,9 +330,12 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       [4, '4', 'def6d2f1254a'].each do |r1|
         # Full diff of changeset 4
         ['inline', 'sbs'].each do |dt|
-          get :diff, :id => PRJ_ID, :rev => r1, :type => dt
+          get :diff, :params => {
+              :id => PRJ_ID,
+              :rev => r1,
+              :type => dt
+            }
           assert_response :success
-          assert_template 'diff'
           if @diff_c_support
             # Line 22 removed
             assert_select 'th.line-num:contains(22) ~ td.diff_out', :text => /def remove/
@@ -305,15 +353,13 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       [2, '400bb8672109', '400', 400].each do |r1|
         [4, 'def6d2f1254a'].each do |r2|
           ['inline', 'sbs'].each do |dt|
-            get :diff,
+            get :diff, :params => {
                 :id     => PRJ_ID,
                 :rev    => r1,
                 :rev_to => r2,
                 :type => dt
+              }
             assert_response :success
-            assert_template 'diff'
-            diff = assigns(:diff)
-            assert_not_nil diff
             assert_select 'h2', :text => /4:def6d2f1254a 2:400bb8672109/
           end
         end
@@ -324,9 +370,12 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       with_settings :repositories_encodings => 'UTF-8,ISO-8859-1' do
         [21, 'adf805632193'].each do |r1|
           ['inline', 'sbs'].each do |dt|
-            get :diff, :id => PRJ_ID, :rev => r1, :type => dt
+            get :diff, :params => {
+                :id => PRJ_ID,
+                :rev => r1,
+                :type => dt
+              }
             assert_response :success
-            assert_template 'diff'
             assert_select 'table' do
               assert_select 'thead th.filename', :text => /latin-1-dir\/test-#{@char_1}-2.txt/
               assert_select 'tbody td.diff_in', :text => /It is written in Python/
@@ -337,24 +386,31 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
     end
 
     def test_diff_should_show_modified_filenames
-      get :diff, :id => PRJ_ID, :rev => '400bb8672109', :type => 'inline'
+      get :diff, :params => {
+          :id => PRJ_ID,
+          :rev => '400bb8672109',
+          :type => 'inline'
+        }
       assert_response :success
-      assert_template 'diff'
       assert_select 'th.filename', :text => 'sources/watchers_controller.rb'
     end
 
     def test_diff_should_show_deleted_filenames
-      get :diff, :id => PRJ_ID, :rev => 'b3a615152df8', :type => 'inline'
+      get :diff, :params => {
+          :id => PRJ_ID,
+          :rev => 'b3a615152df8',
+          :type => 'inline'
+        }
       assert_response :success
-      assert_template 'diff'
       assert_select 'th.filename', :text => 'sources/welcome_controller.rb'
     end
 
     def test_annotate
-      get :annotate, :id => PRJ_ID,
+      get :annotate, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param]
+        }
       assert_response :success
-      assert_template 'annotate'
 
       # Line 22, revision 4:def6d2f1254a
       assert_select 'tr' do
@@ -370,8 +426,10 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       @repository.fetch_changesets
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
-      get :annotate, :id => PRJ_ID,
+      get :annotate, :params => {
+          :id => PRJ_ID,
           :path => repository_path_hash(['sources', 'welcome_controller.rb'])[:param]
+        }
       assert_response 404
       assert_select_error /was not found/
     end
@@ -382,21 +440,24 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
       [2, '400bb8672109', '400', 400].each do |r1|
-        get :annotate, :id => PRJ_ID, :rev => r1,
+        get :annotate, :params => {
+            :id => PRJ_ID,
+            :rev => r1,
             :path => repository_path_hash(['sources', 'watchers_controller.rb'])[:param]
+          }
         assert_response :success
-        assert_template 'annotate'
         assert_select 'h2', :text => /@ 2:400bb8672109/
       end
     end
 
     def test_annotate_latin_1_path
       [21, '21', 'adf805632193'].each do |r1|
-        get :annotate, :id => PRJ_ID,
-            :path => repository_path_hash(['latin-1-dir', "test-#{@char_1}-2.txt"])[:param],
-            :rev => r1
+        get :annotate, :params => {
+            :id => PRJ_ID,
+          :path => repository_path_hash(['latin-1-dir', "test-#{@char_1}-2.txt"])[:param],
+          :rev => r1
+          }
         assert_response :success
-        assert_template 'annotate'
         assert_select "th.line-num", :text => '1' do
           assert_select "+ td.revision" do
             assert_select "a", :text => '20:709858aafd1b'
@@ -412,9 +473,11 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
     def test_annotate_latin_1_contents
       with_settings :repositories_encodings => 'UTF-8,ISO-8859-1' do
         [27, '7bbf4c738e71'].each do |r1|
-          get :annotate, :id => PRJ_ID,
-              :path => repository_path_hash(['latin-1-dir', "test-#{@char_1}.txt"])[:param],
-              :rev => r1
+          get :annotate, :params => {
+              :id => PRJ_ID,
+            :path => repository_path_hash(['latin-1-dir', "test-#{@char_1}.txt"])[:param],
+            :rev => r1
+            }
           assert_select 'tr#L1 td.line-code', :text => /test-#{@char_1}.txt/
         end
       end
@@ -427,9 +490,11 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       assert_equal NUM_REV, @repository.changesets.count
       ['1', '9d5b5b', '9d5b5b004199'].each do |r|
         with_settings :default_language => "en" do
-          get :revision, :id => PRJ_ID, :rev => r
+          get :revision, :params => {
+              :id => PRJ_ID,
+              :rev => r
+            }
           assert_response :success
-          assert_template 'revision'
           assert_select 'title',
                         :text => 'Revision 1:9d5b5b004199 - Added 2 files and modified one. - eCookbook Subproject 1 - Redmine'
           end
@@ -442,7 +507,10 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       @project.reload
       assert_equal NUM_REV, @repository.changesets.count
       ['', ' ', nil].each do |r|
-        get :revision, :id => PRJ_ID, :rev => r
+        get :revision, :params => {
+            :id => PRJ_ID,
+            :rev => r
+          }
         assert_response 404
         assert_select_error /was not found/
       end
@@ -455,7 +523,9 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       assert_equal NUM_REV, @repository.changesets.count
 
       assert_difference 'Repository.count', -1 do
-        delete :destroy, :id => @repository.id
+        delete :destroy, :params => {
+            :id => @repository.id
+          }
       end
       assert_response 302
       @project.reload
@@ -474,7 +544,9 @@ class RepositoriesMercurialControllerTest < ActionController::TestCase
       assert_equal 0, @repository.changesets.count
 
       assert_difference 'Repository.count', -1 do
-        delete :destroy, :id => @repository.id
+        delete :destroy, :params => {
+            :id => @repository.id
+          }
       end
       assert_response 302
       @project.reload
