@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class WatchersControllerTest < ActionController::TestCase
+class WatchersControllerTest < Redmine::ControllerTest
   fixtures :projects, :users, :roles, :members, :member_roles, :enabled_modules,
            :issues, :trackers, :projects_trackers, :issue_statuses, :enumerations, :watchers
 
@@ -25,10 +25,20 @@ class WatchersControllerTest < ActionController::TestCase
     User.current = nil
   end
 
+  def test_watch_a_single_object_as_html
+    @request.session[:user_id] = 3
+    assert_difference('Watcher.count') do
+      post :watch, :params => {:object_type => 'issue', :object_id => '1'}
+      assert_response :success
+      assert_include 'Watcher added', response.body
+    end
+    assert Issue.find(1).watched_by?(User.find(3))
+  end
+
   def test_watch_a_single_object
     @request.session[:user_id] = 3
     assert_difference('Watcher.count') do
-      xhr :post, :watch, :object_type => 'issue', :object_id => '1'
+      post :watch, :params => {:object_type => 'issue', :object_id => '1'}, :xhr => true
       assert_response :success
       assert_include '$(".issue-1-watcher")', response.body
     end
@@ -38,7 +48,7 @@ class WatchersControllerTest < ActionController::TestCase
   def test_watch_a_collection_with_a_single_object
     @request.session[:user_id] = 3
     assert_difference('Watcher.count') do
-      xhr :post, :watch, :object_type => 'issue', :object_id => ['1']
+      post :watch, :params => {:object_type => 'issue', :object_id => ['1']}, :xhr => true
       assert_response :success
       assert_include '$(".issue-1-watcher")', response.body
     end
@@ -48,7 +58,7 @@ class WatchersControllerTest < ActionController::TestCase
   def test_watch_a_collection_with_multiple_objects
     @request.session[:user_id] = 3
     assert_difference('Watcher.count', 2) do
-      xhr :post, :watch, :object_type => 'issue', :object_id => ['1', '3']
+      post :watch, :params => {:object_type => 'issue', :object_id => ['1', '3']}, :xhr => true
       assert_response :success
       assert_include '$(".issue-bulk-watcher")', response.body
     end
@@ -61,7 +71,7 @@ class WatchersControllerTest < ActionController::TestCase
     assert_not_nil m = Project.find(1).enabled_module('news')
 
     assert_difference 'Watcher.count' do
-      xhr :post, :watch, :object_type => 'enabled_module', :object_id => m.id.to_s
+      post :watch, :params => {:object_type => 'enabled_module', :object_id => m.id.to_s}, :xhr => true
       assert_response :success
     end
     assert m.reload.watched_by?(User.find(7))
@@ -72,7 +82,7 @@ class WatchersControllerTest < ActionController::TestCase
     assert_not_nil m = Project.find(2).enabled_module('news')
 
     assert_no_difference 'Watcher.count' do
-      xhr :post, :watch, :object_type => 'enabled_module', :object_id => m.id.to_s
+      post :watch, :params => {:object_type => 'enabled_module', :object_id => m.id.to_s}, :xhr => true
       assert_response 403
     end
   end
@@ -81,7 +91,7 @@ class WatchersControllerTest < ActionController::TestCase
     Role.find(2).remove_permission! :view_issues
     @request.session[:user_id] = 3
     assert_no_difference('Watcher.count') do
-      xhr :post, :watch, :object_type => 'issue', :object_id => '1'
+      post :watch, :params => {:object_type => 'issue', :object_id => '1'}, :xhr => true
       assert_response 403
     end
   end
@@ -89,7 +99,7 @@ class WatchersControllerTest < ActionController::TestCase
   def test_watch_invalid_class_should_respond_with_404
     @request.session[:user_id] = 3
     assert_no_difference('Watcher.count') do
-      xhr :post, :watch, :object_type => 'foo', :object_id => '1'
+      post :watch, :params => {:object_type => 'foo', :object_id => '1'}, :xhr => true
       assert_response 404
     end
   end
@@ -97,15 +107,25 @@ class WatchersControllerTest < ActionController::TestCase
   def test_watch_invalid_object_should_respond_with_404
     @request.session[:user_id] = 3
     assert_no_difference('Watcher.count') do
-      xhr :post, :watch, :object_type => 'issue', :object_id => '999'
+      post :watch, :params => {:object_type => 'issue', :object_id => '999'}, :xhr => true
       assert_response 404
     end
   end
 
+  def test_unwatch_as_html
+    @request.session[:user_id] = 3
+    assert_difference('Watcher.count', -1) do
+      delete :unwatch, :params => {:object_type => 'issue', :object_id => '2'}
+      assert_response :success
+      assert_include 'Watcher removed', response.body
+    end
+    assert !Issue.find(1).watched_by?(User.find(3))
+  end
+
   def test_unwatch
     @request.session[:user_id] = 3
     assert_difference('Watcher.count', -1) do
-      xhr :delete, :unwatch, :object_type => 'issue', :object_id => '2'
+      delete :unwatch, :params => {:object_type => 'issue', :object_id => '2'}, :xhr => true
       assert_response :success
       assert_include '$(".issue-2-watcher")', response.body
     end
@@ -118,7 +138,7 @@ class WatchersControllerTest < ActionController::TestCase
     Watcher.create!(:user_id => 3, :watchable => Issue.find(3))
 
     assert_difference('Watcher.count', -2) do
-      xhr :delete, :unwatch, :object_type => 'issue', :object_id => ['1', '3']
+      delete :unwatch, :params => {:object_type => 'issue', :object_id => ['1', '3']}, :xhr => true
       assert_response :success
       assert_include '$(".issue-bulk-watcher")', response.body
     end
@@ -128,39 +148,52 @@ class WatchersControllerTest < ActionController::TestCase
 
   def test_new
     @request.session[:user_id] = 2
-    xhr :get, :new, :object_type => 'issue', :object_id => '2'
+    get :new, :params => {:object_type => 'issue', :object_id => '2'}, :xhr => true
     assert_response :success
     assert_match /ajax-modal/, response.body
   end
 
   def test_new_with_multiple_objects
     @request.session[:user_id] = 2
-    xhr :get, :new, :object_type => 'issue', :object_id => ['1', '2']
+    get :new, :params => {:object_type => 'issue', :object_id => ['1', '2']}, :xhr => true
     assert_response :success
     assert_match /ajax-modal/, response.body
   end
 
   def test_new_for_new_record_with_project_id
     @request.session[:user_id] = 2
-    xhr :get, :new, :project_id => 1
+    get :new, :params => {:project_id => 1}, :xhr => true
     assert_response :success
-    assert_equal Project.find(1), assigns(:project)
     assert_match /ajax-modal/, response.body
   end
 
   def test_new_for_new_record_with_project_identifier
     @request.session[:user_id] = 2
-    xhr :get, :new, :project_id => 'ecookbook'
+    get :new, :params => {:project_id => 'ecookbook'}, :xhr => true
     assert_response :success
-    assert_equal Project.find(1), assigns(:project)
     assert_match /ajax-modal/, response.body
   end
 
+  def test_create_as_html
+    @request.session[:user_id] = 2
+    assert_difference('Watcher.count') do
+      post :create, :params => {
+        :object_type => 'issue', :object_id => '2',
+        :watcher => {:user_id => '4'}
+      }
+      assert_response :success
+      assert_include 'Watcher added', response.body
+    end
+    assert Issue.find(2).watched_by?(User.find(4))
+  end
+
   def test_create
     @request.session[:user_id] = 2
     assert_difference('Watcher.count') do
-      xhr :post, :create, :object_type => 'issue', :object_id => '2',
-          :watcher => {:user_id => '4'}
+      post :create, :params => {
+        :object_type => 'issue', :object_id => '2',
+        :watcher => {:user_id => '4'}
+      }, :xhr => true
       assert_response :success
       assert_match /watchers/, response.body
       assert_match /ajax-modal/, response.body
@@ -171,8 +204,10 @@ class WatchersControllerTest < ActionController::TestCase
   def test_create_with_mutiple_users
     @request.session[:user_id] = 2
     assert_difference('Watcher.count', 2) do
-      xhr :post, :create, :object_type => 'issue', :object_id => '2',
-          :watcher => {:user_ids => ['4', '7']}
+      post :create, :params => {
+        :object_type => 'issue', :object_id => '2',
+        :watcher => {:user_ids => ['4', '7']}
+      }, :xhr => true
       assert_response :success
       assert_match /watchers/, response.body
       assert_match /ajax-modal/, response.body
@@ -184,8 +219,10 @@ class WatchersControllerTest < ActionController::TestCase
   def test_create_with_mutiple_objects
     @request.session[:user_id] = 2
     assert_difference('Watcher.count', 4) do
-      xhr :post, :create, :object_type => 'issue', :object_id => ['1', '2'],
-          :watcher => {:user_ids => ['4', '7']}
+      post :create, :params => {
+        :object_type => 'issue', :object_id => ['1', '2'],
+        :watcher => {:user_ids => ['4', '7']}
+      }, :xhr => true
       assert_response :success
       assert_match /watchers/, response.body
       assert_match /ajax-modal/, response.body
@@ -198,7 +235,7 @@ class WatchersControllerTest < ActionController::TestCase
 
   def test_autocomplete_on_watchable_creation
     @request.session[:user_id] = 2
-    xhr :get, :autocomplete_for_user, :q => 'mi', :project_id => 'ecookbook'
+    get :autocomplete_for_user, :params => {:q => 'mi', :project_id => 'ecookbook'}, :xhr => true
     assert_response :success
     assert_select 'input', :count => 4
     assert_select 'input[name=?][value="1"]', 'watcher[user_ids][]'
@@ -213,15 +250,17 @@ class WatchersControllerTest < ActionController::TestCase
     user = User.generate!(:firstname => 'issue15622')
     membership = user.membership(project)
     assert_nil membership
-    xhr :get, :autocomplete_for_user, :q => 'issue15622', :project_id => 'ecookbook'
+    get :autocomplete_for_user, :params => {:q => 'issue15622', :project_id => 'ecookbook'}, :xhr => true
     assert_response :success
     assert_select 'input', :count => 1
   end
 
   def test_autocomplete_on_watchable_update
     @request.session[:user_id] = 2
-    xhr :get, :autocomplete_for_user, :q => 'mi', :object_id => '2',
-        :object_type => 'issue', :project_id => 'ecookbook'
+    get :autocomplete_for_user, :params => {
+      :object_type => 'issue', :object_id => '2',
+      :project_id => 'ecookbook', :q => 'mi'
+    }, :xhr => true
     assert_response :success
     assert_select 'input', :count => 3
     assert_select 'input[name=?][value="2"]', 'watcher[user_ids][]'
@@ -235,13 +274,19 @@ class WatchersControllerTest < ActionController::TestCase
     user = User.generate!(:firstname => 'issue15622')
     membership = user.membership(project)
     assert_nil membership
-    xhr :get, :autocomplete_for_user, :q => 'issue15622', :object_id => '2',
-        :object_type => 'issue', :project_id => 'ecookbook'
+
+    get :autocomplete_for_user, :params => {
+      :object_type => 'issue', :object_id => '2',
+      :project_id => 'ecookbook', :q => 'issue15622'
+    }, :xhr => true
     assert_response :success
     assert_select 'input', :count => 1
+
     assert_difference('Watcher.count', 1) do
-      xhr :post, :create, :object_type => 'issue', :object_id => '2',
-          :watcher => {:user_ids => ["#{user.id}"]}
+      post :create, :params => {
+        :object_type => 'issue', :object_id => '2',
+        :watcher => {:user_ids => ["#{user.id}"]}
+      }, :xhr => true
       assert_response :success
       assert_match /watchers/, response.body
       assert_match /ajax-modal/, response.body
@@ -252,22 +297,24 @@ class WatchersControllerTest < ActionController::TestCase
   def test_autocomplete_for_user_should_return_visible_users
     Role.update_all :users_visibility => 'members_of_visible_projects'
 
-    hidden = User.generate!(:lastname => 'autocomplete')
-    visible = User.generate!(:lastname => 'autocomplete')
+    hidden = User.generate!(:lastname => 'autocomplete_hidden')
+    visible = User.generate!(:lastname => 'autocomplete_visible')
     User.add_to_project(visible, Project.find(1))
 
     @request.session[:user_id] = 2
-    xhr :get, :autocomplete_for_user, :q => 'autocomp', :project_id => 'ecookbook'
+    get :autocomplete_for_user, :params => {:q => 'autocomp', :project_id => 'ecookbook'}, :xhr => true
     assert_response :success
 
-    assert_include visible, assigns(:users)
-    assert_not_include hidden, assigns(:users)
+    assert_include visible.name, response.body
+    assert_not_include hidden.name, response.body
   end
 
   def test_append
     @request.session[:user_id] = 2
     assert_no_difference 'Watcher.count' do
-      xhr :post, :append, :watcher => {:user_ids => ['4', '7']}, :project_id => 'ecookbook'
+      post :append, :params => {
+        :watcher => {:user_ids => ['4', '7']}, :project_id => 'ecookbook'
+      }, :xhr => true
       assert_response :success
       assert_include 'watchers_inputs', response.body
       assert_include 'issue[watcher_user_ids][]', response.body
@@ -276,15 +323,29 @@ class WatchersControllerTest < ActionController::TestCase
 
   def test_append_without_user_should_render_nothing
     @request.session[:user_id] = 2
-    xhr :post, :append, :project_id => 'ecookbook'
+    post :append, :params => {:project_id => 'ecookbook'}, :xhr => true
     assert_response :success
     assert response.body.blank?
   end
 
+  def test_destroy_as_html
+    @request.session[:user_id] = 2
+    assert_difference('Watcher.count', -1) do
+      delete :destroy, :params => {
+        :object_type => 'issue', :object_id => '2', :user_id => '3'
+      }
+      assert_response :success
+      assert_include 'Watcher removed', response.body
+    end
+    assert !Issue.find(2).watched_by?(User.find(3))
+  end
+
   def test_destroy
     @request.session[:user_id] = 2
     assert_difference('Watcher.count', -1) do
-      xhr :delete, :destroy, :object_type => 'issue', :object_id => '2', :user_id => '3'
+      delete :destroy, :params => {
+        :object_type => 'issue', :object_id => '2', :user_id => '3'
+      }, :xhr => true
       assert_response :success
       assert_match /watchers/, response.body
     end
@@ -298,7 +359,9 @@ class WatchersControllerTest < ActionController::TestCase
 
     @request.session[:user_id] = 2
     assert_difference('Watcher.count', -1) do
-      xhr :delete, :destroy, :object_type => 'issue', :object_id => '2', :user_id => '3'
+      delete :destroy, :params => {
+        :object_type => 'issue', :object_id => '2', :user_id => '3'
+      }, :xhr => true
       assert_response :success
       assert_match /watchers/, response.body
     end
@@ -308,7 +371,9 @@ class WatchersControllerTest < ActionController::TestCase
   def test_destroy_invalid_user_should_respond_with_404
     @request.session[:user_id] = 2
     assert_no_difference('Watcher.count') do
-      delete :destroy, :object_type => 'issue', :object_id => '2', :user_id => '999'
+      delete :destroy, :params => {
+        :object_type => 'issue', :object_id => '2', :user_id => '999'
+      }
       assert_response 404
     end
   end
