@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../test_helper', __FILE__)
 
-class WorkflowsControllerTest < ActionController::TestCase
+class WorkflowsControllerTest < Redmine::ControllerTest
   fixtures :roles, :trackers, :workflows, :users, :issue_statuses
 
   def setup
@@ -28,7 +28,6 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_index
     get :index
     assert_response :success
-    assert_template 'index'
 
     count = WorkflowTransition.where(:role_id => 1, :tracker_id => 2).count
     assert_select 'a[href=?]', '/workflows/edit?role_id=1&tracker_id=2', :content => count.to_s
@@ -37,7 +36,6 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_get_edit
     get :edit
     assert_response :success
-    assert_template 'edit'
   end
 
   def test_get_edit_with_role_and_tracker
@@ -45,13 +43,13 @@ class WorkflowsControllerTest < ActionController::TestCase
     WorkflowTransition.create!(:role_id => 1, :tracker_id => 1, :old_status_id => 2, :new_status_id => 3)
     WorkflowTransition.create!(:role_id => 2, :tracker_id => 1, :old_status_id => 3, :new_status_id => 5)
 
-    get :edit, :role_id => 2, :tracker_id => 1
+    get :edit, :params => {:role_id => 2, :tracker_id => 1}
     assert_response :success
-    assert_template 'edit'
 
     # used status only
-    assert_not_nil assigns(:statuses)
-    assert_equal [2, 3, 5], assigns(:statuses).collect(&:id)
+    statuses = IssueStatus.where(:id => [2, 3, 5]).sorted.pluck(:name)
+    assert_equal ["New issue"] + statuses,
+      css_select('table.workflows.transitions-always tbody tr td:first').map(&:text).map(&:strip)
 
     # allowed transitions
     assert_select 'input[type=checkbox][name=?][value="1"][checked=checked]', 'transitions[3][5][always]'
@@ -61,32 +59,56 @@ class WorkflowsControllerTest < ActionController::TestCase
     assert_select 'input[type=checkbox][name=?]', 'transitions[1][1][always]', 0
   end
 
+  def test_get_edit_with_role_and_tracker_should_not_include_statuses_from_roles_without_workflow_permissions
+    WorkflowTransition.delete_all
+    WorkflowTransition.create!(:role_id => 1, :tracker_id => 1, :old_status_id => 2, :new_status_id => 3)
+
+    reporter = Role.find(3)
+    reporter.remove_permission! :edit_issues
+    reporter.remove_permission! :add_issues
+    assert !reporter.consider_workflow?
+    WorkflowTransition.create!(:role_id => 3, :tracker_id => 1, :old_status_id => 1, :new_status_id => 5)
+
+    get :edit, :params => {:role_id => 2, :tracker_id => 1}
+    assert_response :success
+
+    # statuses 1 and 5 not displayed
+    statuses = IssueStatus.where(:id => [2, 3]).sorted.pluck(:name)
+    assert_equal ["New issue"] + statuses,
+      css_select('table.workflows.transitions-always tbody tr td:first').map(&:text).map(&:strip)
+  end
+
   def test_get_edit_should_include_allowed_statuses_for_new_issues
     WorkflowTransition.delete_all
     WorkflowTransition.create!(:role_id => 1, :tracker_id => 1, :old_status_id => 0, :new_status_id => 1)
 
-    get :edit, :role_id => 1, :tracker_id => 1
+    get :edit, :params => {:role_id => 1, :tracker_id => 1}
     assert_response :success
     assert_select 'td', 'New issue'
     assert_select 'input[type=checkbox][name=?][value="1"][checked=checked]', 'transitions[0][1][always]'
   end
 
   def test_get_edit_with_all_roles_and_all_trackers
-    get :edit, :role_id => 'all', :tracker_id => 'all'
+    get :edit, :params => {:role_id => 'all', :tracker_id => 'all'}
     assert_response :success
-    assert_equal Role.sorted.to_a, assigns(:roles)
-    assert_equal Tracker.sorted.to_a, assigns(:trackers)
+
+    assert_select 'select[name=?][multiple=multiple]', 'role_id[]' do
+      assert_select 'option[selected=selected]', Role.all.select(&:consider_workflow?).count
+    end
+    assert_select 'select[name=?]', 'tracker_id[]' do
+      assert_select 'option[selected=selected][value=all]'
+    end
   end
 
   def test_get_edit_with_role_and_tracker_and_all_statuses
     WorkflowTransition.delete_all
 
-    get :edit, :role_id => 2, :tracker_id => 1, :used_statuses_only => '0'
+    get :edit, :params => {:role_id => 2, :tracker_id => 1, :used_statuses_only => '0'}
     assert_response :success
-    assert_template 'edit'
 
-    assert_not_nil assigns(:statuses)
-    assert_equal IssueStatus.count, assigns(:statuses).size
+    statuses = IssueStatus.all.sorted.pluck(:name)
+    assert_equal ["New issue"] + statuses,
+      css_select('table.workflows.transitions-always tbody tr td:first').map(&:text).map(&:strip)
 
     assert_select 'input[type=checkbox][name=?]', 'transitions[1][1][always]'
   end
@@ -94,11 +116,14 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_post_edit
     WorkflowTransition.delete_all
 
-    post :edit, :role_id => 2, :tracker_id => 1,
+    post :edit, :params => {
+      :role_id => 2,
+      :tracker_id => 1,
       :transitions => {
         '4' => {'5' => {'always' => '1'}},
         '3' => {'1' => {'always' => '1'}, '2' => {'always' => '1'}}
       }
+    }
     assert_response 302
 
     assert_equal 3, WorkflowTransition.where(:tracker_id => 1, :role_id => 2).count
@@ -109,10 +134,13 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_post_edit_with_allowed_statuses_for_new_issues
     WorkflowTransition.delete_all
 
-    post :edit, :role_id => 2, :tracker_id => 1,
+    post :edit, :params => {
+      :role_id => 2,
+      :tracker_id => 1,
       :transitions => {
         '0' => {'1' => {'always' => '1'}, '2' => {'always' => '1'}}
       }
+    }
     assert_response 302
 
     assert WorkflowTransition.where(:role_id => 2, :tracker_id => 1, :old_status_id => 0, :new_status_id => 1).any?
@@ -122,14 +150,17 @@ class WorkflowsControllerTest < ActionController::TestCase
 
   def test_post_edit_with_additional_transitions
     WorkflowTransition.delete_all
-  
-    post :edit, :role_id => 2, :tracker_id => 1,
+
+    post :edit, :params => {
+      :role_id => 2,
+      :tracker_id => 1,
       :transitions => {
         '4' => {'5' => {'always' => '1', 'author' => '0', 'assignee' => '0'}},
         '3' => {'1' => {'always' => '0', 'author' => '1', 'assignee' => '0'},
                 '2' => {'always' => '0', 'author' => '0', 'assignee' => '1'},
                 '4' => {'always' => '0', 'author' => '1', 'assignee' => '1'}}
       }
+    }
     assert_response 302
 
     assert_equal 4, WorkflowTransition.where(:tracker_id => 1, :role_id => 2).count
@@ -152,7 +183,6 @@ class WorkflowsControllerTest < ActionController::TestCase
     get :permissions
 
     assert_response :success
-    assert_template 'permissions'
   end
 
   def test_get_permissions_with_role_and_tracker
@@ -161,9 +191,8 @@ class WorkflowsControllerTest < ActionController::TestCase
     WorkflowPermission.create!(:role_id => 1, :tracker_id => 2, :old_status_id => 2, :field_name => 'fixed_version_id', :rule => 'required')
     WorkflowPermission.create!(:role_id => 1, :tracker_id => 2, :old_status_id => 3, :field_name => 'fixed_version_id', :rule => 'readonly')
 
-    get :permissions, :role_id => 1, :tracker_id => 2
+    get :permissions, :params => {:role_id => 1, :tracker_id => 2}
     assert_response :success
-    assert_template 'permissions'
 
     assert_select 'input[name=?][value="1"]', 'role_id[]'
     assert_select 'input[name=?][value="2"]', 'tracker_id[]'
@@ -202,9 +231,8 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_get_permissions_with_required_custom_field_should_not_show_required_option
     cf = IssueCustomField.create!(:name => 'Foo', :field_format => 'string', :tracker_ids => [1], :is_required => true)
 
-    get :permissions, :role_id => 1, :tracker_id => 1
+    get :permissions, :params => {:role_id => 1, :tracker_id => 1}
     assert_response :success
-    assert_template 'permissions'
 
     # Custom field that is always required
     # The default option is "(Required)"
@@ -220,9 +248,8 @@ class WorkflowsControllerTest < ActionController::TestCase
     cf2 = IssueCustomField.generate!(:tracker_ids => [1], :visible => false, :role_ids => [1])
     cf3 = IssueCustomField.generate!(:tracker_ids => [1], :visible => false, :role_ids => [1, 2])
 
-    get :permissions, :role_id => 2, :tracker_id => 1
+    get :permissions, :params => {:role_id => 2, :tracker_id => 1}
     assert_response :success
-    assert_template 'permissions'
 
     assert_select 'select[name=?]:not(.disabled)', "permissions[1][#{cf1.id}]"
     assert_select 'select[name=?]:not(.disabled)', "permissions[1][#{cf3.id}]"
@@ -236,7 +263,7 @@ class WorkflowsControllerTest < ActionController::TestCase
     WorkflowPermission.delete_all
     WorkflowPermission.create!(:role_id => 1, :tracker_id => 2, :old_status_id => 1, :field_name => 'assigned_to_id', :rule => 'required')
 
-    get :permissions, :role_id => [1, 2], :tracker_id => 2
+    get :permissions, :params => {:role_id => [1, 2], :tracker_id => 2}
     assert_response :success
 
     assert_select 'select[name=?]', 'permissions[1][assigned_to_id]' do
@@ -250,7 +277,7 @@ class WorkflowsControllerTest < ActionController::TestCase
     WorkflowPermission.create!(:role_id => 1, :tracker_id => 2, :old_status_id => 1, :field_name => 'assigned_to_id', :rule => 'required')
     WorkflowPermission.create!(:role_id => 2, :tracker_id => 2, :old_status_id => 1, :field_name => 'assigned_to_id', :rule => 'readonly')
 
-    get :permissions, :role_id => [1, 2], :tracker_id => 2
+    get :permissions, :params => {:role_id => [1, 2], :tracker_id => 2}
     assert_response :success
 
     assert_select 'select[name=?]', 'permissions[1][assigned_to_id]' do
@@ -264,7 +291,7 @@ class WorkflowsControllerTest < ActionController::TestCase
     WorkflowPermission.create!(:role_id => 1, :tracker_id => 2, :old_status_id => 1, :field_name => 'assigned_to_id', :rule => 'required')
     WorkflowPermission.create!(:role_id => 2, :tracker_id => 2, :old_status_id => 1, :field_name => 'assigned_to_id', :rule => 'required')
 
-    get :permissions, :role_id => [1, 2], :tracker_id => 2
+    get :permissions, :params => {:role_id => [1, 2], :tracker_id => 2}
     assert_response :success
 
     assert_select 'select[name=?]', 'permissions[1][assigned_to_id]' do
@@ -276,9 +303,12 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_get_permissions_with_role_and_tracker_and_all_statuses_should_show_all_statuses
     WorkflowTransition.delete_all
 
-    get :permissions, :role_id => 1, :tracker_id => 2, :used_statuses_only => '0'
+    get :permissions, :params => {:role_id => 1, :tracker_id => 2, :used_statuses_only => '0'}
     assert_response :success
-    assert_equal IssueStatus.sorted.to_a, assigns(:statuses)
+
+    statuses = IssueStatus.all.sorted.pluck(:name)
+    assert_equal statuses,
+      css_select('table.workflows.fields_permissions thead tr:nth-child(2) td:not(:first-child)').map(&:text).map(&:strip)
   end
 
   def test_get_permissions_should_set_css_class
@@ -287,7 +317,7 @@ class WorkflowsControllerTest < ActionController::TestCase
     cf = IssueCustomField.create!(:name => 'Foo', :field_format => 'string', :tracker_ids => [2])
     WorkflowPermission.create!(:role_id => 1, :tracker_id => 2, :old_status_id => 1, :field_name => cf.id, :rule => 'required')
 
-    get :permissions, :role_id => 1, :tracker_id => 2
+    get :permissions, :params => {:role_id => 1, :tracker_id => 2}
     assert_response :success
     assert_select 'td.required > select[name=?]', 'permissions[1][assigned_to_id]'
     assert_select 'td.required > select[name=?]', "permissions[1][#{cf.id}]"
@@ -296,10 +326,14 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_post_permissions
     WorkflowPermission.delete_all
 
-    post :permissions, :role_id => 1, :tracker_id => 2, :permissions => {
-      '1' => {'assigned_to_id' => '', 'fixed_version_id' => 'required', 'due_date' => ''},
-      '2' => {'assigned_to_id' => 'readonly', 'fixed_version_id' => 'readonly', 'due_date' => ''},
-      '3' => {'assigned_to_id' => '',  'fixed_version_id' => '', 'due_date' => ''}
+    post :permissions, :params => {
+      :role_id => 1,
+      :tracker_id => 2,
+      :permissions => {
+        '1' => {'assigned_to_id' => '', 'fixed_version_id' => 'required', 'due_date' => ''},
+        '2' => {'assigned_to_id' => 'readonly', 'fixed_version_id' => 'readonly', 'due_date' => ''},
+        '3' => {'assigned_to_id' => '',  'fixed_version_id' => '', 'due_date' => ''}
+      }
     }
     assert_response 302
 
@@ -317,7 +351,7 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_get_copy
     get :copy
     assert_response :success
-    assert_template 'copy'
+
     assert_select 'select[name=source_tracker_id]' do
       assert_select 'option[value="1"]', :text => 'Bug'
     end
@@ -335,8 +369,10 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_post_copy_one_to_one
     source_transitions = status_transitions(:tracker_id => 1, :role_id => 2)
 
-    post :copy, :source_tracker_id => '1', :source_role_id => '2',
-                :target_tracker_ids => ['3'], :target_role_ids => ['1']
+    post :copy, :params => {
+      :source_tracker_id => '1', :source_role_id => '2',
+      :target_tracker_ids => ['3'], :target_role_ids => ['1']
+    }
     assert_response 302
     assert_equal source_transitions, status_transitions(:tracker_id => 3, :role_id => 1)
   end
@@ -344,8 +380,10 @@ class WorkflowsControllerTest < ActionController::TestCase
   def test_post_copy_one_to_many
     source_transitions = status_transitions(:tracker_id => 1, :role_id => 2)
 
-    post :copy, :source_tracker_id => '1', :source_role_id => '2',
-                :target_tracker_ids => ['2', '3'], :target_role_ids => ['1', '3']
+    post :copy, :params => {
+      :source_tracker_id => '1', :source_role_id => '2',
+      :target_tracker_ids => ['2', '3'], :target_role_ids => ['1', '3']
+    }
     assert_response 302
     assert_equal source_transitions, status_transitions(:tracker_id => 2, :role_id => 1)
     assert_equal source_transitions, status_transitions(:tracker_id => 3, :role_id => 1)
@@ -357,8 +395,10 @@ class WorkflowsControllerTest < ActionController::TestCase
     source_t2 = status_transitions(:tracker_id => 2, :role_id => 2)
     source_t3 = status_transitions(:tracker_id => 3, :role_id => 2)
 
-    post :copy, :source_tracker_id => 'any', :source_role_id => '2',
-                :target_tracker_ids => ['2', '3'], :target_role_ids => ['1', '3']
+    post :copy, :params => {
+      :source_tracker_id => 'any', :source_role_id => '2',
+      :target_tracker_ids => ['2', '3'], :target_role_ids => ['1', '3']
+    }
     assert_response 302
     assert_equal source_t2, status_transitions(:tracker_id => 2, :role_id => 1)
     assert_equal source_t3, status_transitions(:tracker_id => 3, :role_id => 1)
@@ -368,19 +408,21 @@ class WorkflowsControllerTest < ActionController::TestCase
 
   def test_post_copy_with_incomplete_source_specification_should_fail
     assert_no_difference 'WorkflowRule.count' do
-      post :copy,
+      post :copy, :params => {
         :source_tracker_id => '', :source_role_id => '2',
         :target_tracker_ids => ['2', '3'], :target_role_ids => ['1', '3']
+      }
       assert_response 200
-      assert_select 'div.flash.error', :text => 'Please select a source tracker or role' 
+      assert_select 'div.flash.error', :text => 'Please select a source tracker or role'
     end
   end
 
   def test_post_copy_with_incomplete_target_specification_should_fail
     assert_no_difference 'WorkflowRule.count' do
-      post :copy,
+      post :copy, :params => {
         :source_tracker_id => '1', :source_role_id => '2',
         :target_tracker_ids => ['2', '3']
+      }
       assert_response 200
       assert_select 'div.flash.error', :text => 'Please select target tracker(s) and role(s)'
     end
