@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -30,12 +30,15 @@ class AdminTest < Redmine::IntegrationTest
     log_user("admin", "admin")
     get "/users/new"
     assert_response :success
-    assert_template "users/new"
-    post "/users",
-         :user => { :login => "psmith", :firstname => "Paul",
-                    :lastname => "Smith", :mail => "psmith@somenet.foo",
-                    :language => "en", :password => "psmith09",
-                    :password_confirmation => "psmith09" }
+
+    post "/users", :params => {
+        :user => {
+          :login => "psmith", :firstname => "Paul",
+          :lastname => "Smith", :mail => "psmith@somenet.foo",
+          :language => "en", :password => "psmith09",
+          :password_confirmation => "psmith09"
+        }
+      }
 
     user = User.find_by_login("psmith")
     assert_kind_of User, user
@@ -45,16 +48,24 @@ class AdminTest < Redmine::IntegrationTest
     assert_kind_of User, logged_user
     assert_equal "Paul", logged_user.firstname
 
-    put "/users/#{user.id}", :id => user.id, :user => { :status => User::STATUS_LOCKED }
+    put "/users/#{user.id}", :params => {
+        :id => user.id,
+        :user => {
+          :status => User::STATUS_LOCKED 
+        }
+      }
     assert_redirected_to "/users/#{ user.id }/edit"
     locked_user = User.try_to_login("psmith", "psmith09")
-    assert_equal nil, locked_user
+    assert_nil locked_user
   end
 
   test "Add a user as an anonymous user should fail" do
-    post '/users',
-         :user => { :login => 'psmith', :firstname => 'Paul'},
-         :password => "psmith09", :password_confirmation => "psmith09"
+    post '/users', :params => {
+        :user => {
+          :login => 'psmith', :firstname => 'Paul',
+          :password => "psmith09", :password_confirmation => "psmith09"
+        }
+      }
     assert_response :redirect
     assert_redirected_to "/login?back_url=http%3A%2F%2Fwww.example.com%2Fusers"
   end
