@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -21,7 +21,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
   fixtures :users
 
   def test_api_should_deny_without_credentials
-    get '/users/current.xml', {}
+    get '/users/current.xml'
     assert_response 401
     assert_equal User.anonymous, User.current
     assert response.headers.has_key?('WWW-Authenticate')
@@ -31,7 +31,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
     user = User.generate! do |user|
       user.password = 'my_password'
     end
-    get '/users/current.xml', {}, credentials(user.login, 'my_password')
+    get '/users/current.xml', :headers => credentials(user.login, 'my_password')
     assert_response 200
     assert_equal user, User.current
   end
@@ -40,7 +40,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
     user = User.generate! do |user|
       user.password = 'my_password'
     end
-    get '/users/current.xml', {}, credentials(user.login, 'wrong_password')
+    get '/users/current.xml', :headers => credentials(user.login, 'wrong_password')
     assert_response 401
     assert_equal User.anonymous, User.current
   end
@@ -48,7 +48,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
   def test_api_should_accept_http_basic_auth_using_api_key
     user = User.generate!
     token = Token.create!(:user => user, :action => 'api')
-    get '/users/current.xml', {}, credentials(token.value, 'X')
+    get '/users/current.xml', :headers => credentials(token.value, 'X')
     assert_response 200
     assert_equal user, User.current
   end
@@ -56,7 +56,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
   def test_api_should_deny_http_basic_auth_using_wrong_api_key
     user = User.generate!
     token = Token.create!(:user => user, :action => 'feeds') # not the API key
-    get '/users/current.xml', {}, credentials(token.value, 'X')
+    get '/users/current.xml', :headers => credentials(token.value, 'X')
     assert_response 401
     assert_equal User.anonymous, User.current
   end
@@ -64,7 +64,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
   def test_api_should_accept_auth_using_api_key_as_parameter
     user = User.generate!
     token = Token.create!(:user => user, :action => 'api')
-    get "/users/current.xml?key=#{token.value}", {}
+    get "/users/current.xml?key=#{token.value}"
     assert_response 200
     assert_equal user, User.current
   end
@@ -72,7 +72,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
   def test_api_should_deny_auth_using_wrong_api_key_as_parameter
     user = User.generate!
     token = Token.create!(:user => user, :action => 'feeds') # not the API key
-    get "/users/current.xml?key=#{token.value}", {}
+    get "/users/current.xml?key=#{token.value}"
     assert_response 401
     assert_equal User.anonymous, User.current
   end
@@ -80,7 +80,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
   def test_api_should_accept_auth_using_api_key_as_request_header
     user = User.generate!
     token = Token.create!(:user => user, :action => 'api')
-    get "/users/current.xml", {}, {'X-Redmine-API-Key' => token.value.to_s}
+    get "/users/current.xml", :headers => {'X-Redmine-API-Key' => token.value.to_s}
     assert_response 200
     assert_equal user, User.current
   end
@@ -88,20 +88,20 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
   def test_api_should_deny_auth_using_wrong_api_key_as_request_header
     user = User.generate!
     token = Token.create!(:user => user, :action => 'feeds') # not the API key
-    get "/users/current.xml", {}, {'X-Redmine-API-Key' => token.value.to_s}
+    get "/users/current.xml", :headers => {'X-Redmine-API-Key' => token.value.to_s}
     assert_response 401
     assert_equal User.anonymous, User.current
   end
 
   def test_api_should_trigger_basic_http_auth_with_basic_authorization_header
     ApplicationController.any_instance.expects(:authenticate_with_http_basic).once
-    get '/users/current.xml', {}, credentials('jsmith')
+    get '/users/current.xml', :headers => credentials('jsmith')
     assert_response 401
   end
 
   def test_api_should_not_trigger_basic_http_auth_with_non_basic_authorization_header
     ApplicationController.any_instance.expects(:authenticate_with_http_basic).never
-    get '/users/current.xml', {}, 'HTTP_AUTHORIZATION' => 'Digest foo bar'
+    get '/users/current.xml', :headers => {'HTTP_AUTHORIZATION' => 'Digest foo bar'}
     assert_response 401
   end
 
@@ -109,7 +109,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
     invalid_utf8 = "\x82".force_encoding('UTF-8')
     assert !invalid_utf8.valid_encoding?
     assert_nothing_raised do
-      get '/users/current.xml', {}, credentials(invalid_utf8, "foo")
+      get '/users/current.xml', :headers => credentials(invalid_utf8, "foo")
     end
   end
 
@@ -127,14 +127,14 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
     user = User.find(1)
     su = User.find(4)
 
-    get '/users/current', {}, {'X-Redmine-API-Key' => user.api_key, 'X-Redmine-Switch-User' => su.login}
+    get '/users/current', :headers => {'X-Redmine-API-Key' => user.api_key, 'X-Redmine-Switch-User' => su.login}
     assert_response :success
-    assert_equal su, assigns(:user)
+    assert_select 'h2', :text => su.name
     assert_equal su, User.current
   end
 
   def test_api_should_respond_with_412_when_trying_to_switch_to_a_invalid_user
-    get '/users/current', {}, {'X-Redmine-API-Key' => User.find(1).api_key, 'X-Redmine-Switch-User' => 'foobar'}
+    get '/users/current', :headers => {'X-Redmine-API-Key' => User.find(1).api_key, 'X-Redmine-Switch-User' => 'foobar'}
     assert_response 412
   end
 
@@ -142,7 +142,7 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
     user = User.find(5)
     assert user.locked?
 
-    get '/users/current', {}, {'X-Redmine-API-Key' => User.find(1).api_key, 'X-Redmine-Switch-User' => user.login}
+    get '/users/current', :headers => {'X-Redmine-API-Key' => User.find(1).api_key, 'X-Redmine-Switch-User' => user.login}
     assert_response 412
   end
 
@@ -150,9 +150,9 @@ class Redmine::ApiTest::AuthenticationTest < Redmine::ApiTest::Base
     user = User.find(2)
     su = User.find(4)
 
-    get '/users/current', {}, {'X-Redmine-API-Key' => user.api_key, 'X-Redmine-Switch-User' => su.login}
+    get '/users/current', :headers => {'X-Redmine-API-Key' => user.api_key, 'X-Redmine-Switch-User' => su.login}
     assert_response :success
-    assert_equal user, assigns(:user)
+    assert_select 'h2', :text => user.name
     assert_equal user, User.current
   end
 end
