@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,17 +27,6 @@ class AttachmentTest < ActiveSupport::TestCase
   # in transactional fixtures (https://github.com/rails/rails/pull/18458)
   self.use_transactional_fixtures = false
 
-  class MockFile
-    attr_reader :original_filename, :content_type, :content, :size
-
-    def initialize(attributes)
-      @original_filename = attributes[:original_filename]
-      @content_type = attributes[:content_type]
-      @content = attributes[:content] || "Content"
-      @size = content.size
-    end
-  end
-
   def setup
     set_tmp_attachments_directory
   end
@@ -62,7 +51,7 @@ class AttachmentTest < ActiveSupport::TestCase
     assert_equal 59, a.filesize
     assert_equal 'text/plain', a.content_type
     assert_equal 0, a.downloads
-    assert_equal '1478adae0d4eb06d35897518540e25d6', a.digest
+    assert_equal '6bc2eb7e87cfbf9145065689aaa8b5f513089ca0af68e2dc41f9cc025473d106', a.digest
 
     assert a.disk_directory
     assert_match %r{\A\d{4}/\d{2}\z}, a.disk_directory
@@ -81,7 +70,23 @@ class AttachmentTest < ActiveSupport::TestCase
     assert_nil a.content_type
   end
 
+  def test_shorted_filename_if_too_long
+    file = mock_file_with_options(:original_filename => "#{'a'*251}.txt")
+
+    a = Attachment.new(:container => Issue.find(1),
+                       :file => file,
+                       :author => User.find(1))
+    assert a.save
+    a.reload
+    assert_equal 12 + 1 + 32 + 4, a.disk_filename.length
+    assert_equal 255, a.filename.length
+  end
+
   def test_copy_should_preserve_attributes
+
+    # prevent re-use of data from other attachments with equal contents
+    Attachment.where('id <> 1').destroy_all
+
     a = Attachment.find(1)
     copy = a.copy
 
@@ -176,7 +181,7 @@ class AttachmentTest < ActiveSupport::TestCase
     assert_equal 59, a.filesize
     assert_equal 'text/plain', a.content_type
     assert_equal 0, a.downloads
-    assert_equal '1478adae0d4eb06d35897518540e25d6', a.digest
+    assert_equal '6bc2eb7e87cfbf9145065689aaa8b5f513089ca0af68e2dc41f9cc025473d106', a.digest
     diskfile = a.diskfile
     assert File.exist?(diskfile)
     assert_equal 59, File.size(a.diskfile)
@@ -208,23 +213,38 @@ class AttachmentTest < ActiveSupport::TestCase
     assert_equal 'text/plain', a.content_type
   end
 
-  def test_identical_attachments_at_the_same_time_should_not_overwrite
-    a1 = Attachment.create!(:container => Issue.find(1),
-                            :file => uploaded_test_file("testfile.txt", ""),
-                            :author => User.find(1))
-    a2 = Attachment.create!(:container => Issue.find(1),
-                            :file => uploaded_test_file("testfile.txt", ""),
-                            :author => User.find(1))
-    assert a1.disk_filename != a2.disk_filename
+  def test_attachments_with_same_content_should_reuse_same_file
+    a1 = Attachment.create!(:container => Issue.find(1), :author => User.find(1),
+                            :file => mock_file(:filename => 'foo', :content => 'abcd'))
+    a2 = Attachment.create!(:container => Issue.find(1), :author => User.find(1),
+                            :file => mock_file(:filename => 'bar', :content => 'abcd'))
+    assert_equal a1.diskfile, a2.diskfile
+  end
+
+  def test_attachments_with_same_content_should_not_reuse_same_file_if_deleted
+    a1 = Attachment.create!(:container => Issue.find(1), :author => User.find(1),
+                            :file => mock_file(:filename => 'foo', :content => 'abcd'))
+    a1.delete_from_disk
+    a2 = Attachment.create!(:container => Issue.find(1), :author => User.find(1),
+                            :file => mock_file(:filename => 'bar', :content => 'abcd'))
+    assert_not_equal a1.diskfile, a2.diskfile
+  end
+
+  def test_attachments_with_same_filename_at_the_same_time_should_not_overwrite
+    a1 = Attachment.create!(:container => Issue.find(1), :author => User.find(1),
+                            :file => mock_file(:filename => 'foo', :content => 'abcd'))
+    a2 = Attachment.create!(:container => Issue.find(1), :author => User.find(1),
+                            :file => mock_file(:filename => 'foo', :content => 'efgh'))
+    assert_not_equal a1.diskfile, a2.diskfile
   end
 
   def test_filename_should_be_basenamed
-    a = Attachment.new(:file => MockFile.new(:original_filename => "path/to/the/file"))
+    a = Attachment.new(:file => mock_file(:original_filename => "path/to/the/file"))
     assert_equal 'file', a.filename
   end
 
   def test_filename_should_be_sanitized
-    a = Attachment.new(:file => MockFile.new(:original_filename => "valid:[] invalid:?%*|\"'<>chars"))
+    a = Attachment.new(:file => mock_file(:original_filename => "valid:[] invalid:?%*|\"'<>chars"))
     assert_equal 'valid_[] invalid_chars', a.filename
   end
 
@@ -320,6 +340,14 @@ class AttachmentTest < ActiveSupport::TestCase
     assert_equal 'text/plain', attachment.content_type
   end
 
+  def test_update_digest_to_sha256_should_update_digest
+    set_fixtures_attachments_directory
+    attachment = Attachment.find 6
+    assert attachment.readable?
+    attachment.update_digest_to_sha256!
+    assert_equal 'ac5c6e99a21ae74b2e3f5b8e5b568be1b9107cd7153d139e822b9fe5caf50938', attachment.digest
+  end
+
   def test_update_attachments
     attachments = Attachment.where(:id => [2, 3]).to_a
 
@@ -418,4 +446,5 @@ class AttachmentTest < ActiveSupport::TestCase
   else
     puts '(ImageMagick convert not available)'
   end
+
 end
