@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,9 +17,8 @@
 
 require File.expand_path('../../../test_helper', __FILE__)
 
-class ActivitiesHelperTest < ActionView::TestCase
+class ActivitiesHelperTest < Redmine::HelperTest
   include ActivitiesHelper
-  include Redmine::I18n
 
   class MockEvent
     attr_reader :event_datetime, :event_group, :name
@@ -38,6 +37,7 @@ class ActivitiesHelperTest < ActionView::TestCase
   end
 
   def setup
+    super
     MockEvent.clear
   end
 
