@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,10 +17,9 @@
 
 require File.expand_path('../../../test_helper', __FILE__)
 
-class CustomFieldsHelperTest < ActionView::TestCase
+class CustomFieldsHelperTest < Redmine::HelperTest
   include ApplicationHelper
   include CustomFieldsHelper
-  include Redmine::I18n
   include ERB::Util
 
   def test_format_boolean_value
