@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,10 +17,9 @@
 
 require File.expand_path('../../../test_helper', __FILE__)
 
-class ProjectsHelperTest < ActionView::TestCase
+class ProjectsHelperTest < Redmine::HelperTest
   include ApplicationHelper
   include ProjectsHelper
-  include Redmine::I18n
   include ERB::Util
   include Rails.application.routes.url_helpers
 
@@ -33,12 +32,6 @@ class ProjectsHelperTest < ActionView::TestCase
            :groups_users,
            :enabled_modules
 
-  def setup
-    super
-    set_language_if_valid('en')
-    User.current = nil
-  end
-
   def test_link_to_version_within_project
     @project = Project.find(2)
     User.current = User.find(1)
