@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,9 +17,8 @@
 
 require File.expand_path('../../../test_helper', __FILE__)
 
-class QueriesHelperTest < ActionView::TestCase
+class QueriesHelperTest < Redmine::HelperTest
   include QueriesHelper
-  include Redmine::I18n
 
   fixtures :projects, :enabled_modules, :users, :members,
            :member_roles, :roles, :trackers, :issue_statuses,
@@ -89,7 +88,7 @@ class QueriesHelperTest < ActionView::TestCase
     ]
 
     with_locale 'fr' do
-      csv = query_to_csv(issues, IssueQuery.new, :columns => 'all')
+      csv = query_to_csv(issues, IssueQuery.new(:column_names => ['id', "cf_#{f.id}"]))
       assert_include "Oui", csv
       assert_include "Non", csv
     end
