@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,9 +17,8 @@
 
 require File.expand_path('../../../test_helper', __FILE__)
 
-class TimelogHelperTest < ActionView::TestCase
+class TimelogHelperTest < Redmine::HelperTest
   include TimelogHelper
-  include Redmine::I18n
   include ActionView::Helpers::TextHelper
   include ActionView::Helpers::DateHelper
   include ERB::Util
@@ -32,10 +31,6 @@ class TimelogHelperTest < ActionView::TestCase
                       :attachments,
                       :enumerations
 
-  def setup
-    super
-  end
-
   def test_activities_collection_for_select_options_should_return_array_of_activity_names_and_ids
     activities = activity_collection_for_select_options
     assert activities.include?(["Design", 9])
