@@ -27,7 +27,7 @@ class IssueNestedSetConcurrencyTest < ActiveSupport::TestCase
   self.use_transactional_fixtures = false
 
   def setup
-    skip if sqlite?
+    skip if sqlite? || mysql?
     CustomField.delete_all
   end
 
