@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -87,5 +87,14 @@ class Redmine::EnumerationFieldFormatTest < ActionView::TestCase
 
   def test_value_from_keyword_should_return_enumeration_id
     assert_equal @foo.id, @field.value_from_keyword('foo', nil)
+    assert_nil @field.value_from_keyword('baz', nil)
+  end
+
+  def test_value_from_keyword_for_multiple_custom_field_should_return_enumeration_ids
+    @field.multiple = true
+    @field.save!
+    assert_equal [@foo.id, @bar.id], @field.value_from_keyword('foo, bar', nil)
+    assert_equal [@foo.id], @field.value_from_keyword('foo, baz', nil)
+    assert_equal [], @field.value_from_keyword('baz', nil)
   end
 end
