@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -58,4 +58,22 @@ class Redmine::UserFieldFormatTest < ActionView::TestCase
 
     assert_equal ['Dave Lopper'], field.possible_values_options(project).map(&:first)
   end
+
+  def test_value_from_keyword_should_return_user_id
+    field = IssueCustomField.new(:field_format => 'user')
+    project = Project.find(1)
+
+    assert_equal 2, field.value_from_keyword('jsmith', project)
+    assert_equal 3, field.value_from_keyword('Dave Lopper', project)
+    assert_nil field.value_from_keyword('Unknown User', project)
+  end
+
+  def test_value_from_keyword_for_multiple_custom_field_should_return_enumeration_ids
+    field = IssueCustomField.new(:field_format => 'user', :multiple => true)
+    project = Project.find(1)
+
+    assert_equal [2, 3], field.value_from_keyword('jsmith, Dave Lopper', project)
+    assert_equal [2], field.value_from_keyword('jsmith', project)
+    assert_equal [], field.value_from_keyword('Unknown User', project)
+  end
 end
