@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 
 require File.expand_path('../../../../../test_helper', __FILE__)
 
-class Redmine::Helpers::GanttHelperTest < ActionView::TestCase
+class Redmine::Helpers::GanttHelperTest < Redmine::HelperTest
   fixtures :projects, :trackers, :issue_statuses,
            :enumerations, :users, :issue_categories
 
@@ -59,7 +59,7 @@ class Redmine::Helpers::GanttHelperTest < ActionView::TestCase
     assert_equal 2, @gantt.number_of_rows
   end
 
-  test "#number_of_rows with no project should return the total number of rows for all the projects, resursively" do
+  test "#number_of_rows with no project should return the total number of rows for all the projects, recursively" do
     p1, p2 = Project.generate!, Project.generate!
     create_gantt(nil)
     # fix the return value of #number_of_rows_on_project() to an arbitrary value
