@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2016  Jean-Philippe Lang
+# Copyright (C) 2006-2017  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -47,7 +47,7 @@ class TrackerTest < ActiveSupport::TestCase
 
     target = Tracker.new(:name => 'Target', :default_status_id => 1)
     assert target.save
-    target.workflow_rules.copy(source)
+    target.copy_workflow_rules(source)
     target.reload
     assert_equal rules_count, target.workflow_rules.size
   end
@@ -64,7 +64,7 @@ class TrackerTest < ActiveSupport::TestCase
   end
 
   def test_issue_statuses_empty
-    WorkflowTransition.delete_all("tracker_id = 1")
+    WorkflowTransition.where(:tracker_id => 1).delete_all
     assert_equal [], Tracker.find(1).issue_statuses
   end
 
@@ -110,7 +110,7 @@ class TrackerTest < ActiveSupport::TestCase
 
   def test_destroying_a_tracker_without_issues_should_not_raise_an_error
     tracker = Tracker.find(1)
-    Issue.delete_all :tracker_id => tracker.id
+    Issue.where(:tracker_id => tracker.id).delete_all
 
     assert_difference 'Tracker.count', -1 do
       assert_nothing_raised do
